using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using System.Security.Principal;
using Vha.Vtk.Common;
using Vha.Vtk.TimeKeeping;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;
using Vha.Vss.Utility;


namespace VTK.DailyTimeKeeping
{
	/// <summary>
	/// Summary description for OccasionalEdit.
	/// </summary>
	public class OccasionalEdit : Page
	{
		protected System.Web.UI.WebControls.Button GetTimeButton;
		protected System.Web.UI.WebControls.DropDownList SortByList;
		protected System.Web.UI.WebControls.Label OccasionalIdLabel;
		protected System.Web.UI.WebControls.ListBox OrganizationList;
		protected System.Web.UI.WebControls.ListBox ServiceList;
		protected System.Web.UI.WebControls.TextBox NameOrOrganizationText;
		protected System.Web.UI.WebControls.RangeValidator NumberValidator;
		protected System.Web.UI.WebControls.RangeValidator HoursValidator;
		protected System.Web.UI.HtmlControls.HtmlForm OccasionalTimeSheet;
		protected System.Web.UI.WebControls.DataGrid TimeSheetDataGrid;
		protected System.Web.UI.WebControls.Button DeleteButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label DataGridHeaderLabel;
		protected System.Web.UI.WebControls.DropDownList DayList;
		protected System.Web.UI.WebControls.Label MonthLabel;
		protected System.Web.UI.WebControls.Label YearLabel;
		protected System.Web.UI.WebControls.TextBox NumberInGroupText;
		protected System.Web.UI.WebControls.TextBox TotalHoursText;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.DropDownList MonthList;
		protected System.Web.UI.HtmlControls.HtmlGenericControl occBody;
	
		public OccasionalEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Occasional Hours")) 
				{
					if (!Page.IsPostBack)
					{
						//set today to current date time
						DateTime today = DateTime.Now ;
						DataSet dsm = Vha.Vtk.MealTickets.MealsProvided.GetMonthsList() ;
						DataTable dtm = dsm.Tables["MonthsList"] ;

						//define columns in list box
						MonthList.DataTextField = "Display" ;
						MonthList.DataValueField = "Month" ;

						//bind monthlist to DataTable
						MonthList.DataSource = dtm ;
						MonthList.DataBind() ;
						dsm.Dispose() ;
						dtm.Dispose() ;

						//if we have no months, then we can't continue
						if (MonthList.Items.Count < 1)
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "There are no available Months") ;
							GetTimeButton.Enabled = false ;
							DeleteButton.Enabled = false ;
							NewButton.Enabled = false ;
							PostButton.Enabled = false ;
						}
						else
						{
							// set month to return value or current
							if (ViewState["month"] != null)
							{ MonthList.SelectedIndex = Convert.ToInt32(ViewState["month"].ToString()) ;}
							else
							{ VtkUtility.SetSelectedSingle(MonthList.Items, today.Month.ToString()) ;}

							//get current station, must have, and use in selecting service and organizations
							int siteId = VtkPageHeader1.DivSelectedId ;

							GetServiceList(siteId) ;
							GetOrganizationList(siteId) ;
							GetDataGrid() ;
							InitializeFields() ;
							PostButton.Enabled = true ;
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheets: " + err.Message) ;}
		}

		private void GetTimeButton_Click(object sender, System.EventArgs e)
		{
			GetDataGrid() ;
		}

		private void GetServiceList(int siteId)
		{
			try
			{
				//populate list of Services, get dataset, sort by code
				DataSet dssrv = Service.GetSiteQuickListByName(siteId) ;
				DataTable dtsrv = dssrv.Tables["ServiceList"] ;

				//add the first row
				DataRow drsrv = dtsrv.NewRow() ;
				drsrv["DisplayName"] = " -Select Service Code- " ;
				drsrv["Code"] = "" ;
				dtsrv.Rows.InsertAt(drsrv, 0) ;


				//define columns in list box
				ServiceList.DataTextField = "DisplayName" ;
				ServiceList.DataValueField = "Id" ;

				//bind list box to DataTable and cleanup
				ServiceList.DataSource = dtsrv ;
				ServiceList.DataBind() ;
				dssrv.Dispose() ;
				dtsrv.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + err.Message) ;}
		}

		private void GetOrganizationList(int siteId)
		{
			try
			{
				//populate list of Organizations, get dataset, sort by code
				//ref. Vha.Vtk.Common.Organization
				DataSet dsorg = Organization.GetSiteActiveQuickListByName(siteId) ;
				DataTable dtorg = dsorg.Tables["OrganizationList"] ;

				//create a new column that will combine code and name
				dtorg.Columns.Add("CodeAndName", System.Type.GetType("System.String")) ;

				//add the first row
				DataRow drorg = dtorg.NewRow() ;
				drorg["DisplayName"] = " -Select Organization Code- " ;
				drorg["Id"] = 0 ;
				dtorg.Rows.InsertAt(drorg, 0) ;

				//loop and build string for the new column, CodeAndName
				/*foreach (DataRow dr in dtorg.Rows)
				{
					string s = String.Copy(dr["Code"].ToString().PadRight(6, '-') + dr["Name"]) ;
					dr["CodeAndName"] = s ;
				}
				*/

				//define columns in list box
				OrganizationList.DataTextField = "DisplayName" ;
				OrganizationList.DataValueField = "Id" ;

				//bind list box to DataTable and clean up
				OrganizationList.DataSource = dtorg ;
				OrganizationList.DataBind() ;
				dsorg.Dispose() ;
				dtorg.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void GetDataGrid()
		{
			//clear current fields
			InitializeFields() ;

			//must have a station and month/year
			int siteId = VtkPageHeader1.DivSelectedId ;
			string moyr = MonthList.SelectedItem.Text ;
			int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
			int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;

			DataGridHeaderLabel.Text = VtkPageHeader1.DivSelectedName.ToString() ;

			try
			{
				//check for closed records
				if (Vha.Vtk.Kernel.Data.SystemTables.RollupLog.IsMonthEditable(month, year))
				{
					//populate list of TimeSheets, get dataset(site, month, year, srvCfg)
					//ref. Vha.Vtk.TimeKeeping.OccasionalHours
					DataSet dsts = OccasionalHours.GetSiteMonthlyQuickListByDate(siteId, month, year, VtkUtility.GetAppCon()) ;
					//sort based on SortByList
					string selectedValue = SortByList.SelectedItem.Value.ToString() ;

					switch (selectedValue)
					{
						case "D":
							//sort by Date in descending order
							dsts.Tables["OccasionalHoursList"].DefaultView.Sort = "DateWorkProvided DESC" ;
							DataTable dtts1 = dsts.Tables["OccasionalHoursList"] ;

							//bind datagrid to DataTable
							TimeSheetDataGrid.DataSource = dtts1 ;
							TimeSheetDataGrid.DataBind() ;
							dsts.Dispose() ;
							break ;

						case "O":
							//sort by Organization in ascending order
							dsts.Tables["OccasionalHoursList"].DefaultView.Sort = "VolunteerOrganizationOrganizationName ASC" ;
							DataTable dtts2 = dsts.Tables["OccasionalHoursList"] ;

							//bind datagrid to DataTable
							TimeSheetDataGrid.DataSource = dtts2 ;
							TimeSheetDataGrid.DataBind() ;
							dsts.Dispose() ;
							break ;

						case "I":
							//sort by Id in descending order
							dsts.Tables["OccasionalHoursList"].DefaultView.Sort = "ID DESC" ;
							DataTable dtts3 = dsts.Tables["OccasionalHoursList"] ;						

							//bind datagrid to DataTable
							TimeSheetDataGrid.DataSource = dtts3 ;
							TimeSheetDataGrid.DataBind() ;
							dsts.Dispose() ;
							break ;
						default:
							break ;
					}
					GetServiceList(siteId) ;
					GetOrganizationList(siteId) ;
				}
				else
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "Time Sheets are CLOSED for the given month and year, No actions allowed") ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheets: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheets: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheets: " + err.Message) ;}
		}

		private void InitializeFields()
		{
			//input: userEdit = true, you want user to edit fields
			//clear fields
			OccasionalIdLabel.Text = string.Empty ;
			NameOrOrganizationText.Text = string.Empty ;
			NumberInGroupText.Text = string.Empty ;
			TotalHoursText.Text = string.Empty ;
			DayList.SelectedIndex = 0 ;
			OrganizationList.SelectedIndex = 0 ;
			ServiceList.SelectedIndex = 0 ;

			string moyr = MonthList.SelectedItem.Text ;
			MonthLabel.Text =  moyr.Substring(0, moyr.IndexOf(" "));
			YearLabel.Text =  moyr.Substring((moyr.IndexOf(" ")+1), 4) ;

			//clear viewstate variables
			ViewState["occasionalId"] = string.Empty ;
			ViewState["occasionalVersion"] = string.Empty ;
			//set default values
			OccasionalIdLabel.Text = "NEW" ;
			DeleteButton.Enabled = false ;
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			bool flag = false ;
			if (DayList.SelectedIndex < 1)
			{
				fields = "Date" ;
				flag = true ;
			}
			if (OrganizationList.SelectedIndex < 0)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Organization" ;
				flag = true ;
			}
			if (ServiceList.SelectedIndex < 0)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Service Assignment" ;
				flag = true ;
			}
			if (NumberInGroupText.Text == string.Empty )
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Number in Group" ;
				flag = true ;
			}
			if (TotalHoursText.Text == string.Empty )
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Total Hours" ;
			}
			return fields ;
		}

		private DateTime CheckDay(int day)
		{
			DateTime d = DateTime.MinValue ;
			string moyr = MonthList.SelectedItem.Text ;
			int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
			int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;
			try
			{
				d = new DateTime(year, month, day) ;
				return d ;
			}
			catch
			{ return d ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			ViewState["occasionalId"] = string.Empty ;
			ViewState["occasionalVersion"] = string.Empty ;
			int siteId = VtkPageHeader1.DivSelectedId ;
			string moyr = MonthList.SelectedItem.Text ;
			int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
			int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;
			//check for closed records
			if (Vha.Vtk.Kernel.Data.SystemTables.RollupLog.IsMonthEditable(month, year))
			{
				GetServiceList(siteId) ;
				GetOrganizationList(siteId) ;
				//clear fields
				InitializeFields() ;
				DayList.SelectedIndex = DateTime.Now.Day ;
			}
			else
			{
				InitializeFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Time Sheets are CLOSED for the given month and year, No actions allowed") ;
			}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following field(s) are Required: " + missingdata) ;}
			else
			{
				//check DayList
				DateTime DateWorked = CheckDay(Convert.ToInt32(DayList.SelectedItem.Value.ToString())) ;
				if (DateWorked == DateTime.MinValue)
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "An incorrect date was entered") ;
				}
				else
				{
					string moyr = MonthList.SelectedItem.Text ;
					int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
					int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;
					//check for closed records
					if (Vha.Vtk.Kernel.Data.SystemTables.RollupLog.IsMonthEditable(month, year))
					{
						//flag to check if version number has changed
						bool versionOk = true ;
						Vha.Vtk.TimeKeeping.OccasionalHours occhdl ;
						try
						{
							//disable post button until we are done
							PostButton.Enabled = false ;
							//existing record
							if (ViewState["occasionalId"].ToString() != string.Empty)
							{
								int occid = Convert.ToInt32(ViewState["occasionalId"].ToString()) ;
								//create handle and open current record
								occhdl = new OccasionalHours(occid) ;

								//check version
								if (ViewState["occasionalVersion"].ToString() != occhdl.Version.ToString())
								{
									VtkUtility.ErrMsgAdd(ErrorMessage, "Current Occasional Time Sheet record has changed while you were editing, Please press EXIT and start over. ") ;
									versionOk = false ;
								}
							}
								//new record
							else
							{
								//create handle and open new record
								occhdl = OccasionalHours.AddRecord() ;
							}
							if (versionOk)
							{
								//save current fields
								occhdl.Comments = NameOrOrganizationText.Text.ToString() ;
								occhdl.NumberInGroup = Convert.ToInt32(NumberInGroupText.Text.ToString()) ;
								occhdl.TotalHours = Convert.ToInt32(TotalHoursText.Text.ToString()) ;
								occhdl.DateWorkProvided = DateWorked ;
								occhdl.StationId = VtkPageHeader1.DivSelectedId ;

								if (OrganizationList.SelectedIndex>-1)
								{occhdl.OrganizationId = Convert.ToInt32(OrganizationList.SelectedItem.Value.ToString()) ;}
								if (ServiceList.SelectedIndex>-1)
								{occhdl.ServiceAssignmentId = Convert.ToInt32(ServiceList.SelectedItem.Value.ToString()) ;}

								//save and close
								occhdl.Save() ;
								occhdl.Dispose() ;
								//update confirmation message
								ConfirmationMessage.Text = "Record " + ViewState["occasionalId"] + " Posted!" ;
								//update DataGrid
								GetDataGrid() ;
								InitializeFields() ;
							}
						}
						catch (VhaValidationException valErr)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + valErr.Message) ;}
						catch (VhaTransactionException transErr)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + transErr.Message) ;}
						catch (Exception err)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet Record: " + err.Message) ;}
						finally
						{ PostButton.Enabled = true ;}
					}
					else
					{
						InitializeFields() ;
						VtkUtility.ErrMsgAdd(ErrorMessage, "Time Sheets are CLOSED for the given month and year, record NOT posted") ;
					}
				}
			}
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			if (ViewState["occasionalId"].ToString() != string.Empty)
			{
				//get id of existing record
				int occid = Convert.ToInt32(ViewState["occasionalId"].ToString()) ;
				try
				{
					Vha.Vtk.TimeKeeping.OccasionalHours occhdl ;
					//create handle and open current record
					occhdl = new OccasionalHours(Convert.ToInt32(occid)) ;
					//delete, save and close
					occhdl.Delete() ;
					occhdl.Save() ;
					occhdl.Dispose() ;
					//update confirmation message
					ConfirmationMessage.Text = "Record " + ViewState["occasionalId"] + " DELETED!" ;
					//Update DataGrid
					GetDataGrid() ;
					InitializeFields() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Occasional Time Sheet: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Cannot Delete a record without an ID number!") ;}
		}

		private void TimeSheetEdit_Click(object sender, System.EventArgs e)
		{
			//get selected timesheet
			int occid = Convert.ToInt32(TimeSheetDataGrid.SelectedItem.Cells[1].Text) ;

			try
			{
				//create handle
				Vha.Vtk.TimeKeeping.OccasionalHours occhdl = new Vha.Vtk.TimeKeeping.OccasionalHours(occid) ;

				// set current month and year in header
				//VtkUtility.SetSelectedSingle(MonthList.Items, occhdl.DateWorkProvided.Month.ToString()) ;
				//VtkUtility.SetSelectedSingle(YearList.Items, occhdl.DateWorkProvided.Year.ToString()) ;
				//clear fields, it will alse set month & year in body
				InitializeFields() ;
				//set viewstate variables
				ViewState["occasionalId"] = occhdl.ID ;
				ViewState["occasionalVersion"] = occhdl.Version.ToString() ;
				//set day in body
				DayList.SelectedIndex = occhdl.DateWorkProvided.Day ;
				//populate other fields
				OccasionalIdLabel.Text = occhdl.ID.ToString() ;
				NameOrOrganizationText.Text = occhdl.Comments.ToString() ;
				NumberInGroupText.Text = occhdl.NumberInGroup.ToString() ;
				TotalHoursText.Text = occhdl.TotalHours.ToString() ;
				//enable button
				DeleteButton.Enabled = true ;

				if (occhdl.OrganizationId > 0)
				{
					VtkUtility.SetSelectedSingle(OrganizationList.Items, occhdl.OrganizationId.ToString());
				}
				else
				{ OrganizationList.SelectedIndex = 0 ;}

				if (occhdl.ServiceAssignmentId > 0)
				{
					VtkUtility.SetSelectedSingle(ServiceList.Items, occhdl.ServiceAssignmentId.ToString());
				}
				else
				{ ServiceList.SelectedIndex = 0 ;}

				occhdl.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{
				InitializeFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + valErr.Message) ;
			}
			catch (VhaTransactionException transErr)
			{
				InitializeFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet: " + transErr.Message) ;
			}
			catch (Exception err)
			{
				InitializeFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Occasional Time Sheet Record: " + err.Message) ;
			}
		}

		private void FinishButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.GetTimeButton.Click += new System.EventHandler(this.GetTimeButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.DeleteButton.Click += new System.EventHandler(this.DeleteButton_Click);
			this.TimeSheetDataGrid.SelectedIndexChanged += new System.EventHandler(this.TimeSheetEdit_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}