using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for AffiliatedOrganizationEdit.
	/// </summary>
	public class AffiliatedOrganizationEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button AddButton;
		protected System.Web.UI.WebControls.DropDownList OrganizationList;
		protected System.Web.UI.WebControls.DataGrid OrganizationDataGrid;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;

		int siteId ;
	
		public AffiliatedOrganizationEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Affiliated Organizations")) 
				{
					if (!Page.IsPostBack) 
					{
						siteId = VtkPageHeader1.DivSelectedId ;

						//populate list of Organizations, get dataset, sort by code
						DataSet dsorg = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(siteId) ;
						//dsorg.Tables["OrganizationList"].DefaultView.Sort = "Code ASC" ;
						DataTable dtorg = dsorg.Tables["OrganizationList"] ;

						//add the first row
						DataRow drorg = dtorg.NewRow() ;
						drorg["DisplayName"] = " -Select Organization Code- " ;
						drorg["Id"] = 0 ;
						dtorg.Rows.InsertAt(drorg, 0) ;

						//define columns in list box
						OrganizationList.DataTextField = "DisplayName" ;
						OrganizationList.DataValueField = "Id" ;

						//bind list box to DataTable and dispose
						OrganizationList.DataSource = dtorg ;
						OrganizationList.DataBind() ;
						dsorg.Dispose() ;
						dtorg.Dispose() ;

						GetDataGrid(siteId) ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			} 
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void GetDataGrid(int siteId)
		{
			try
			{
				//populate DataGrid of Affiliated Organizations
				DataSet dsaorg = Vha.Vtk.Common.AffiliatedOrganization.GetQuickList(siteId) ;
				//dsorg.Tables["AffiliatedOrganizationCollection"].DefaultView.Sort = "Code ASC" ;
				DataTable dtaorg = dsaorg.Tables["AffiliatedOrganizationList"] ;

				//bind list box to DataTable and dispose
				OrganizationDataGrid.DataSource = dtaorg ;
				OrganizationDataGrid.DataBind() ;
				dsaorg.Dispose() ;
				dtaorg.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + err.Message) ;}
		}

		private void AddButton_Click(object sender, System.EventArgs e)
		{
			if (OrganizationList.SelectedIndex > 0)
			{
				try
				{
					//get selected org to add and site id
					int orgid = Convert.ToInt32(OrganizationList.SelectedItem.Value.ToString()) ;
					siteId = VtkPageHeader1.DivSelectedId ;
					//create new record and save organization id
					Vha.Vtk.Common.AffiliatedOrganization neworg = Vha.Vtk.Common.AffiliatedOrganization.AddRecord(siteId, VtkUtility.GetAppCon()) ;
					neworg.OrganizationId = orgid ;
					//save and close
					neworg.Save() ;
					neworg.Dispose() ;

					//update confirmation message
					ConfirmationMessage.Text = "Record Added!" ;
					//reset org list back to begining
					OrganizationList.SelectedIndex = 0 ;
					//update data grid
					GetDataGrid(siteId) ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select an Organization to Add") ;}
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		private void OrganizationDeleteButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				//get selected org to delete and site id
				int orgid = Convert.ToInt32(OrganizationDataGrid.SelectedItem.Cells[1].Text) ;
				siteId = VtkPageHeader1.DivSelectedId ;
				//create handle to record
				Vha.Vtk.Common.AffiliatedOrganization orghdl = new Vha.Vtk.Common.AffiliatedOrganization(orgid, VtkUtility.GetAppCon()) ;

				//delete, save and close
				orghdl.Delete() ;
				orghdl.Save() ;
				orghdl.Dispose() ;
				//update confirmation message
				ConfirmationMessage.Text = "Record Deleted!" ;
				//Update DataGrid
				GetDataGrid(siteId) ;			
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Affiliated Organization Record: " + err.Message) ;}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.AddButton.Click += new System.EventHandler(this.AddButton_Click);
			this.OrganizationDataGrid.SelectedIndexChanged += new System.EventHandler(this.OrganizationDeleteButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void DivisionChange(object sender, System.EventArgs e)
		{

		}

	}
}
