using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Donations;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for DonationChooserNew.
	/// </summary>
	public class DonationChooserNew : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button AddButton;
		protected System.Web.UI.WebControls.Button ChooseButton;
		protected System.Web.UI.WebControls.ListBox DonorList;
		protected System.Web.UI.WebControls.Button OrganizationButton;
		protected System.Web.UI.WebControls.DropDownList OrganizationList;
		protected System.Web.UI.WebControls.Button AffiliationButton;
		protected System.Web.UI.WebControls.TextBox AffiliationText;
		protected System.Web.UI.WebControls.Button NameButton;
		protected System.Web.UI.WebControls.TextBox LastNameText;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label MatchLabel;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		const string emptyText="Enter info above to search for an existing Donor";

	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Add|Edit Donation"))
				{
					if (!Page.IsPostBack)
					{
						//get current station, must have, and use in selecting organizations
						int siteId = VtkPageHeader1.DivSelectedId ;

						GetOrganizationList(siteId) ;
						Refresh() ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Donations: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Donations: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Donations: " + err.Message) ;}
			
		}

		private void GetOrganizationList(int siteId)
		{
			try
			{
				//populate list of Organizations, get dataset, sort by code
				//ref. Vha.Vtk.Common.Organization
				DataSet dsorg = Organization.GetSiteActiveQuickListByName(siteId) ;
				DataTable dtorg = dsorg.Tables["OrganizationList"] ;

				//add the first row
				DataRow drorg = dtorg.NewRow() ;
				drorg["DisplayName"] = " -Select Organization Code- " ;
				drorg["Id"] = 0 ;
				dtorg.Rows.InsertAt(drorg, 0) ;
				
				//define columns in list box
				OrganizationList.DataTextField = "DisplayName" ;
				OrganizationList.DataValueField = "Id" ;

				//bind list box to DataTable and clean up
				OrganizationList.DataSource = dtorg ;
				OrganizationList.DataBind() ;
				dsorg.Dispose() ;
				dtorg.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void Refresh()
		{
			//clear both lists and fields for new entry
			DonorList.Items.Clear() ;
			DonorList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
			DonorList.Enabled = false ;
			//filter is check in GetDonationList(input); "donorId", "date", or none
			ViewState["filter"] = string.Empty ;
			//donorName is check in AddButton_Click, contains donor name
			//it determines which text field to get the name from, begins with (1=individual,4=organization,5=affiliation)
			ViewState["donorName"] = string.Empty ;
		}

		private void EnableDonorList(DataTable dt)
		{
			ChooseButton.Enabled = true ;
			DonorList.Enabled = true ;
			//define columns in donor list
			DonorList.DataTextField = "DisplayName" ;
			DonorList.DataValueField = "ID" ;
			//bind list box to DataTable
			DonorList.DataSource = dt ;
			DonorList.DataBind() ;
		}

		private string NavBuilder(string donation, string donor, string name)
		{
			//build url string to navigate to DonorEdit.aspx, add query strings
			StringBuilder sb = new StringBuilder("DonationEdit.aspx") ;
			sb.Append("?") ;
			//add division
			sb.Append(VtkPageHeader.GetURLParameterString()) ;
			sb.Append("=") ;
			sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
			//add donation id or 'new'
			sb.Append("&donationId=") ;
			sb.Append(donation) ;
			//add donor id or 'new'
			sb.Append("&donorId=") ;
			sb.Append(donor) ;
			//add donor name, begins with donor type(1=individual,2=organization,3=affiliation)
			sb.Append("&donorName=") ;
			sb.Append(name) ;
			return sb.ToString() ;
		}

		private void ChooseButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				string donorId ;
				string donorName ;
				if (DonorList.SelectedIndex < 0)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please select Donor and press 'Choose'") ;}
				else
				{
					donorId = DonorList.SelectedItem.Value.ToString() ;
					donorName = DonorList.SelectedItem.Text ;
					//goto new page, donationId='new' for a new donation
					Response.Redirect(NavBuilder("new", donorId, donorName)) ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error navigating to next screen: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error navigating to next screen: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error navigating to next screen: " + err.Message) ;}
		}

		private void AddButton_Click(object sender, System.EventArgs e)
		{
			string donorId ;
			string donorName = null ;
			try
			{
				donorId = "new" ;
				if (ViewState["donorName"].ToString() != string.Empty)
				{ donorName = ViewState["donorName"].ToString() ;}

				//goto new page, donationId='new' for a new donation, donor='new' for new donor, name= 1=individual,2=organization,3=affiliation
				Response.Redirect(NavBuilder("new", donorId, donorName)) ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error navigating to next screen: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error navigating to next screen: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error navigating to next screen: " + err.Message) ;}
		}

		private void NameButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				int siteId = VtkPageHeader1.DivSelectedId ;
				string lastName = LastNameText.Text.Trim() ;
				string display ;
				//clear other fields
				AffiliationText.Text = string.Empty ;
				OrganizationList.SelectedIndex = 0 ;
				Refresh() ;

				if (lastName.Length < 3)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the first 3 or more characters of the Donor's Last Name and press 'List By Name'") ;}
				else
				{
					//donorName is needed in case they press the add button
					ViewState["donorName"] = "1" + LastNameText.Text ;

					DataSet nameDs = Vha.Vtk.Donations.Donor.GetQuickListBy_StationId_LastName(siteId, lastName) ;
					DataTable nameDt = nameDs.Tables["GetQuickListBy_StationId_LastName"] ;
					//create a new column for display name
					nameDt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;
					//check if anything was found
					if (nameDt.Rows.Count > 0)
					{
						//loop and build string for the new column, DisplayName
						foreach (DataRow dr in nameDt.Rows)
						{
							display = String.Copy(dr["LastName"] + ", " + dr["FirstName"]) ;
							//Donor Type: 1=Individual, 2=Ind&Org, 3=Ind&Affil, 4=Organization, 5=Affiliate
							switch (dr["DonorTypeId"].ToString())
							{
								case "2":
									display = display + " -- Org: " + dr["OrganizationName"] + "(" + dr["OrganizationCode"] + ")" ;
									break ;
								case "3":
									display = display + " -- Affl: " + dr["DonorAffiliation"] ;
									break ;
								default:
									break ;
							}
							dr["DisplayName"] = display ;
						}
						//set ViewState for filter
						ViewState["filter"] = "donorId" ;
						//populate donor list
						EnableDonorList(nameDt) ;
						//if only one donor, select it
						if (nameDt.Rows.Count == 1)
						{ DonorList.SelectedIndex = 0 ;}
					}
					else
					{
						MatchLabel.Text = "No Donors match your criteria, Press 'Add' to create new Donor!" ;
						MatchLabel.Visible = true ;
					}
					nameDs.Dispose() ;
					nameDt.Dispose() ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + err.Message) ;}
		
		}

		private void AffiliationButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				int siteId = VtkPageHeader1.DivSelectedId ;
				string affiliation = AffiliationText.Text.Trim() ;
				string display ;
				//clear other fields
				LastNameText.Text = string.Empty ;
				OrganizationList.SelectedIndex = 0 ;
				Refresh() ;

				if (affiliation.Length < 3)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the first 3 or more characters of the Donor's Affiliation and press 'List By Affiliation'") ;}
				else
				{
					//donorName is needed in case they press the add button
					ViewState["donorName"] = "5" + AffiliationText.Text ;
					DataSet affDs = Vha.Vtk.Donations.Donor.GetQuickListBy_StationId_DonorAffiliation(siteId, affiliation) ;
					DataTable affDt = affDs.Tables["GetQuickListBy_StationId_DonorAffiliation"] ;
					//create a new column for display name
					affDt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;
					//check if anything was found
					if (affDt.Rows.Count > 0)
					{
						//loop and build string for the new column, DisplayName
						foreach (DataRow dr in affDt.Rows)
						{
							display = dr["DonorAffiliation"].ToString() ;
							//Donor Type: 1=Individual, 2=Ind&Org, 3=Ind&Affil, 4=Organization, 5=Affiliate
							switch (dr["DonorTypeId"].ToString())
							{
								case "3":
									display = display + " -- " + dr["LastName"] + ", " + dr["FirstName"] ;
									break ;
								default:
									break ;
							}
							dr["DisplayName"] = display ;
						}
						//set ViewState for filter
						ViewState["filter"] = "donorId" ;
						//populate donor list
						EnableDonorList(affDt) ;
						//if only one donor, select it
						if (affDt.Rows.Count == 1)
						{ DonorList.SelectedIndex = 0 ;}
					}
					else
					{
						MatchLabel.Text = "No Donors match your criteria, Press 'Add' to create new Donor!" ;
						MatchLabel.Visible = true ;
					}
					affDs.Dispose() ;
					affDt.Dispose() ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + err.Message) ;}
		
		}

		private void OrganizationButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				if (OrganizationList.SelectedIndex < 1)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please select an Organization and press 'List By Organization'") ;}
				else
				{
					int siteId = VtkPageHeader1.DivSelectedId ;
					int orgId = Convert.ToInt32(OrganizationList.SelectedItem.Value) ;
					string display ;
					//clear other fields
					LastNameText.Text = string.Empty ;
					AffiliationText.Text = string.Empty ;
					Refresh() ;
					//donorName is needed in case they press the add button
					ViewState["donorName"] = "4" + OrganizationList.SelectedItem.Value.ToString() ;

					DataSet orgDs = Vha.Vtk.Donations.Donor.GetQuickListBy_StationId_OrganizationId(siteId, orgId) ;
					DataTable orgDt = orgDs.Tables["GetQuickListBy_StationId_OrganizationId"] ;
					//create a new column for display name
					orgDt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;
					//check if anything was found
					if (orgDt.Rows.Count > 0)
					{
						//loop and build string for the new column, DisplayName
						foreach (DataRow dr in orgDt.Rows)
						{
							display = dr["OrganizationName"].ToString() ;
							//Donor Type: 1=Individual, 2=Ind&Org, 3=Ind&Affil, 4=Organization, 5=Affiliate
							switch (dr["DonorTypeId"].ToString())
							{
								case "2":
									display = display + " -- " + dr["LastName"] + ", " + dr["FirstName"] ;
									break ;
								default:
									break ;
							}
							dr["DisplayName"] = display ;
						}
						//set ViewState for filter
						ViewState["filter"] = "donorId" ;
						//populate donor list
						EnableDonorList(orgDt) ;
						//if only one donor, select it
						if (orgDt.Rows.Count == 1)
						{ DonorList.SelectedIndex = 0 ;}
					}
					else
					{
						MatchLabel.Text = "No Donors match your criteria, Press 'Add' to create new Donor!" ;
						MatchLabel.Visible = true ;
					}
					orgDs.Dispose() ;
					orgDt.Dispose() ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donor List: " + err.Message) ;}
		
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.NameButton.Click += new System.EventHandler(this.NameButton_Click);
			this.AffiliationButton.Click += new System.EventHandler(this.AffiliationButton_Click);
			this.OrganizationButton.Click += new System.EventHandler(this.OrganizationButton_Click);
			this.ChooseButton.Click += new System.EventHandler(this.ChooseButton_Click);
			this.AddButton.Click += new System.EventHandler(this.AddButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
