using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Donations;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for DonorChooser.
	/// </summary>
	public class DonorChooser : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;


		const string donationEmptyText = "No Donations to list" ;
		protected System.Web.UI.WebControls.Button AddButton;
		protected System.Web.UI.WebControls.Button ResetButton;
		protected System.Web.UI.WebControls.Button SearchButton;
		protected System.Web.UI.WebControls.TextBox SearchText;
		protected System.Web.UI.WebControls.DropDownList SearchOptionList;
		protected System.Web.UI.WebControls.Panel SearchPanel;
		protected System.Web.UI.WebControls.ImageButton LAST;
		protected System.Web.UI.WebControls.ImageButton Next;
		protected System.Web.UI.WebControls.Label PageStats;
		protected System.Web.UI.WebControls.ImageButton Previous;
		protected System.Web.UI.WebControls.ImageButton FIRST;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate BeginDate;
		protected System.Web.UI.WebControls.Panel PagerPanel;
		protected System.Web.UI.WebControls.Label ForLabel;
		protected System.Web.UI.WebControls.Label NoListLabel;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate EndDate;
		protected System.Web.UI.WebControls.Label FromLabel;
		protected System.Web.UI.WebControls.Label ToLabel;
		protected System.Web.UI.WebControls.DataGrid DonationGrid;

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Add|Edit Donation"))
				{
					if (!Page.IsPostBack)
					{
						//get current station, must have, and use in selecting organizations
						int siteId = VtkPageHeader1.DivSelectedId ;
						DateTime donDate = DateTime.Today ;

						//set year list
						BeginDate.YearListBegin = 2002 ;
						BeginDate.YearListEnd = DateTime.Now.Year ;
						BeginDate.InitializeControl() ;
						BeginDate.Date = donDate ;

						EndDate.YearListBegin = 2002 ;
						EndDate.YearListEnd = DateTime.Now.Year ;
						EndDate.InitializeControl() ;
						EndDate.Date = donDate ;

						//get list of donations
						Reset() ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Donations: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Donations: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Donations: " + err.Message) ;}
		}

		private void UpdateDonationGrid()
		{
			//bind to grid: [1]=Donation Id, [2]=Donor Id
			DataSet dsDon ;
			DataTable dtDon ;
			string displayName = string.Empty ;
			string sText = SearchText.Text ;
			string sOption = SearchOptionList.SelectedItem.Value ;
			int siteId = VtkPageHeader1.DivSelectedId ;
			string error = CheckFields(sOption) ;
			if (error != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
			else
			{
				//'-select-' is the default, works like LastName without any text to search on.
				if (sOption == "none")
				{
					sText = string.Empty ;
					sOption = "LastName" ;
				}
				if (sOption == "DonationDate")
				{
//					dsDon = Vha.Vtk.Donations.Donation.GetQuickListBy_StationId_DonationDate(siteId, BeginDate.Date) ;
//					dtDon = dsDon.Tables["GetQuickListBy_StationId_DonationDate"] ;
					//Changed the Donation search option for a given date to 
					//a given date range.

					dsDon = Vha.Vtk.Donations.Donation.GetQuickListBy_StationId_BeginDate_EndDate(siteId, BeginDate.Date, EndDate.Date) ;
					dtDon = dsDon.Tables["GetQuickListBy_StationId_BeginDate_EndDate"] ;

				}
				else if (sOption == "DonationValue")
				{
					dsDon = Vha.Vtk.Donations.Donation.GetQuickListBy_StationId(siteId) ;
					dsDon.Tables["GetQuickListBy_StationId"].DefaultView.RowFilter =  sOption + " = " + Convert.ToDecimal(sText) ;
					dtDon = dsDon.Tables["GetQuickListBy_StationId"] ;
				}
				else
				{
					dsDon = Vha.Vtk.Donations.Donation.GetQuickListBy_StationId(siteId) ;
					if (sText != string.Empty)
					{ dsDon.Tables["GetQuickListBy_StationId"].DefaultView.RowFilter =  sOption + " LIKE '" + sText + "*'" ;}
					else
					{ dsDon.Tables["GetQuickListBy_StationId"].DefaultView.Sort = sOption ;}
					dtDon = dsDon.Tables["GetQuickListBy_StationId"] ;
				}

				//create a new column for display name
				dtDon.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;

				if (dtDon.Rows.Count > 0)
				{
					//loop and build string for the new column, DisplayName
					foreach (DataRow dr in dtDon.Rows)
					{
						displayName = String.Copy(dr["LastName"] + ", " + dr["FirstName"]) ;
						//Donor Type: 1=Individual, 2=Ind&Org, 3=Ind&Affil, 4=Organization, 5=Affiliate
						switch (dr["DonorTypeFK"].ToString())
						{
							case "2":
								displayName = displayName + " Org: " + dr["OrganizationName"] + "(" + dr["OrganizationCode"] + ")" ;
								break ;
							case "3":
								displayName = displayName + " Affl: " + dr["DonorAffiliation"] ;
								break ;
							case "4":
								displayName = dr["OrganizationName"] + "(" + dr["OrganizationCode"] + ")" ;
								break ;
							case "5":
								displayName = dr["DonorAffiliation"].ToString() ;
								break ;
							default:
								break ;
						}
						dr["DisplayName"] = displayName ;
						NoListLabel.Visible = false ;
					}
				}
				else
				{ NoListLabel.Visible = true ;}
				dtDon.DefaultView.Sort = "DisplayName" ;
				DonationGrid.DataSource = dtDon ;
				DonationGrid.DataBind() ;
				SetPagerStats();
				dsDon.Dispose() ;
				dtDon.Dispose() ;
			}
		}

		private void Reset()
		{
			//reset search fields
			SearchText.Text = string.Empty ;
			SearchOptionList.SelectedIndex = 0 ;
			DonationGrid.CurrentPageIndex = 0;
			BeginDate.Date = DateTime.Today ;
			EndDate.Date = DateTime.Today ;
			UpdateDonationGrid() ;
			BeginDate.Visible = false ;
			EndDate.Visible = false;
			FromLabel.Visible = false;
			ToLabel.Visible = false;
			SearchText.Visible = false ;
			ForLabel.Visible = false ;
		}

		private string CheckFields(string option)
		{
			//check that search fields exist
			string errorMsg = string.Empty ;
			if (option == "DonationDate")
			{
				if (BeginDate.Date == DateTime.MinValue || EndDate.Date == DateTime.MinValue)
				{ errorMsg = "Sort date is invalid." ;}
				else if (System.DateTime.Compare(BeginDate.Date, EndDate.Date) > 0 )
				{ errorMsg = "End date must be greater than the Begin date." ;}


			}
			else if (option != "none")
			{
				if (SearchText.Text == string.Empty)
				{ errorMsg = "Sort text is invalid." ;}
			}
			return errorMsg ;
		}

		private void DonationGridEdit_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			string donationId ;
			try
			{
				//get information from grid
				donationId = e.Item.Cells[1].Text.ToString() ;
				//build url string to navigate to DonorEdit.aspx, add query strings
				StringBuilder sb = new StringBuilder("DonationEdit.aspx") ;
				sb.Append("?") ;
				//add division
				sb.Append(VtkPageHeader.GetURLParameterString()) ;
				sb.Append("=") ;
				sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
				//add donation id
				sb.Append("&donationId=") ;
				sb.Append(donationId) ;
				//add donor id and name is null, donor exist and referenced in donation
				sb.Append("&donorId=&donorName=") ;
				//goto new page
				Response.Redirect(sb.ToString()) ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation Record: " + err.Message) ;}
		}

		private void DonationGridAdd_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			string donorId ;
			try
			{
				//get information from grid
				donorId = e.Item.Cells[2].Text.ToString() ;
				//build url string to navigate to DonorEdit.aspx, add query strings
				StringBuilder sb = new StringBuilder("DonationEdit.aspx") ;
				sb.Append("?") ;
				//add division
				sb.Append(VtkPageHeader.GetURLParameterString()) ;
				sb.Append("=") ;
				sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
				//add donation id of 'new'
				sb.Append("&donationId=new") ;
				//add donor id and name
				sb.Append("&donorId=") ;
				sb.Append(donorId) ;
				sb.Append("&donorName=") ;
				//goto new page
				Response.Redirect(sb.ToString()) ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation Record: " + err.Message) ;}
		
		}

		private void SearchOptionList_Click(object sender, System.EventArgs e)
		{
			string option = SearchOptionList.SelectedItem.Value ;
			if (option == "DonationDate")
			{
				BeginDate.Visible = true ;
				EndDate.Visible=true;
				FromLabel.Visible=true;
				ToLabel.Visible=true;
				SearchText.Visible = false ;
				ForLabel.Visible = false ;
			}
			else if (option == "none")
			{
				BeginDate.Visible = false ;
				EndDate.Visible=false;
				FromLabel.Visible=false;
				ToLabel.Visible=false;
				SearchText.Visible = false ;
				ForLabel.Visible = false ;
			}
			else
			{
				BeginDate.Visible = false ;
				EndDate.Visible=false;
				FromLabel.Visible=false;
				ToLabel.Visible=false;
				SearchText.Visible = true ;
				ForLabel.Visible = true ;
			}
			SearchText.Text = string.Empty ;
		}

		private void AddButton_Click(object sender, System.EventArgs e)
		{
			//build url string to navigate to DonorEdit.aspx, add query strings
			StringBuilder sb = new StringBuilder("DonationEdit.aspx") ;
			//add division
			sb.Append("?StationId=") ;
			sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
			//add donation 'new'
			sb.Append("&donationId=new") ;
			//add donor 'new'
			sb.Append("&donorId=new") ;
			//add donor name, begins with donor type(1=individual,2=organization,3=affiliation)
			sb.Append("&donorName=") ;
			//navigate to new volunteer: StationId is the Host station for games
			Response.Redirect(sb.ToString()) ;
		}

		private void SearchButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				DonationGrid.CurrentPageIndex = 0;
				UpdateDonationGrid() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + err.Message) ;}
		}

		private void ResetButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				Reset() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + err.Message) ;}
		}

		#region Paging Data

		private void PageGrid(object obj, DataGridPageChangedEventArgs e)
		{
			DonationGrid.CurrentPageIndex = 0;
			UpdateDonationGrid() ;
		}

		private void SetPagerStats()
		{
			int currentPageIndex = DonationGrid.CurrentPageIndex + 1;
			int pageCount = DonationGrid.PageCount;

			PageStats.Text = "Page " + currentPageIndex.ToString() + " of " + pageCount.ToString();
		}

		private void Pager_Click(object sender, System.Web.UI.ImageClickEventArgs e)
		{			
			ImageButton objSender = (ImageButton)sender;
			switch(objSender.CommandArgument)
			{
				case "PREV":
					if(DonationGrid.CurrentPageIndex > 0)
						DonationGrid.CurrentPageIndex --;
					break;
				case "NEXT":
					if(DonationGrid.CurrentPageIndex < (DonationGrid.PageCount - 1))
						DonationGrid.CurrentPageIndex ++;
					break;
				case "FIRST":
					DonationGrid.CurrentPageIndex = 0;
					break;
				case "LAST":					
					DonationGrid.CurrentPageIndex = DonationGrid.PageCount - 1;
					break;
			}
			UpdateDonationGrid() ;
		}
		#endregion

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.SearchOptionList.SelectedIndexChanged += new System.EventHandler(this.SearchOptionList_Click);
			this.SearchButton.Click += new System.EventHandler(this.SearchButton_Click);
			this.ResetButton.Click += new System.EventHandler(this.ResetButton_Click);
			this.DonationGrid.PageIndexChanged += new System.Web.UI.WebControls.DataGridPageChangedEventHandler(this.PageGrid);
			this.DonationGrid.CancelCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.DonationGridAdd_Click);
			this.DonationGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.DonationGridEdit_Click);
			this.FIRST.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.Previous.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.Next.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.LAST.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.AddButton.Click += new System.EventHandler(this.AddButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


	}
}
