using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for ProgramsEdit.
	/// </summary>
	public class ProgramsEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox CodeText;
		protected System.Web.UI.WebControls.TextBox NameText;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.DropDownList ProgramList;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Label ProgramIdLabel;
		protected System.Web.UI.WebControls.Label CodeLabel;
		protected System.Web.UI.WebControls.Label NameLabel;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.RangeValidator RangeValidator1;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Programs"))
				{
					if (!Page.IsPostBack)
					{
						int siteId = VtkPageHeader1.DivSelectedId ;
						GetProgramList(siteId) ;
						//setup for a new entry
						SetFields("L") ;
						ProgramIdLabel.Text = "New" ;
						PostButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		protected void SetFields(string scope)
		{
			//set text fields to empty
			CodeText.Text = string.Empty ;
			NameText.Text = string.Empty ;
			//set label fields to empty
			ProgramIdLabel.Text = string.Empty ;
			CodeLabel.Text = string.Empty ;
			NameLabel.Text = string.Empty ;
			//clear variables
			ViewState["Id"] = string.Empty ;
			ViewState["Version"] = string.Empty ;

			//scope is national, labels are visible
			if (scope == "N")
			{
				//set labels to visible
				CodeLabel.Visible = true ;
				NameLabel.Visible = true ;
				//set text to invisible
				CodeText.Visible = false ;
				NameText.Visible = false ;
			}
			else
			{
				//scope is local, label fields are visible
				//set labels to invisible
				CodeLabel.Visible = false ;
				NameLabel.Visible = false ;
				//set text to invisible
				CodeText.Visible = true ;
				NameText.Visible = true ;
			}
		}

		private void GetProgramList(int siteId)
		{
			try
			{
				//get program list
				DataSet pds = Vha.Vtk.ServicesDirectory.Programs.GetVoluntaryPrograms(siteId, VtkUtility.GetAppCon()) ;
				pds.Tables["ProgramsList"].DefaultView.Sort = "ProgramName" ;
				DataTable pdt = pds.Tables["ProgramsList"] ;
				pdt.Columns.Add("ProgramAndCode", System.Type.GetType("System.String")) ;

				//loop and build string for the new column, CodeAndName
				foreach (DataRow dr in pdt.Rows)
					{
						string s = String.Copy(dr["ProgramName"] + " (" + dr["ProgramCode"].ToString() + ") ") ;
						dr["ProgramAndCode"] = s ;
					}

				//add the first row, uses Rows.InsertAt(
				DataRow pdr = pdt.NewRow() ;
				pdr["ProgramAndCode"] = " -Select Program- " ;
				pdr["ProgramId"] = -1 ;
				pdt.Rows.InsertAt(pdr, 0) ;

				//define columns in list box
				ProgramList.DataTextField = "ProgramAndCode" ;
				ProgramList.DataValueField = "ProgramId" ;
				ProgramList.DataSource = pdt ;
				ProgramList.DataBind() ;
				pds.Dispose() ;
				pdt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program List: " + err.Message) ;}
		}

		private string MissingFields()
		{
			bool flag = false ;
			string fields = string.Empty ;
			if (CodeText.Text == string.Empty)
			{
				fields = "Code" ;
				flag = true ;
			}
			if (NameText.Text == string.Empty)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Program Name" ;
			}

			return fields ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//pScope will be N(ational) or L(ocal)
			string pScope ;
			//check that a program was selected
			if (ProgramList.SelectedIndex > 0)
			{
				//get selected program
				string pid = ProgramList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save id and version
					Vha.Vtk.ServicesDirectory.Programs phdl = new Vha.Vtk.ServicesDirectory.Programs(Convert.ToInt32(pid), VtkUtility.GetAppCon()) ;
					//get scope and clear fields
					pScope = phdl.Scope.ToString() ;
					SetFields(pScope) ;
					ViewState["Id"] = phdl.ID ;
					ViewState["Version"] = phdl.Version.ToString() ;
					ProgramIdLabel.Text = phdl.ID.ToString() ;
					if (pScope == "N")
					{
						//scope is national, display only
						//populate label fields
						CodeLabel.Text = phdl.Code.ToString() ;
						NameLabel.Text = phdl.ProgramName.ToString() ;
						//disable post button
						PostButton.Enabled = false ;
					}
					else
					{
						//scope is local, edit
						//set text fields to values
						CodeText.Text = phdl.Code.ToString() ;
						NameText.Text = phdl.ProgramName ;
						//enable post button
						PostButton.Enabled = true ;
					}
					phdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program Record: " + err.Message) ;}
			}
			else
			{
				SetFields("L") ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Program to Edit") ;
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			//this button_click is no longer called, The button has been replace with a client side button
			//clear the program list
			ProgramList.SelectedIndex = 0 ;
			SetFields("L") ;
			//set id label
			ProgramIdLabel.Text = "New" ;
			PostButton.Enabled = true ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			string programCode = CodeText.Text ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following field(s) are Required: " + missingdata) ;}
			else
			{
				bool versionOk = true ;
				int siteId = VtkPageHeader1.DivSelectedId ;
				try
				{
					//check that code 3 integers
					if ((!Regex.IsMatch(programCode, @"^\d{3}") || (Convert.ToInt32(programCode) < 100)))
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Invalid Code, must be 3 digits!") ;}
					else
					{
						//define handle
						Vha.Vtk.ServicesDirectory.Programs phdl ;
						//check if new or existing record
						if (ViewState["Id"].ToString() != string.Empty)
						{
							string pid = ViewState["Id"].ToString() ;
							phdl = new Vha.Vtk.ServicesDirectory.Programs(Convert.ToInt32(pid), VtkUtility.GetAppCon()) ;
							//check version
							if (ViewState["Version"].ToString() != phdl.Version.ToString())
							{
								VtkUtility.ErrMsgAdd(ErrorMessage, "Current Program record has changed while you were editing, Please press EXIT and start over. ") ;
								versionOk = false ;
							}
						}
						else
						{
							//new record
							phdl = Vha.Vtk.ServicesDirectory.Programs.AddRecord(VtkUtility.GetAppCon()) ;
						}
						if (versionOk)
						{
							//file fields
							phdl.Code = Convert.ToInt32(programCode) ;
							phdl.ProgramName = NameText.Text ;
							phdl.Scope = "L" ;
							phdl.InstitutionId = siteId ;
							//save & close
							phdl.Save() ;
							phdl.Dispose() ;
							//update confirmation message
							ConfirmationMessage.Text = "Record Posted!" ;
							//update Organization List
							GetProgramList(siteId) ;
							SetFields("L") ;
						}
						//setup for a new entry
						ProgramIdLabel.Text = "New" ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Program Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Program Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Program Record: " + err.Message) ;}
			}
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
		Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
