using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;
using System.Text;

using Vha.Vtk.WebControlLibrary;
using VTK.Utility;
using Vha.Vtk.Kernel.Data.SystemTables;
using Vha.Vtk.Common;
using Vha.Vtk.TimeKeeping;
using Vha.Vtk.Kernel.Common;
using Vha.Vss.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for UserManagement.
	/// </summary>
	public class UserManagement : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button DeleteButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.DataGrid RolesDataGrid;
		protected System.Web.UI.WebControls.DropDownList StationList;
		protected System.Web.UI.WebControls.TextBox EMailText;
		protected System.Web.UI.WebControls.TextBox NTUserNameText;
		protected System.Web.UI.WebControls.TextBox MiddleNameText;
		protected System.Web.UI.WebControls.TextBox FirstNameText;
		protected System.Web.UI.WebControls.TextBox LastNameText;
		protected System.Web.UI.WebControls.Label RecordLabel;
		protected System.Web.UI.WebControls.DropDownList UserList;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label StationLabel;
		protected System.Web.UI.WebControls.Label PrimaryStationLabel;
		protected System.Web.UI.WebControls.Label LastNameLabel;
		protected System.Web.UI.WebControls.Label FirstNameLabel;
		protected System.Web.UI.WebControls.Label MiddleNameLabel;
		protected System.Web.UI.WebControls.Label NTUserNameLabel;
		protected System.Web.UI.WebControls.Label EMailLabel;
		protected System.Web.UI.WebControls.ListBox CurrentRoleList;
		protected System.Web.UI.WebControls.Button AddRolesButton;
		protected System.Web.UI.WebControls.ListBox RoleList;
		protected System.Web.UI.WebControls.Button RemoveRolesButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("User Management")) 
				{
					if (!Page.IsPostBack)
					{
						GetUserList() ;
						GetStationList() ;
						GetRoleList() ;
						ClearFields() ;
						StationLabel.Text = VtkPageHeader1.DivSelectedName ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{
					//user doesn't have access to page
					Response.Redirect("/Vtk/Welcome.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading this page: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading this page: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading this page: " + err.Message) ;}
		}

		private void GetUserList() 
		{
			try 
			{
				int usersCount = 0;
				NameObjectCollection usrList = new NameObjectCollection();
				NameObjectCollection userRec = new NameObjectCollection();

//				Commented by Sachy 10.28.03. Dataset is mannually populated from the NameObjectCollection
//				object returned by the GetQuickDRList. DR here states that this method in the BL
//				internally uses DataReader object instead of Dataset.
//				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.User.GetQuickList();
//				DataTable dt = ds.Tables["UserList"];

				usrList  = Vha.Vtk.Kernel.Data.SystemTables.User.GetQuickDRList();
				DataTable dtUser = new DataTable("UserList");
				//DataSet ds = new DataSet("Users");
				DataColumn dcNew;
				DataRow drUser;
				// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
				dcNew= new DataColumn();
				dcNew.DataType = System.Type.GetType("System.Int32");
				dcNew.ColumnName = "Id";
				dtUser.Columns.Add(dcNew);

				dcNew= new DataColumn();
				dcNew.DataType  = typeof(string);
				dcNew.MaxLength = 120;
				dcNew.ColumnName = "FullNameForReports";
				dtUser.Columns.Add(dcNew);

				usersCount = usrList.Count;
				int intCnt;
				for (intCnt=1; intCnt <= usersCount; intCnt++)
				{
					userRec = (NameObjectCollection)usrList.Get(intCnt-1);
					if (userRec.Count > 0)
					{
						drUser = dtUser.NewRow();
						drUser["Id"] = (Int32)userRec.Get("Column1");
						drUser["FullNameForReports"] = (string)userRec.Get("Column2");

						dtUser.Rows.Add(drUser);
					}
				}

				usrList.Dispose();
				userRec.Dispose();

				//ds.Tables.Add(dtUser);

				DataView dv = dtUser.DefaultView;
				//dv.Sort = "LowercaseNameForDisplay ASC";
				UserList.DataSource=dv;
				UserList.DataTextField="FullNameForReports";
				UserList.DataValueField="Id";
				UserList.DataBind();
				UserList.Items.Insert(0,new ListItem(" - select user - ","-1"));
				dtUser.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading the User List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading the User List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the User List: " + err.Message) ;}
		}

		private void GetStationList()
		{
			try
			{
				int InstCount = 0;
				NameObjectCollection InstList = new NameObjectCollection();
				NameObjectCollection InstRec = new NameObjectCollection();

//				Commented by Sachy 10.28.03. Dataset is mannually populated from the NameObjectCollection
//				object returned by the GetQuickDRList. DR here states that this method in the BL
//				internally uses DataReader object instead of Dataset.

				//get station list, NEED TO EXCLUDE GAMES?????
//				DataSet ids = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickList();
//				ids.Tables["InstitutionList"].DefaultView.Sort = "DisplayName ASC" ;
//				DataTable idt = ids.Tables["InstitutionList"] ;
				//add the first row, uses Rows.InsertAt(

				InstList  = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickDRList();
							//Vha.Vtk.Kernel.Data.SystemTables.Inst.GetQuickDRList();
				DataTable dtInst = new DataTable("InstitutionList");
				DataColumn dcNew;
				DataRow drInst;
				// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
				dcNew= new DataColumn();
				dcNew.DataType = System.Type.GetType("System.Int32");
				dcNew.ColumnName = "Id";
				dtInst.Columns.Add(dcNew);

				dcNew= new DataColumn();
				dcNew.DataType  = typeof(string);
				dcNew.MaxLength = 40;
				dcNew.ColumnName = "DisplayName";
				dtInst.Columns.Add(dcNew);

				InstCount = InstList.Count;
				int intCnt;
				for (intCnt=1; intCnt <= InstCount; intCnt++)
				{
					InstRec = (NameObjectCollection)InstList.Get(intCnt-1);
					if (InstRec.Count > 0)
					{
						drInst = dtInst.NewRow();
						drInst["Id"] = (Int32)InstRec.Get("Column1");
						drInst["DisplayName"] = (string)InstRec.Get("Column2");

						dtInst.Rows.Add(drInst);
					}
				}

				InstList.Dispose();
				InstRec.Dispose();

				dtInst.DefaultView.Sort = "DisplayName ASC" ;

				drInst = dtInst.NewRow() ;
				drInst["DisplayName"] = " -Select Station- " ;
				drInst["ID"] = -1 ;
				dtInst.Rows.InsertAt(drInst, 0) ;
				//define columns in list box
				StationList.DataTextField = "DisplayName" ;
				StationList.DataValueField = "ID" ;
				StationList.DataSource = dtInst ;
				StationList.DataBind() ;
				//ids.Dispose() ;
				dtInst.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading the Station List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading the Station List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + err.Message) ;}
		}

		private void GetRoleList()
		{
			try
			{
				string siteNumber ;
				string pattern ;
				string roleName ;
				int siteId = VtkPageHeader1.DivSelectedId ;
				//get site station number
				Vha.Vtk.Kernel.Data.SystemTables.Institution siteusr = new Institution(siteId, VtkUtility.GetAppCon()) ;
				siteNumber = siteusr.StationNumber ;
				siteusr.Dispose() ;
				//set pattern for regular expression
				switch (siteNumber)
				{
					case "101":
						//site 101 is central office: VtkCOUser, VtkCOAdministrator
						pattern = "CO{1}" ;
						break ;
					case "101EMC":
						//site 101EMC is the EMC: VtkNationalAdministrator
						pattern = "NationalAdministrator{1}" ;
						break ;
					case "101WSC":
						pattern = "Games{1}" ;
						break ;
					case "101WCG":
						pattern = "Games{1}" ;
						break ;
					case "101GAG":
						pattern = "Games{1}" ;
						break ;
					case "101CAF":
						pattern = "Games{1}" ;
						break ;
					default:
						//default is all other sites: VtkSiteUser, VtkSiteManager, VtkSiteUserAdministrator
						pattern = "Site{1}" ;
						break ;
				}

				//DataSet dsrl = Vha.Vtk.Kernel.Data.SystemTables.Role.GetQuickList() ;
				//dsrl.Tables["RoleList"].DefaultView.Sort = "Id ASC" ;
				//DataTable dtrl = dsrl.Tables["RoleList"] ;

				int RolesCount = 0;
				NameObjectCollection RolesList = new NameObjectCollection();
				NameObjectCollection RolesRec = new NameObjectCollection();

				RolesList  = Vha.Vtk.Kernel.Data.SystemTables.Role.GetQuickDRList();
				//Vha.Vtk.Kernel.Data.SystemTables.Inst.GetQuickDRList();
				DataTable dtRoles = new DataTable("RoleList");
				DataColumn dcNew;
				DataRow drRoles;
				// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
				dcNew= new DataColumn();
				dcNew.DataType = System.Type.GetType("System.Int32");
				dcNew.ColumnName = "Id";
				dtRoles.Columns.Add(dcNew);

				dcNew= new DataColumn();
				dcNew.DataType  = typeof(string);
				dcNew.MaxLength = 40;
				dcNew.ColumnName = "RoleName";
				dtRoles.Columns.Add(dcNew);

				RolesCount = RolesList.Count;
				int intCnt;
				for (intCnt=1; intCnt <= RolesCount; intCnt++)
				{
					RolesRec = (NameObjectCollection)RolesList.Get(intCnt-1);
					if (RolesRec.Count > 0)
					{

						roleName = (string)RolesRec.Get("Column2");
						//find site roles only
						if (Regex.IsMatch(roleName, @pattern))
						{
							drRoles = dtRoles.NewRow();

							drRoles["Id"] = (Int32)RolesRec.Get("Column1");
							drRoles["RoleName"] = (string)RolesRec.Get("Column2");

							dtRoles.Rows.Add(drRoles);
						}
					}
				}
				
				RolesList.Dispose();
				RolesRec.Dispose();

				dtRoles.DefaultView.Sort = "Id ASC" ;

				//loop and get rid of any role not for this site
//				foreach (DataRow dr in dtRoles.Rows)
//				{
//					roleName = dr["RoleName"].ToString() ;
//					//find site roles only
//					if (!Regex.IsMatch(roleName, @pattern))
//					{ dr.Delete() ;}
//				}

				RoleList.DataTextField = "RoleName" ;
				RoleList.DataValueField = "ID" ;
				RoleList.DataSource = dtRoles ;
				RoleList.DataBind() ;
				//dsrl.Dispose() ;
				dtRoles.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading the User Roles List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading the User Roles List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the User Roles List: " + err.Message) ;}
		}

		private void GetCurrentRoleList(int usrId)
		{
			try
			{
				int UrolesCount = 0;
				NameObjectCollection UrolesList = new NameObjectCollection();
				NameObjectCollection UrolesRec = new NameObjectCollection();

				//DataSet dsr = Vha.Vtk.Kernel.Data.SystemTables.UserRole.GetUserRolesAtSite(usrId, VtkPageHeader1.DivSelectedId) ;
				//DataTable dtr = dsr.Tables["UserRolesAtSite"] ;
				UrolesList  = Vha.Vtk.Kernel.Data.SystemTables.UserRole.GetUserRolesDRAtSite(usrId, VtkPageHeader1.DivSelectedId) ;
				DataTable dtUroles = new DataTable("UserRolesAtSite");
				DataColumn dcNew;
				DataRow drUroles;
				// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
				dcNew= new DataColumn();
				dcNew.DataType = System.Type.GetType("System.Int32");
				dcNew.ColumnName = "RoleId";
				dtUroles.Columns.Add(dcNew);

				dcNew= new DataColumn();
				dcNew.DataType  = typeof(string);
				dcNew.MaxLength = 40;
				dcNew.ColumnName = "RoleName";
				dtUroles.Columns.Add(dcNew);

				dcNew= new DataColumn();
				dcNew.DataType = System.Type.GetType("System.Int32");
				dcNew.ColumnName = "UserRoleId";
				dtUroles.Columns.Add(dcNew);

				UrolesCount = UrolesList.Count;
				int intCnt;
				for (intCnt=1; intCnt <= UrolesCount; intCnt++)
				{
					UrolesRec = (NameObjectCollection)UrolesList.Get(intCnt-1);
					if (UrolesRec.Count > 0)
					{
						drUroles = dtUroles.NewRow();
						drUroles["RoleId"] = (Int32)UrolesRec.Get("Column1");
						drUroles["RoleName"] = (string)UrolesRec.Get("Column2");
						drUroles["UserRoleId"] = (Int32)UrolesRec.Get("Column3");

						dtUroles.Rows.Add(drUroles);
					}
				}

				
				//define columns for list for display
				CurrentRoleList.DataTextField = "RoleName" ;
				CurrentRoleList.DataValueField = "RoleId" ;
				CurrentRoleList.DataSource = dtUroles ;
				CurrentRoleList.DataBind() ;
				//define columns for hidden grid, this is used when posting
				RolesDataGrid.DataSource = dtUroles ;
				RolesDataGrid.DataBind() ;
				//dsr.Dispose() ;
				dtUroles.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading the User Roles List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading the User Roles List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the User Roles List: " + err.Message) ;}
		}

		protected void ClearFields()
		{
			//clear variables
			ViewState["userId"] = string.Empty ;
			ViewState["userVersion"] = string.Empty ;
			ViewState["isEditable"] = "true" ;

			//set text fields to empty
			RecordLabel.Text = "NEW" ;
			LastNameText.Text = string.Empty ;
			FirstNameText.Text = string.Empty ;
			MiddleNameText.Text = string.Empty ;
			NTUserNameText.Text = string.Empty ;
			EMailText.Text = string.Empty ;
			//reset all list
			UserList.SelectedIndex = 0 ;
			RoleList.SelectedIndex = -1 ;
			//clear out the current roles list and datagrid
			CurrentRoleList.Items.Clear() ;
			DataSet ds = null ;
			RolesDataGrid.DataSource = ds ;
			RolesDataGrid.DataBind() ;
			//labels
			LastNameLabel.Text = string.Empty ;
			FirstNameLabel.Text = string.Empty ;
			MiddleNameLabel.Text = string.Empty ;
			NTUserNameLabel.Text = string.Empty ;
			EMailLabel.Text = string.Empty ;
			//set station list to current header station & make invisible
			VtkUtility.SetSelectedSingle(StationList.Items, VtkPageHeader1.DivSelectedId.ToString()) ;
			StationList.Visible = false ;
			//set primary station label and make visible
			PrimaryStationLabel.Text = VtkPageHeader1.DivSelectedName ;
			PrimaryStationLabel.Visible = true ;

			//disable buttons that are not relavent with a new entry
			DeleteButton.Enabled = false ;

			EditFields(true) ;
		}

		private void EditFields(bool local)
		{
			//local: true=can edit, false=can't edit
			LastNameText.Visible = local ;
			FirstNameText.Visible = local ;
			MiddleNameText.Visible = local ;
			NTUserNameText.Visible = local ;
			EMailText.Visible = local ;
			StationList.Visible = local ;
			LastNameLabel.Visible = !local ;
			FirstNameLabel.Visible = !local ;
			MiddleNameLabel.Visible = !local ;
			NTUserNameLabel.Visible = !local ;
			EMailLabel.Visible = !local ;
			PrimaryStationLabel.Visible = !local ;
		}

		private string MissingFields()
		{
			bool comma = false ;
			string fields = string.Empty ;
			if (LastNameText.Text == string.Empty)
			{
				fields = "Last Name" ;
				comma = true ;
			}
			if (FirstNameText.Text == string.Empty)
			{
				if (comma)
				{ fields = fields + ", " ;}
				fields = fields + "First Name" ;
				comma = true ;
			}
			if (NTUserNameText.Text == string.Empty)
			{
				if (comma)
				{ fields = fields + ", " ;}
				fields = fields + "NT User Name" ;
				comma = true ;
			}
			if (StationList.SelectedIndex < 0)
			{
				if (comma)
				{ fields = fields + ", " ;}
				fields = fields + "Primary Station" ;
				comma = true ;
			}
			return fields ;
		}

		private void AddUserRole(int usrId, int roleId)
		{
			//add role to user
			try
			{
				//create handle for role
				Vha.Vtk.Kernel.Data.SystemTables.UserRole rolhdl = Vha.Vtk.Kernel.Data.SystemTables.UserRole.AddRecord(VtkUtility.GetAppCon()) ;
				rolhdl.RoleId = roleId ;
				rolhdl.InstitutionId = VtkPageHeader1.DivSelectedId ;
				rolhdl.UserId = usrId ;
				rolhdl.Save() ;
				rolhdl.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + err.Message) ;}
		}

		private void DeleteUserRole(int usrId, int rowId)
		{
			//delete row from datagrid
			try
			{
				//create handle for role
				Vha.Vtk.Kernel.Data.SystemTables.UserRole rolhdl = new Vha.Vtk.Kernel.Data.SystemTables.UserRole(rowId, VtkUtility.GetAppCon()) ;
				rolhdl.Delete() ;
				rolhdl.Save() ;
				rolhdl.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + err.Message) ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			Vha.Vtk.Kernel.Data.SystemTables.User usrhdl ;
			int usrId = 0 ;
			bool versionOk = true ;
			string roleId ;
			bool roleOk ;
			try
			{
				PostButton.Enabled = false ;
				if (ViewState["userId"].ToString() != string.Empty)
				{ usrId = Convert.ToInt32(ViewState["userId"].ToString()) ;}
				//check if we can edit user information, can't edit that don't have a primary station of this site
				if (Convert.ToBoolean(ViewState["isEditable"]))
				{
					//post to User table
					string missingdata = MissingFields() ;
					if (missingdata != string.Empty)
					{
						//missing data, nothing posted
						VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + missingdata) ;
						//reset usrId so no roles are not posted
						usrId = 0 ;
					}
					else
					{
						//check if new or existing record
						if (usrId > 0)
						{
							usrhdl = new Vha.Vtk.Kernel.Data.SystemTables.User(usrId, VtkUtility.GetAppCon()) ;
							//check version
							if (ViewState["userVersion"].ToString() != usrhdl.Version.ToString())
							{
								VtkUtility.ErrMsgAdd(ErrorMessage, "Current Program record has changed while you were editing, Please press EXIT and start over. ") ;
								versionOk = false ;
							}
						}
						else
						{
							//new record
							usrhdl = Vha.Vtk.Kernel.Data.SystemTables.User.AddRecord(VtkUtility.GetAppCon()) ;
						}
						if (versionOk)
						{
							usrhdl.LastName = LastNameText.Text  ;
							usrhdl.FirstName = FirstNameText.Text ;
							usrhdl.MiddleName = MiddleNameText.Text ;
							usrhdl.NtUserName = NTUserNameText.Text ;
							usrhdl.EMailAddress = EMailText.Text ;
							usrhdl.PrimaryInstitution = Convert.ToInt32(StationList.SelectedItem.Value.ToString()) ;

							usrhdl.Save() ;
							//need to reset usrId, if new record
							usrId = usrhdl.ID ;
							usrhdl.Dispose() ;
						}
					}
				}

				if (usrId > 0)
				{
					//post roles into UserRole table
					//check roles, loop thru current list and add if not in grid
					for (int i=0; i<CurrentRoleList.Items.Count; i++)
					{
						roleId = CurrentRoleList.Items[i].Value ;
						//true mean add
						roleOk = true ;
						//loop thru all roles user has, check if role already exists
						foreach (DataGridItem dgi in RolesDataGrid.Items)
						{
							if (dgi.Cells[1].Text == roleId)
							{
								//already exist
								roleOk = false ;
								break ;
							}
						}
						if (roleOk)
						{ AddUserRole(usrId, Convert.ToInt32(roleId)) ;}
					}
					//check user roles, loop thru and delete if not in list
					foreach (DataGridItem dgi in RolesDataGrid.Items)
					{
						roleId = dgi.Cells[1].Text ;
						roleOk = true ;
						//loop thru current list, if not there then delete
						for (int i=0; i<CurrentRoleList.Items.Count; i++)
						{
							if (CurrentRoleList.Items[i].Value == roleId)
							{
								//already exist
								roleOk = false ;
								break ;
							}
						}
						if (roleOk)
						{ DeleteUserRole(usrId, Convert.ToInt32(dgi.Cells[0].Text)) ;}
					}
					GetUserList() ;
					ClearFields() ;
					//update confirmation message
					ConfirmationMessage.Text = "Record Posted!" ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting User record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting User record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting User record: " + err.Message) ;}
			finally
			{ PostButton.Enabled = true ;}
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			int usrId ;
			string usrNt ;
			//must be editing a user and be editable inorder to delete
			if (ViewState["userId"].ToString() != string.Empty && Convert.ToBoolean(ViewState["isEditable"]))
			{
				try
				{
					//can't have any roles
					if (CurrentRoleList.Items.Count > 0)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "This User cannot be deleted, You need to delete this User's roles first!") ;}
					else
					{
						usrId = Convert.ToInt32(ViewState["userId"].ToString()) ;
						//check if we need to delete roles for this site
						if (RolesDataGrid.Items.Count > 0)
						{
							foreach (DataGridItem dgi in RolesDataGrid.Items)
							{ DeleteUserRole(usrId, Convert.ToInt32(dgi.Cells[0].Text)) ;}
						}

						//create handle for user
						Vha.Vtk.Kernel.Data.SystemTables.User usrhdl = new Vha.Vtk.Kernel.Data.SystemTables.User(usrId, VtkUtility.GetAppCon()) ;
						usrNt = usrhdl.NtUserName ;

						//check for roles at other sites
						DataSet uds = Vha.Vtk.Kernel.Data.SystemTables.UserRole.GetUserRoleAtSites(usrNt, VtkUtility.GetAppCon()) ;
						if (uds.Tables["UserRolesAtSites"].Rows.Count > 0)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "This User cannot be deleted, They have roles at other sites!") ;}
						else
						{
							//delete user record
							usrhdl.Delete() ;
							usrhdl.Save() ;
							usrhdl.Dispose() ;

							ClearFields() ;
							GetUserList() ;
							//update confirmation message
							ConfirmationMessage.Text = "Role Deleted!" ;
						}
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting User Role: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a User to delete!") ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			ClearFields() ;
		}

		private void UserList_Click(object sender, System.EventArgs e)
		{
			//false = use labels fields, true = use text fields
			bool isEditable = false ;
			string primaryStation = string.Empty ;
			if (UserList.SelectedIndex > 0)
			{
				try
				{
					int usrId = Convert.ToInt32(UserList.SelectedItem.Value.ToString()) ;
					ClearFields() ;
					//create handle and save Id and version
					Vha.Vtk.Kernel.Data.SystemTables.User usrhdl = new Vha.Vtk.Kernel.Data.SystemTables.User(usrId, VtkUtility.GetAppCon()) ;
					ViewState["userId"] = usrhdl.ID ;
					ViewState["userVersion"] = usrhdl.Version ;
					isEditable = (usrhdl.PrimaryInstitution == VtkPageHeader1.DivSelectedId) ;
					ViewState["isEditable"] = isEditable ;

					//get primary station name
					Vha.Vtk.Kernel.Data.SystemTables.Institution sitehdl = new Institution(usrhdl.PrimaryInstitution, VtkUtility.GetAppCon()) ;
					primaryStation = sitehdl.NameOfInstitution ;
					sitehdl.Dispose() ;

					RecordLabel.Text = usrhdl.ID.ToString() ;

					if (isEditable)
					{
						LastNameText.Text = usrhdl.LastName ;
						FirstNameText.Text = usrhdl.FirstName ;
						MiddleNameText.Text = usrhdl.MiddleName ;
						NTUserNameText.Text = usrhdl.NtUserName ;
						EMailText.Text = usrhdl.EMailAddress ;
						VtkUtility.SetSelectedSingle(StationList.Items, usrhdl.PrimaryInstitution.ToString()) ;
						//can only delete if user is at your site
						DeleteButton.Enabled = true ;
					}
					else
					{
						EditFields(false) ;
						LastNameLabel.Text = usrhdl.LastName ;
						FirstNameLabel.Text = usrhdl.FirstName ;
						MiddleNameLabel.Text = usrhdl.MiddleName ;
						NTUserNameLabel.Text = usrhdl.NtUserName ;
						EMailLabel.Text = usrhdl.EMailAddress ;
						PrimaryStationLabel.Text = primaryStation ;
					}
					usrhdl.Dispose() ;
					GetCurrentRoleList(usrId) ;					
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading Volunteer Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading Volunteer Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer Record: " + err.Message) ;}
			}
		}

		private void AddRolesButton_Click(object sender, System.EventArgs e)
		{
			//must select role first
			if (RoleList.SelectedIndex > -1)
			{
				bool add = true ;
				string roleId = RoleList.SelectedItem.Value ;
				//check if role is already assigned
				for (int i=0; i<CurrentRoleList.Items.Count; i++)
				{
					if (CurrentRoleList.Items[i].Value == roleId)
					{
						add = false ;
						break ;
					}
				}
				if (add)
				{
					CurrentRoleList.Items.Add(RoleList.SelectedItem) ;
					RoleList.SelectedIndex = -1 ;
					CurrentRoleList.SelectedIndex = -1 ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "User already has that Role!") ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Role to add!") ;}
		}

		private void RemoveRolesButton_Click(object sender, System.EventArgs e)
		{
			//must select role first
			if (CurrentRoleList.SelectedIndex > -1)
			{
				CurrentRoleList.Items.Remove(CurrentRoleList.SelectedItem) ;
				CurrentRoleList.SelectedIndex = -1 ;
				RoleList.SelectedIndex = -1 ;
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Role to remove!") ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.UserList.SelectedIndexChanged += new System.EventHandler(this.UserList_Click);
			this.AddRolesButton.Click += new System.EventHandler(this.AddRolesButton_Click);
			this.RemoveRolesButton.Click += new System.EventHandler(this.RemoveRolesButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.DeleteButton.Click += new System.EventHandler(this.DeleteButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
