using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for UserTitlesEdit.
	/// </summary>
	public class UserTitlesEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox DescriptionText;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.DropDownList TitleList;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.TextBox TitleText;
		protected System.Web.UI.WebControls.Label RecordIdLabel;
		protected System.Web.UI.WebControls.Label TitleLabel;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Staff Titles")) 
				{
					if (!Page.IsPostBack)
					{
						int siteId = VtkPageHeader1.DivSelectedId ;
						GetTitleList(siteId) ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + err.Message) ;}
		}

		protected void SetFields(string scope)
		{
			//set text and label fields to empty
			RecordIdLabel.Text = string.Empty ;
			TitleText.Text = string.Empty ;
			DescriptionText.Text = string.Empty ;
			TitleLabel.Text = string.Empty ;
			//clear variables
			ViewState["Id"] = string.Empty ;
			ViewState["Version"] = string.Empty ;

			//scope is national, labels are visible
			if (scope == "N")
			{
				//set labels to visible, disable description
				TitleLabel.Visible = true ;
				DescriptionText.Enabled = false ;
				//set text to invisible
				TitleText.Visible = false ;
			}
			else
			{
				//scope is local, label fields are visible
				//set labels to invisible
				TitleLabel.Visible = false ;
				DescriptionText.Enabled = true ;
				//set text to invisible
				TitleText.Visible = true ;
			}
		}

		private void GetTitleList(int siteId)
		{
			try
			{
				//get title list, IsVolChiefSupervisor is a byte: 0=false, 1=true, 2=null
				DataSet tds = Vha.Vtk.ServicesDirectory.StaffTitle.GetQuickList(siteId, 2, VtkUtility.GetAppCon()) ;
				tds.Tables["StaffTitleList"].DefaultView.Sort = "Title ASC" ;
				DataTable tdt = tds.Tables["StaffTitleList"] ;
				//add the first row, uses Rows.InsertAt(
				DataRow tdr = tdt.NewRow() ;
				tdr["Title"] = " -Select Staff Title- " ;
				tdr["Id"] = -1 ;
				tdt.Rows.InsertAt(tdr, 0) ;
				//define columns in list box
				TitleList.DataTextField = "Title" ;
				TitleList.DataValueField = "Id" ;
				TitleList.DataSource = tdt ;
				TitleList.DataBind() ;
				tds.Dispose() ;
				tdt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + err.Message) ;}
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if (TitleText.Text == string.Empty)
			{ fields = "Title " ;}

			return fields ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//tScope will be N(ational) or L(ocal)
			string tScope ;
			//check that a title was selected
			if (TitleList.SelectedIndex > 0)
			{
				//get selected title
				string tid = TitleList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save id and version
					Vha.Vtk.ServicesDirectory.StaffTitle thdl = new Vha.Vtk.ServicesDirectory.StaffTitle(Convert.ToInt32(tid), VtkUtility.GetAppCon()) ;
					//get scope and clear fields
					tScope = thdl.Scope.ToString() ;
					SetFields(tScope) ;
					ViewState["Id"] = thdl.ID ;
					ViewState["Version"] = thdl.Version.ToString() ;
					//set values in fields that don't have a counterpart
					RecordIdLabel.Text = thdl.ID.ToString() ;
					DescriptionText.Text = thdl.Description ;

					if (tScope == "N")
					{
						//scope is National, display only, populate labels
						TitleLabel.Text = thdl.Title ;
						//disable post button
						PostButton.Enabled = false ;
					}
					else
					{
						//scope is Local, edit, populate text
						TitleText.Text = thdl.Title ;
						//enable post button
						PostButton.Enabled = true ;
					}
					thdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Title List: " + err.Message) ;}
			}
			else
			{
				SetFields("L") ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Staff Title to Edit") ;
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			//clear the title list
			TitleList.SelectedIndex = 0 ;
			SetFields("L") ;
			//set id label
			RecordIdLabel.Text = "New" ;
			PostButton.Enabled = true ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + missingdata) ;}
			else
			{
				bool versionOk = true ;
				int siteId = VtkPageHeader1.DivSelectedId ;
				try
				{
					//define handle
					Vha.Vtk.ServicesDirectory.StaffTitle thdl ;
					//check if new or existing record
					if (ViewState["Id"].ToString() != string.Empty)
					{
						string tid = ViewState["Id"].ToString() ;
						thdl = new Vha.Vtk.ServicesDirectory.StaffTitle(Convert.ToInt32(tid), VtkUtility.GetAppCon()) ;
						//check version
						if (ViewState["Version"].ToString() != thdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Staff Title record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
					else
					{
						//new record
						thdl = Vha.Vtk.ServicesDirectory.StaffTitle.AddRecord(VtkUtility.GetAppCon()) ;
					}
					if (versionOk)
					{
						//file fields
						thdl.Title = TitleText.Text ;
						thdl.Description = DescriptionText.Text ;
						thdl.Scope = "L" ;
						thdl.InstitutionId = siteId ;
						//save & close
						thdl.Save() ;
						thdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update Organization List
						GetTitleList(siteId) ;
						SetFields("L") ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the record: " + err.Message) ;}
			}
		}

			private void ExitButton_Click(object sender, System.EventArgs e)
		{
		Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
					private void InitializeComponent()
					{    
						this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
						this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
						this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
						this.Load += new System.EventHandler(this.Page_Load);

					}
		#endregion

	}
}
