using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;
using System.Text.RegularExpressions;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.Kernel.Data;
using Vha.Vtk.Kernel.Data.SystemTables;
using Vha.Vtk.WebControlLibrary;
using Vha.Vss.Utility;
using VTK.Utility;
using Vha.Vtk.Games ;

namespace VTK.Games
{
	/// <summary>
	/// Summary description for GamesScheduling.
	/// </summary>
	public class GamesScheduling : System.Web.UI.Page
	{
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.DropDownList ddlHostStation;
		protected System.Web.UI.WebControls.TextBox txtStartDate;
		protected System.Web.UI.WebControls.TextBox txtEndDate;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.CompareValidator EndDateValidator;
		protected System.Web.UI.WebControls.Button btnSave;
		protected System.Web.UI.WebControls.Button btnCancel;
		protected System.Web.UI.WebControls.Label lblTitle;
		protected System.Web.UI.WebControls.RequiredFieldValidator StartDateValidator;
		protected System.Web.UI.WebControls.DataGrid GamesGrid;
		protected System.Web.UI.WebControls.Panel AddGamePanel;
		protected System.Web.UI.WebControls.Panel GamesGridPanel;

		protected int _HostStationId;
		protected DateTime _StartDate;
		protected System.Web.UI.WebControls.Button btnAdd;
		protected System.Web.UI.WebControls.DropDownList ddlGamesTypeList;

		protected DateTime _EndDate;
		private void Page_Load(object sender, System.EventArgs e)
		{
			
			try
			{
				if (VtkPageHeader1.IsDivSelected("Scheduling")) 
				{
					if(!Page.IsPostBack)
					{
						this.InitGamesGrid();
					}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
				//save the stationId on the form
				Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
			} 
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Games Scheduling: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Games Scheduling: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Games Scheduling: " + err.Message) ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			this.GamesGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.GamesGrid_Edit);
			this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
		
		#region Section: Private Event Methods
		private void btnSave_Click(object sender, System.EventArgs e)
		{
			//check Host Station and dates
			string error = CheckFields() ;
			if (error != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
			else
			{
				_StartDate = Convert.ToDateTime(txtStartDate.Text);
				_EndDate = Convert.ToDateTime(txtEndDate.Text);
				_HostStationId = Convert.ToInt32(ddlHostStation.SelectedItem.Value);
				int _GameTypeId = Convert.ToInt32(ddlGamesTypeList.SelectedItem.Value);

				if(ViewState["GamesScheduleId"] != null)
				{
					GamesSchedule gms = new GamesSchedule(Convert.ToInt32(ViewState["GamesScheduleId"]));
					gms.StartDate = _StartDate;
					gms.EndDate = _EndDate;
					gms.HostStationFk = _HostStationId;
					gms.GameTypeFk = _GameTypeId;
					gms.Save() ;
					gms.Dispose() ;
				}
				else
				{
					GamesSchedule gms = new GamesSchedule();
					GamesSchedule.AddRecord(_HostStationId, _GameTypeId, _StartDate, _EndDate);
				}
				InitGamesGrid() ;
			}

		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			this.InitGamesGrid();
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			this.InitAddGame();	
			btnSave.Text = "  Save  ";
		}

		private void GamesGrid_Edit(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{			
			//Get the Data for the selected Game Schedule
			int GamesScheduleId = Convert.ToInt32(e.Item.Cells[0].Text);
			GamesSchedule gms = new GamesSchedule(GamesScheduleId);
			this.InitAddGame(gms.StartDate.Date.ToShortDateString(), gms.EndDate.Date.ToShortDateString(), gms.HostStationFk.ToString(), gms.GameTypeFk.ToString());
			ViewState["GamesScheduleId"] = GamesScheduleId;
			//DeleteButton.Enabled = true;
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			if(ViewState["GamesScheduleId"] != null)
			{
				int grId ;
				Vha.Vtk.Games.GamesRegistration grhdl ;
				int gameId = Convert.ToInt32(ViewState["GamesScheduleId"].ToString()) ;
				//remove all registrations from this game
				DataSet dsgr = Vha.Vtk.Games.GamesRegistration.GetQuickListByGameSchedule(gameId) ;
				DataTable dtgr = dsgr.Tables["GamesRegistrationList"] ;
				foreach (DataRow dr in dtgr.Rows)
				{
					grId = Convert.ToInt32(dr["Id"].ToString()) ;
					grhdl = new Vha.Vtk.Games.GamesRegistration(grId, VtkUtility.GetAppCon()) ;
					grhdl.Delete() ;
					grhdl.Save() ;
					grhdl.Dispose() ;
				}
				dsgr.Dispose() ;
				dtgr.Dispose() ;

				//delete game
				GamesSchedule gms = new GamesSchedule(gameId);
				gms.Delete() ;
				gms.Save() ;
				gms.Dispose() ;
				InitGamesGrid() ;
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Error Deleting station, Please exit and try again!") ;}
		}

		#endregion

		#region Section: Private Methods

		private void InitAddGame()
		{
			this.InitAddGame(System.DateTime.Now.Date.ToShortDateString(), System.DateTime.Now.AddDays(7).ToShortDateString(), null, null);
			ViewState["GamesScheduleId"] = null ;
			//DeleteButton.Enabled = false ;
		}

		private void InitAddGame(string StartDate, string EndDate, string HostId, string GameTypeId)
		{
			GamesGridPanel.Visible = false;
			AddGamePanel.Visible = true;
			
			/*********************************************************************/
			/*		HostStation DropDownList Initialization						 */
			/*********************************************************************/
			//Get the DataSet of Institutions which can host games.
			DataSet ds = Institution.GetQuickList("'101','101EMC','101GAG','101WSC', '101CAF', '101WCG'");
			DataTable dt = ds.Tables["InstitutionList"];
			dt.DefaultView.Sort = "DisplayName ASC" ;

			//Set the DropDropList for the institutions.
			ddlHostStation.DataSource = dt;
			ddlHostStation.DataTextField = "DisplayName";
			ddlHostStation.DataValueField = "ID";
			ddlHostStation.DataBind();
						
			//Create the default selection.
			ddlHostStation.Items.Insert(0,new ListItem(" - Select Hosting Station - ","-1"));
						

			/*********************************************************************/
			/*		GamesType DropDownList Initialization						 */
			/*********************************************************************/
			DataSet gtds = GameType.GetQuickList();
			DataTable gtdt = gtds.Tables["GameTypeList"];
			DataView ftdv = dt.DefaultView;

			ddlGamesTypeList.DataSource = gtds;
			ddlGamesTypeList.DataTextField = "Name";
			ddlGamesTypeList.DataValueField = "ID";
			ddlGamesTypeList.DataBind();
			
			ddlGamesTypeList.Items.Insert(0, new ListItem(" - Select Game Type - ", "-1"));

			for(int i = 0; i < ddlGamesTypeList.Items.Count; i++)
			{
				if(Convert.ToInt32(ddlGamesTypeList.Items[i].Value) == Convert.ToInt32(GameTypeId))
				{
					ddlGamesTypeList.Items[i].Selected = true;
				}
			}

			//Set the default dates AND host institution if given
			txtStartDate.Text = StartDate;
			txtEndDate.Text = EndDate;
			if (HostId != null)
			{ VtkUtility.SetSelectedSingle(ddlHostStation.Items, HostId) ;}
		}
		
		private void InitGamesGrid()
		{
			//initialize ViewState
			ViewState["GamesScheduleId"] = null ;
			GamesGridPanel.Visible = true;
			AddGamePanel.Visible = false;

			DataSet gds = GamesSchedule.GetQuickList();
			DataTable gts = gds.Tables["GamesScheduleList"];
						
			GamesGrid.DataSource = 	gts.DefaultView;
			GamesGrid.DataBind();
		}

		private string CheckFields()
		{
			string errorMsg = string.Empty ;
			bool flag = false ;
			if (Convert.ToInt32(ddlHostStation.SelectedItem.Value) < 0)
			{
				errorMsg = "You must select a Host Station" ;
				flag = true ;
			}
			if (Convert.ToDateTime(txtStartDate.Text) >= Convert.ToDateTime(txtEndDate.Text))
			{
				if (flag)
				{ errorMsg = errorMsg + "and " ;}
				errorMsg = errorMsg + "Start Date must be before End Date" ;
				flag = true ;
			}
			return errorMsg ;
		}

		#endregion

	}
}
