using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Games;

namespace VTK.Games
{
	/// <summary>
	/// Summary description for GamesServiceCodeEdit.
	/// </summary>
	public class GamesServiceCodeEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.TextBox ServiceSubdivisionText;
		protected System.Web.UI.WebControls.TextBox ServiceAbbreviationText;
		protected System.Web.UI.WebControls.TextBox ServiceNameText;
		protected System.Web.UI.WebControls.TextBox ServiceIdText;
		protected System.Web.UI.WebControls.Label RecordIdLabel;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.DropDownList ServiceCodeList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Games Service Codes")) 
				{
					if (!Page.IsPostBack) 
					{
						string gameCode = GetGameCode() ;
						ViewState["GameCode"] = gameCode ;
						
						//update service list
						GetServiceList(gameCode) ;
						//setup for new record
						SetFields() ;
						RecordIdLabel.Text = "New" ;
						PostButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + err.Message) ;}
		}

		private string GetGameCode()
		{
			string code = null ;
			DataSet ds = GamesSchedule.GetQuickListByInstitutionId(VtkPageHeader1.DivSelectedId);
			DataTable dt = ds.Tables["GamesList"] ;
			//get the first record gamecode, all records should have the same code
			if (dt.Rows.Count > 0)
			{ code = dt.Rows[0]["GameCode"].ToString() ;}
			return code ;
		}

		private void GetServiceList(string gameCode)
		{
			DataSet dsGameService = Vha.Vtk.Common.Service.GetQuickListForGames(gameCode);
			DataTable dtGameService = dsGameService.Tables["GamesServiceCodes"];

			if (dtGameService.Rows.Count > 0)
			{
				dtGameService.Columns.Add("ServiceAndCode", System.Type.GetType("System.String"));
				foreach (DataRow dr in dtGameService.Rows)
				{
					string s = String.Copy("(" + dr["ServiceCode"] + ")  " + dr["Subdivision"] + " " + dr["ServiceName"]);
					dr["ServiceAndCode"] = s;
				}
				ServiceCodeList.DataTextField = "ServiceAndCode";
				ServiceCodeList.DataValueField = "ID";
				ServiceCodeList.DataSource = dtGameService;
				ServiceCodeList.DataBind();
				dtGameService.Dispose();
				ServiceCodeList.Items.Insert(0,new ListItem(" - Select Service Code - ","-1"));
			}

			
			////tracks last code of service
			//int lastCode = 599 ;
			//string code = null ;
			
			////populate list of Services, get dataset, sort by code
			//DataSet dssrv = Service.GetQuickListForGames(gameCode) ;
			////dssrv.Tables["ServiceList"].DefaultView.Sort = "Code ASC" ;
			//DataTable dtsrv = dssrv.Tables["GamesServiceCodes"] ;
			////add the first row
			//DataRow drsrv = dtsrv.NewRow() ;
			//drsrv["DisplayName"] = " -Select Service Code- " ;
			//drsrv["ID"] = 0 ;
			//dtsrv.Rows.InsertAt(drsrv, 0) ;

			////loop and find last code
			//foreach (DataRow dr in dtsrv.Rows)
			//{
			//	//check code, save the last code. It will be used to add new orgs.
			//	if (dr["ServiceCode"].ToString() != string.Empty)
			//	{
			//		code = dr["ServiceCode"].ToString().Substring(0,3) ;
			//		if (Convert.ToInt32(code) > lastCode)
			//		{ lastCode = Convert.ToInt32(code) ;}
			//	}
			//}

			////save last code
			//ViewState["lastCode"] = lastCode.ToString() ;

			////define columns in list box
			//ServiceCodeList.DataTextField = "DisplayName" ;
			//ServiceCodeList.DataValueField = "ID" ;

			////bind list box to DataTable and dispose
			//ServiceCodeList.DataSource = dtsrv ;
			//ServiceCodeList.DataBind() ;
			//dssrv.Dispose() ;
			//dtsrv.Dispose() ;

		}

		protected void SetFields()
		{
			//set text fields to empty
			ServiceIdText.Text = string.Empty ;
			ServiceNameText.Text = string.Empty ;
			ServiceAbbreviationText.Text = string.Empty ;
			ServiceSubdivisionText.Text = string.Empty ;

			//clear variables
			ViewState["serviceId"] = string.Empty ;
			ViewState["serviceVersion"] = string.Empty ;
		}

		
		private void NewButton_Click(object sender, System.EventArgs e)
		{
			ServiceCodeList.SelectedIndex = 0 ;
			//setup for new record
			SetFields() ;
			RecordIdLabel.Text = "New" ;
			PostButton.Enabled = true ;
			//last code from ServiceList add 1
			int lastCode = Convert.ToInt32(ViewState["lastCode"]) ;
			lastCode++ ;
			//can't be greater than 700
			if (lastCode < 700)
			{
				//set text values
				ServiceIdText.Text = lastCode.ToString() ;
			}
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Service was selected
			if (ServiceCodeList.SelectedIndex>0)
			{
				//get selected Service
				string srvid = ServiceCodeList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save Id and version
					//ref. Vha.Vtk.Common.Service
					Service srvhdl = new Service(Convert.ToInt32(srvid), VtkUtility.GetAppCon()) ;
					SetFields() ;
					ViewState["serviceId"] = srvhdl.ID.ToString() ;
					ViewState["serviceVersion"] = srvhdl.Version.ToString() ;
					RecordIdLabel.Text = ViewState["serviceId"].ToString() ;

					//set text fields to values
					//get only the 3 digits for code
					ServiceIdText.Text = srvhdl.Code.ToString().Substring(0,3) ;
					ServiceNameText.Text = srvhdl.ServiceName.ToString() ;
					ServiceAbbreviationText.Text = srvhdl.Abbreviation.ToString() ;
					ServiceSubdivisionText.Text = srvhdl.Subdivision.ToString() ;
					//enable Save button
					PostButton.Enabled = true ;

					//place focus on ServiceNameText field
					//serviceBody.Attributes.Add("onLoad","document.serviceForm.ServiceNameText.focus()") ;

					srvhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + err.Message) ;}
			}
			else
			{
				SetFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Service Code to Edit") ;
			}
		}

		private void PostButoon_Click(object sender, System.EventArgs e)
		{
			int srvid = 0 ;
			//flag to check if version number has changed
			bool versionOk = true ;
			string sc ;
			string gameCode ;
			//ref. Vha.Vtk.Common.Service
			Service srvhdl ;
			if (ServiceIdText.Text != string.Empty)
			{
				try
				{
					gameCode = ViewState["GameCode"].ToString() ;
					sc = ServiceIdText.Text ;
					//need to check the pattern of the ServiceCode, must be 3 digits
					if (!Regex.IsMatch(sc, @"^\d{3}"))
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Service Code must be 3 digits") ;}
					else
					{
						//check that first 3 digits are greater than 600 and less than 700
						if (Convert.ToInt32(sc) < 600 || (Convert.ToInt32(sc) > 699))
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "Service Code must be between 600 and 699") ;}
						else
						{
							//check if edit existing record
							if (ViewState["serviceId"].ToString() != string.Empty)
							{
								srvid = Convert.ToInt32(ViewState["serviceId"].ToString()) ;
								//create handle and open current record
								srvhdl = new Service(srvid, VtkUtility.GetAppCon()) ;
								//check version
								if (ViewState["serviceVersion"].ToString() != srvhdl.Version.ToString())
								{
									VtkUtility.ErrMsgAdd(ErrorMessage, "Current Service record has changed while you were editing, Please press EXIT and start over. ") ;
									versionOk = false ;
								}
							}
								//new record
							else
							{
								//create handle and open new record
								srvhdl = Service.AddRecord(VtkUtility.GetAppCon()) ;
							}
							if (versionOk)
							{
								//save current fields
								srvhdl.Code = sc + gameCode ;
								srvhdl.ServiceName = ServiceNameText.Text ;
								srvhdl.Abbreviation = ServiceAbbreviationText.Text ;
								srvhdl.Subdivision = ServiceSubdivisionText.Text ;
								srvhdl.Scope = "N" ;

								//save and close
								srvhdl.Save() ;
								srvhdl.Dispose() ;

								//update confirmation message
								ConfirmationMessage.Text = "Record Posted!" ;
								//update service list and reset fields
								GetServiceList(gameCode) ;
								SetFields() ;
								RecordIdLabel.Text = "New" ;
							}
						}
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must enter a Service Code") ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButoon_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
	}
}
