using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Games
{
	/// <summary>
	/// Summary description for VolunteerKinEdit.
	/// </summary>
	public class GamesVolunteerKinEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label RecordLabel;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Button ExitButton;
		protected System.Web.UI.WebControls.TextBox KinNameText;
		protected System.Web.UI.WebControls.TextBox KinRelationshipText;
		protected System.Web.UI.WebControls.TextBox KinPhoneText;
		protected System.Web.UI.WebControls.TextBox KinPhone1Text;
		protected System.Web.UI.WebControls.Label StationLabel;
		protected System.Web.UI.WebControls.Button NextButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		public GamesVolunteerKinEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Registration"))
				{
					if (!Page.IsPostBack)
					{
						//return from GamesVolunteerNewEdit
						if (Page.Request.QueryString.Count > 1)
						{
							if (Page.Request.QueryString["GameId"] != null)
							{
								//these inputs come from query strings
								ViewState["GameId"] = Page.Request.QueryString["GameId"].ToString() ;
							}
							if (Page.Request.QueryString["HostStationId"] != null)
							{
								//these inputs come from query strings, these are the subordinate pages
								ViewState["HostStationId"] = Page.Request.QueryString["HostStationId"].ToString() ;
							}
							if (Page.Request.QueryString["HostName"] != null)
							{
								//these inputs come from query strings, these are the subordinate pages
								ViewState["HostStationName"] = Page.Request.QueryString["HostName"].ToString() ;
								StationLabel.Text = ViewState["HostStationName"].ToString() ;
							}
							if (Page.Request.QueryString["volId"] != null)
							{
								//these inputs come from query strings
								ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							}
							if (Page.Request.QueryString["volName"] != null)
							{
								//these inputs come from query strings
								ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
								VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
							}
							if (Page.Request.QueryString["volStId"] != null)
							{
								//these inputs come from query strings
								ViewState["volStId"] = Page.Request.QueryString["volStId"].ToString() ;
							}
							RecordLabel.Text = "NEW" ;
						}
					}
					//save the stationId & volId on the form, this is used by the exit button in the HTML
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + err.Message) ;}
	}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if (KinNameText.Text == string.Empty &&((KinRelationshipText.Text != string.Empty)
				||(KinPhoneText.Text != string.Empty)||(KinPhone1Text.Text != string.Empty)))
			{ fields = "The Name field is required." ;}
			
			return fields ;
		}

		private void NextButton_Click(object sender, System.EventArgs e)
		{
			string volId = string.Empty ;
			string siteId = string.Empty ;
			int kinId ;
			//define handle
			Vha.Vtk.TimeKeeping.NextOfKin kinhdl = null ;
			Vha.Vtk.TimeKeeping.StationProfile prohdl = null ;
			//check if we have incomplete data
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, missingdata) ;}
			else
			{
				try
				{
					volId = ViewState["volId"].ToString() ;
					siteId = ViewState["volStId"].ToString() ;
					//new record
					kinhdl = Vha.Vtk.TimeKeeping.NextOfKin.AddRecord(Convert.ToInt32(volId), VtkUtility.GetAppCon()) ;
					//save current fields
					kinhdl.KinsName = KinNameText.Text ;
					kinhdl.Relationship = KinRelationshipText.Text ;
					kinhdl.Telephone = KinPhoneText.Text ;					
					kinhdl.AlternateTelephone = KinPhone1Text.Text ;

					//save and close
					kinhdl.Save() ;
					//get id, need to post to station profile
					kinId = kinhdl.ID ;
					kinhdl.Dispose() ;
					//use stationId to get station profile and file link
					DataSet ds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVolAndSite(Convert.ToInt32(volId), Convert.ToInt32(siteId)) ;
					DataTable dt = ds.Tables["StationProfileList"] ;
					if (dt.Rows.Count == 1)
					{
						DataRow dr = dt.Rows[0] ;
						int proId = (int) dr["Id"] ;
						ds.Dispose() ;
						dt.Dispose() ;
						//save kinId to volunteer profile
						prohdl = new Vha.Vtk.TimeKeeping.StationProfile(proId, VtkUtility.GetAppCon()) ;
						prohdl.NextOfKinId = kinId ;
						prohdl.Save() ;
						prohdl.Dispose() ;

						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Next of Kin record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Next of Kin record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Next of Kin record: " + err.Message) ;}

				//navigate back to GamesRegistration
				StringBuilder sb = new StringBuilder("GamesRegistration.aspx") ;
				//add station of Games
				sb.Append("?StationId=") ;
				sb.Append(VtkPageHeader1.DivSelectedId) ;
				//game Id
				sb.Append("&GameId=") ;
				sb.Append(ViewState["GameId"].ToString()) ;
				//add volunteer id
				sb.Append("&volId=") ;
				sb.Append(volId) ;
				//add volunteer name
				sb.Append("&volName=") ;
				sb.Append(ViewState["volName"].ToString()) ;
				//add vol station id
				sb.Append("&volStId=") ;
				sb.Append(siteId) ;
				Response.Redirect(sb.ToString()) ;
			}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.NextButton.Click += new System.EventHandler(this.NextButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
