using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.DataClasses ;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.Common;
using Vha.Vtk.WebControlLibrary;

namespace VTK.National
{
	/// <summary>
	/// Summary description for AwardCodesEdit.
	/// </summary>
	public class AwardCodesEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox CodeText;
		protected System.Web.UI.WebControls.TextBox HoursText;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.DropDownList AwardCodeList;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.TextBox NameText;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.TextBox AHoursText;
		protected System.Web.UI.WebControls.DropDownList AwardTypeList;
	
		public AwardCodesEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("National Award Codes"))
				{
					if (!Page.IsPostBack)
					{
						GetAwardList();
						GetAwardTypeList();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Awards List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Awards List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Awards List: " + err.Message) ;}
		}

		private void GetAwardTypeList() 
		{
			try 
			{
				AwardTypeList.DataMember="AwardTypeList";
				AwardTypeList.DataTextField="External";
				AwardTypeList.DataValueField="Key";
				AwardTypeList.DataSource=Vha.Vtk.Common.Award.GetAwardTypeList();
				AwardTypeList.DataBind();
				AwardTypeList.Items.Insert(0,new ListItem(" - select - ",int.MinValue.ToString()));
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
		}

		private void GetAwardList()
		{
			try
			{
				//populate list of award, get dataset, sort by code
				DataSet dsa = Vha.Vtk.Common.Award.GetQuickList() ;
				dsa.Tables["AwardList"].DefaultView.Sort = "AwardCode ASC" ;
				DataTable dta = dsa.Tables["AwardList"] ;
				//create a new column that will combine code and name
				//dta.Columns.Add("CodeAndName", System.Type.GetType("System.String")) ;

				//add the first row
				DataRow dra = dta.NewRow() ;
				dra["DisplayName"] = " -Select Award Code- " ;
				dra["Id"] = 0 ;
				dta.Rows.InsertAt(dra, 0) ;

				//loop and build string for the new column, CodeAndName
				/*foreach (DataRow dr in dta.Rows)
				{
					string s = String.Copy(dr["AwardCode"].ToString().PadRight(6, '-') + dr["AwardName"]) ;
					dr["CodeAndName"] = s ;
				}*/

				//define columns in list box
				AwardCodeList.DataTextField = "DisplayName" ;
				AwardCodeList.DataValueField = "Id" ;

				//bind list box to DataTable and dispose
				AwardCodeList.DataSource = dta ;
				AwardCodeList.DataBind() ;
				dsa.Dispose() ;
				dta.Dispose() ;
				//AwardCodeList.Items.Insert(0,new ListItem(" - select item to edit - ", int.MinValue.ToString()));

				//clear variables
				ClearFields(false);
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Award List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Award List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Award List: " + err.Message) ;}
		}

		protected void ClearFields(bool editable)
		{
			//set text fields to empty
			CodeText.Text = string.Empty ;
			NameText.Text = string.Empty ;
			HoursText.Text = string.Empty ;
			AHoursText.Text = string.Empty ;
			AwardTypeList.SelectedIndex = 0 ;
			//disable fields
			CodeText.Enabled = editable ;
			NameText.Enabled = editable ;
			HoursText.Enabled = editable ;
			AwardTypeList.Enabled = editable ;
			AHoursText.Enabled = editable ;

			PostButton.Enabled = editable ;

			ViewState["awardId"] = 0 ;
			ViewState["awardVersion"] = 0 ;
			ViewState["awardIsNew"] = false;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			// get selected item from list
			if (AwardCodeList.SelectedIndex>0) 
			{
				try 
				{
					Vha.Vtk.Common.Award award = new Award(Convert.ToInt32(AwardCodeList.SelectedItem.Value),
						VtkUtility.GetAppCon());
					//enable fields to be edited
					ClearFields(true) ;
					ViewState["awardId"] = award.ID ;
					ViewState["awardVersion"] = award.Version ;
					CodeText.Text=award.AwardCode;
					NameText.Text=award.AwardName;
					if (award.RequiredHours!=int.MinValue) 
					{
						HoursText.Text=award.RequiredHours.ToString();
					}
					if (award.AwardHours !=int.MinValue) 
					{
						AHoursText.Text=award.AwardHours.ToString();
					}

					VtkUtility.SetSelectedSingle(AwardTypeList.Items, award.AwardType);
				} 
				catch (Exception err) 
				{
					VtkUtility.ErrMsgAdd(ErrorMessage,err.Message);
				}
			} 
			else 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage,"please select an Award Code to edit");
			}
			// populate fields
			// save version ID

		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			ClearFields(true);
			try 
			{
				ViewState["awardIsNew"]=true;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage,err.Message);
			}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			Vha.Vtk.Common.Award award;
			if ((((int)ViewState["awardId"])>0)||(bool)ViewState["awardIsNew"]) 
			{
				try 
				{
					if ((bool)ViewState["awardIsNew"]) 
					{
						award = Award.AddRecord(VtkUtility.GetAppCon());
					} 
					else 
					{
						award = new Award((int)ViewState["awardId"],VtkUtility.GetAppCon());
						if (((int)ViewState["awardVersion"])!=award.Version) {
							throw new Exception("The value of this award code in the database changed. Please start over");
						}
					}
					award.AwardCode=CodeText.Text;
					award.AwardName=NameText.Text;
					if (HoursText.Text.Trim().Length>0) 
					{
						award.RequiredHours=Convert.ToInt32(HoursText.Text);
					} 
					else 
					{
						award.RequiredHours=int.MinValue;
					}
					if (AHoursText.Text.Trim().Length>0) 
					{
						award.AwardHours=Convert.ToInt32(AHoursText.Text);
					} 
					else 
					{
						award.AwardHours=int.MinValue;
					}
					if (AwardTypeList.SelectedIndex>0) 
					{
						award.AwardType=AwardTypeList.SelectedItem.Value;
					} 
					else 
					{
						award.AwardType=string.Empty;
					}
					award.Save();
					ConfirmationMessage.Text="Record Posted!";
					GetAwardList();
					AwardCodeList.SelectedIndex=0;
					award.Dispose();
				} 
				catch (Exception err) 
				{
					VtkUtility.ErrMsgAdd(ErrorMessage,err.Message);
				}
			} 
			else 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage,"No selected award code found.");
			}
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx") ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
