using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Donations;
using Vha.Vtk.TimeKeeping;

namespace VTK.National
{
	/// <summary>
	/// Summary description for ReportsVS01DataView.
	/// </summary>
	public class ReportsVS01DataView : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.DataGrid DataGrid;
		protected System.Web.UI.WebControls.Label KeyLabel;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("VS01 Data View"))
				{
					if (!Page.IsPostBack)
					{
						// get parameters and build data grid
						int fiscalYear = Convert.ToInt32(Request.QueryString["fiscalYear"]);
						int months = Convert.ToInt32(Request.QueryString["months"]);
						bool visn = Convert.ToBoolean(Request.QueryString["visn"]);
						bool station = Convert.ToBoolean(Request.QueryString["station"]);
						bool countrolls = Convert.ToBoolean(Request.QueryString["countrolls"]);
						bool loghours = Convert.ToBoolean(Request.QueryString["loghours"]);
						bool rshours = Convert.ToBoolean(Request.QueryString["rshours"]);
						bool occhours = Convert.ToBoolean(Request.QueryString["occhours"]);
						bool adjhours = Convert.ToBoolean(Request.QueryString["adjhours"]);
						bool tothours = Convert.ToBoolean(Request.QueryString["tothours"]);
						UpdateDataGrid(fiscalYear, months, visn, station, countrolls, loghours, rshours, occhours, adjhours, tothours);
						//set key box
						KeyLabel.Text = "Fiscal Year 1 = " + fiscalYear.ToString() + "  " +
							          "Fiscal Year 2 = " + (fiscalYear-1).ToString() + "  " +
						              "Fiscal Year 3 = " + (fiscalYear-2).ToString() + "  " +
					                  "Fiscal Year 4 = " + (fiscalYear-3).ToString() + "  " +
									  "Fiscal Year 5 = " + (fiscalYear-4).ToString() + "  " +
							          "Months = " + months;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading VS01 Data: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading VS01 Data: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading VS01 Data: " + err.Message) ;}
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void UpdateDataGrid(int fiscalYear, int months, bool visn, bool station, bool countrolls, bool loghours, bool rshours, bool occhours, bool adjhours, bool tothours)
		{
			DataSet dsData;
			DataTable dtData;
			string displayName = string.Empty ;
			string error = "";
			if (error != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
			else
			{
				//get the data for the report
				dsData = Vha.Vtk.TimeKeeping.VolunteerHours.GetQuickListDataForVS01Report(fiscalYear, months);
				dtData = dsData.Tables["GetQuickListDataForVS01Report"];
				
			    DataGrid.DataSource = dtData;
				DataGrid.DataBind();
				//do not show visn detail
				if (visn == false) DataGrid.Columns[1].Visible = false;
				//do not show station detail
				if (station == false)
				{
					DataGrid.Columns[3].Visible = false;
					DataGrid.Columns[4].Visible = false;
					DataGrid.Columns[5].Visible = false;
					DataGrid.Columns[6].Visible = false;
					DataGrid.Columns[7].Visible = false;
					DataGrid.Columns[8].Visible = false;
				}
				//do not show count on rolls
				if (countrolls == false)
				{
					DataGrid.Columns[9].Visible = false;
					DataGrid.Columns[15].Visible = false;
					DataGrid.Columns[21].Visible = false;
					DataGrid.Columns[27].Visible = false;
					DataGrid.Columns[33].Visible = false;
				}
				//do not show count on rolls logging hours
				if (loghours == false)
				{
					DataGrid.Columns[10].Visible = false;
					DataGrid.Columns[16].Visible = false;
					DataGrid.Columns[22].Visible = false;
					DataGrid.Columns[28].Visible = false;
					DataGrid.Columns[34].Visible = false;
				}
				//do not show rs hours
				if (rshours == false)
				{
					DataGrid.Columns[11].Visible = false;
					DataGrid.Columns[17].Visible = false;
					DataGrid.Columns[23].Visible = false;
					DataGrid.Columns[29].Visible = false;
					DataGrid.Columns[35].Visible = false;
				}
				//do not show adjusted hours
				if (adjhours == false)
				{
					DataGrid.Columns[12].Visible = false;
					DataGrid.Columns[18].Visible = false;
					DataGrid.Columns[24].Visible = false;
					DataGrid.Columns[30].Visible = false;
					DataGrid.Columns[36].Visible = false;
				}
				//do not show adjusted hours
				if (occhours == false)
				{
					DataGrid.Columns[13].Visible = false;
					DataGrid.Columns[19].Visible = false;
					DataGrid.Columns[25].Visible = false;
					DataGrid.Columns[31].Visible = false;
					DataGrid.Columns[37].Visible = false;
				}
				//do not show total hours
				if (tothours == false)
				{
					DataGrid.Columns[14].Visible = false;
					DataGrid.Columns[20].Visible = false;
					DataGrid.Columns[26].Visible = false;
					DataGrid.Columns[32].Visible = false;
					DataGrid.Columns[38].Visible = false;
				}

				dsData.Dispose();
				dtData.Dispose();

			}
		}
	}
}
