using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.DataClasses ;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.National
{
	/// <summary>
	/// Summary description for WorkDaysEdit.
	/// </summary>
	public class WorkDaysEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.TextBox DaysText;
		protected System.Web.UI.WebControls.TextBox AppearsText;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.DropDownList ScheduleList;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label RecordIdLabel;
		protected System.Web.UI.WebControls.TextBox CodeText;
	
		public WorkDaysEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("National Schedule Codes"))
				{
					if (!Page.IsPostBack)
					{
						GetScheduleList();
						SetFields() ;
						PostButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Schedule Codes List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Schedule Codes List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Schedule Codes List: " + err.Message) ;}
		}

		private void GetScheduleList()
		{
			try
			{
				//populate list of Organizations, get dataset, sort by code
				DataSet dssch = Vha.Vtk.Common.ScheduleWorkday.GetQuickList() ;
				dssch.Tables["ScheduleWorkdayList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable dtsch = dssch.Tables["ScheduleWorkdayList"] ;

				//define columns in list box
				ScheduleList.DataTextField = "DisplayName" ;
				ScheduleList.DataValueField = "Id" ;

				//bind list box to DataTable and dispose
				ScheduleList.DataSource = dtsch ;
				ScheduleList.DataBind() ;
				dssch.Dispose() ;
				dtsch.Dispose() ;
				ScheduleList.Items.Insert(0,new ListItem(" - select Schedule Workday - ", int.MinValue.ToString()));

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Workday List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Workday List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Workday List: " + err.Message) ;}
		}
		protected void SetFields()
		{
			//set text fields to empty
			CodeText.Text = string.Empty ;
			DaysText.Text = string.Empty ;
			AppearsText.Text = string.Empty ;
			RecordIdLabel.Text = "New" ;

			ViewState["scheduleId"] = string.Empty ;
			ViewState["scheduleVersion"] = string.Empty ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Schedule was selected
			if (ScheduleList.SelectedIndex>0)
			{
				//get selected Schedule
				string schid = ScheduleList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save id and version
					Vha.Vtk.Common.ScheduleWorkday schhdl = new Vha.Vtk.Common.ScheduleWorkday(Convert.ToInt32(schid)) ;
					ViewState["scheduleId"] = schhdl.ID ;
					ViewState["scheduleVersion"] = schhdl.Version.ToString() ;

					//set text fields to values
					RecordIdLabel.Text = schhdl.ID.ToString() ;
					CodeText.Text = schhdl.Code ;
					DaysText.Text = schhdl.Days ;
					AppearsText.Text = schhdl.AppearsAs ;
					//enable Save button
					PostButton.Enabled = true ;

					//place focus on OrganizationIdText field
					//orgBody.Attributes.Add("onLoad","document.orgForm.OrganizationNameText.focus()") ;

					schhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Schedule Workday Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Schedule Workday Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Schedule Workday Record: " + err.Message) ;}
			}
			else
			{
				SetFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Schedule Code to Edit") ;
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			ScheduleList.SelectedIndex = 0 ;
			PostButton.Enabled = true ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			if (CodeText.Text != string.Empty)
			{
				//flag to check if version number has changed
				bool versionOk = true ;
				try
				{
					Vha.Vtk.Common.ScheduleWorkday schhdl ;
					//check if edit existing record
					if (ViewState["scheduleId"].ToString() != string.Empty)
					{
						string schid = ViewState["scheduleId"].ToString() ;
						//create handle and open current record
						schhdl = new Vha.Vtk.Common.ScheduleWorkday(Convert.ToInt32(schid)) ;
						//check version
						if (ViewState["scheduleVersion"].ToString() != schhdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Schedule Workday record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
						//new record
					else
					{
						//create handle and open new record
						schhdl = Vha.Vtk.Common.ScheduleWorkday.AddRecord() ;
					}
					if (versionOk)
					{
						//save current fields
						schhdl.Code = CodeText.Text ;
						schhdl.Days = DaysText.Text ;
						schhdl.AppearsAs = AppearsText.Text ;

						//save and close
						schhdl.Save() ;
						schhdl.Dispose() ;

						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update service list and reset fields
						GetScheduleList() ;
						SetFields() ;
						//NewScheduleText.Text = string.Empty ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was no record to Save") ;}
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx") ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


	}
}
