using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using System.Text;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for PotentialAward.
	/// </summary>
	public class AddressLabels : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.DropDownList SelectBy;
		protected System.Web.UI.WebControls.Panel AgeRangePanel;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.ListBox VolunteerList;
		protected System.Web.UI.WebControls.DropDownList BirthMonthList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;

		const string emptyOrgListItemText = " - select organization - ";
		const string emptySvcListItemText = " - select service - ";
		const string emptyVolListItemText = " - select volunteers - ";
		const string emptyListItemValue = "-1";
		protected System.Web.UI.WebControls.DropDownList OrgSvcList;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.CustomValidator SelectByValidator;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidator1;
		protected System.Web.UI.WebControls.CompareValidator CompareValidator1;
		protected System.Web.UI.WebControls.CustomValidator OrganizationServiceListValidator;
		protected System.Web.UI.WebControls.DropDownList AgeRangeFrom;
		protected System.Web.UI.WebControls.DropDownList AgeRangeTo;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.Panel PrintPanel;
		protected VTK.Volunteer.VolunteerChooserControl VolunteerChooserControl;

		protected System.Web.UI.HtmlControls.HtmlInputButton VolButton;

		public AddressLabels()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			Page.RegisterHiddenField("Action", String.Empty);
			try
			{
				if (VtkPageHeader1.IsDivSelected("Address Labels"))
				{
					if (!Page.IsPostBack) 
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						// initalize age from to
						InitializeAge();
						//disable volunteer button
						VolButton.Visible = false ;

					}					
					else
					{
						if(Request.Form["Action"] != null)
						{
							if(Request.Form["Action"] == "VolButton")
							{
								VolunteerButton();
							}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void InitializeAge() 
		{
			// populate begin and end list month year
			for (int count = 0; count < 121; count++)
			{
				AgeRangeFrom.Items.Add(count.ToString());
				AgeRangeTo.Items.Add(count.ToString());
			}
			AgeRangeFrom.SelectedIndex=0;
			AgeRangeTo.SelectedIndex=120;
		}

		override protected bool OnBubbleEvent(object Sender, EventArgs e) 
		{
			//come here after a volunteer has been choosen
			string volName = string.Empty ;
			string volId = "0" ;
			bool bubbleValue = false ;
			if (VolunteerChooserControl.VolunteerChooserSuccess)
			{
				//check if volunteer has been terminated
				if (VolunteerChooserControl.VolunteerChooserTerminated)
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer has been TERMINATED, No actions allowed") ;
					bubbleValue = true ;
				}
				else
				{
					VtkUtility.SetSelectedSingle(SelectBy.Items, "Selected Volunteers");
					//remove the ' - select volunteers - ' row
					if ((VolunteerList.Items.Count==1)&&(VolunteerList.Items[0].Value=="-1")) 
					{ VolunteerList.Items.RemoveAt(0);}

					volId = VolunteerChooserControl.VolunteerChooserId.ToString() ;
					volName = VolunteerChooserControl.VolunteerChooserName.ToString() ;

					VolunteerChooserControl.BubbleEventClear() ;
					VolunteerList.Items.Add(new ListItem(volName, volId)) ;

					EnableSelectedVolunteers();
					VolunteerChooserControl.Visible = false ;
					PrintPanel.Visible = true ;
					bubbleValue = true ;
				}
			}
			return bubbleValue ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.SelectBy.SelectedIndexChanged += new System.EventHandler(this.SelectBy_SelectedIndexChanged);
			this.PrintFormatList.SelectedIndexChanged += new System.EventHandler(this.PrintFormatList_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			if (ValidateForm()) 
			{
				UIReportParams rp = new UIReportParams();
				//@InstitutionId
				rp.AT_InstitutionId=DivisionList.SelectedItem.Value;
				// TODO: Select By, etc.
				switch (SelectBy.SelectedItem.Value) 
				{
					case "All":
						rp.AT_SortBy=1;
						rp.AT_List="ALL";
						break;
					case "Selected Volunteers":
						rp.AT_SortBy=1;
						rp.AT_List = "";
						foreach (ListItem li in VolunteerList.Items) 
						{
							// MSG - 9/1/2004 Added additional AT_List's due to NOIS CHY-0903-52043
							if (rp.AT_List.Length + li.Value.Length + 1 <= 254)
							{
								rp.AT_List += li.Value + "^";
							}
							else if (rp.AT_List2.Length + li.Value.Length + 1 <= 254)
							{
								rp.AT_List2 += li.Value + "^";
							}
							else if (rp.AT_List3.Length + li.Value.Length + 1 <= 254)
							{
								rp.AT_List3 += li.Value + "^";
							}
							else if (rp.AT_List4.Length + li.Value.Length + 1 <= 254)
							{
								rp.AT_List4 += li.Value + "^";
							}
							else if (rp.AT_List5.Length + li.Value.Length + 1 <= 254)
							{
								rp.AT_List5 += li.Value + "^";
							}
							else
							{
								rp.AT_List = "Overflow";
							}
						}
						break;
					case "Age Range":
						rp.AT_SortBy=3;
						rp.AT_From=AgeRangeFrom.SelectedItem.Value;
						rp.AT_To=AgeRangeTo.SelectedItem.Value;
						break;
					case "Birth Month":
						rp.AT_SortBy=4;
						rp.AT_List=BirthMonthList.SelectedItem.Value;
						break;
					case "Organization":
						rp.AT_SortBy=5;
						rp.AT_List=OrgSvcList.SelectedItem.Value;
						break;
					case "Service":
						rp.AT_SortBy=6;
						rp.AT_List=OrgSvcList.SelectedItem.Value;
						break;
					case "VAVS":
						rp.AT_SortBy=7;
						break;
					default:
						break;
				}
				// MSG - 9/1/2004 Added overflow error message due to NOIS CHY-0903-52043
				if (rp.AT_List.Length >= 8 && rp.AT_List.Substring(0, 8) == "Overflow")
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "The maximum number of selected volunteers has been exceeded, please select fewer volunteers or use a different select method.") ;
				}
				else
				{
					// report format
					rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
					// reportType
					rp.ReportType=UIReportType.VtkVolunteerAddressLabels;

					// Put UIParams into Context
					Context.Items["ReportParams"]=rp;

					// transfer
					if (rp.ReportFormat==UIReportFormat.Web) 
					{
						Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
					} 
					else 
					{
						Server.Transfer("../RptCR/CrystalExport.aspx");
					}
				}
			}
		}
		
		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InstitutionId;
			public int AT_SortBy;
			public string AT_From;
			public string AT_To;
			public string AT_List;
			public string AT_List2;
			public string AT_List3;
			public string AT_List4;
			public string AT_List5;

			public UIReportParams() 
			{
				AT_InstitutionId="";
				AT_SortBy=0;
				AT_From="";
				AT_To="";
				AT_List="";
				AT_List2="";
				AT_List3="";
				AT_List4="";
				AT_List5="";
			}
		}

		private bool ValidateForm() 
		{
			bool printOKFlag=true;
			// validate they chose a division
			if (DivisionList.SelectedIndex<0) 
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a division");
			}
			switch (SelectBy.SelectedItem.Value) 
			{
				case "Selected Volunteers":
					if (VolunteerList.Items.Count<2) 
					{
						if (VolunteerList.Items.Count<1) 
						{
							printOKFlag=false;
							VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose at least one volunteer");
						} 
						else if (VolunteerList.Items.Count==1) 
						{
							if (VolunteerList.Items[0].Value==emptyListItemValue) 
							{
								printOKFlag=false;
								VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose at least one volunteer");
							}
						}
					}
					break;
				case "Age Range":
					int ageFrom=-1; int ageTo=-1;
					try 
					{
						ageFrom=Convert.ToInt32(AgeRangeFrom.SelectedItem.Value);
						ageTo=Convert.ToInt32(AgeRangeTo.SelectedItem.Value);
						if (ageFrom>ageTo) 
						{
							VtkUtility.ErrMsgAdd(ErrorMessage,"Please enter From less than To age");
							printOKFlag=false;
						}
					}
					catch (Exception err) 
					{
						VtkUtility.ErrMsgAdd(ErrorMessage,err.Message);
						printOKFlag=false;
					}

					break;
				case "Organization":
					if (OrgSvcList.SelectedIndex<0) 
					{
						printOKFlag=false;
						VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose an organization");
					} 
					break;
				case "Service":
					if (OrgSvcList.SelectedIndex<0) 
					{
						printOKFlag=false;
						VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose a service");
					} 
					break;
				default:
					break;
			}
			return printOKFlag;
		}

		private void PopulateServiceList() 
		{
			OrgSvcList.Items.Clear();
			try 
			{
				DataSet ds = Vha.Vtk.Common.Service.GetSiteQuickListByName(Convert.ToInt32(DivisionList.SelectedItem.Value));
				OrgSvcList.DataSource=ds.Tables["ServiceList"].DefaultView;
				OrgSvcList.DataTextField="DisplayName";
				OrgSvcList.DataValueField="ID";
				OrgSvcList.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
			finally 
			{
				//OrgSvcList.Items.Insert(0, new ListItem(emptySvcListItemText, emptyListItemValue));
			}
		}

		private void PopulateOrganizationList() 
		{
			OrgSvcList.Items.Clear();
			try 
			{
				DataSet ds = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(
					Convert.ToInt32(DivisionList.SelectedItem.Value));
				OrgSvcList.DataSource=ds.Tables["OrganizationList"].DefaultView;
				OrgSvcList.DataTextField="DisplayName";
				OrgSvcList.DataValueField="ID";
				OrgSvcList.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
			finally 
			{
				//OrgSvcList.Items.Insert(0, new ListItem(emptyOrgListItemText, emptyListItemValue));
			}
		}

		private void SelectBy_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			switch (SelectBy.SelectedItem.Value) 
			{
				case "All":
					EnableAll();
					break;
				case "Selected Volunteers":
					// EnableSelectedVolunteers();
					VolunteerButton();
					break;
				case "Age Range":
					EnableAgeRange();
					break;
				case "Birth Month":
					EnableBirthMonth();
					break;
				case "Organization":
					EnableOrganization();
					break;
				case "Service":
					EnableService();
					break;
				case "VAVS":
					EnableVAVS();
					break;
				default:
					break;
			}
		}

		private void EnableAll() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			VolButton.Visible = false ;
			VolunteerList.Visible=false;
			VolunteerList.Items.Clear();
			BirthMonthList.Visible=false;
		}

		private void EnableSelectedVolunteers() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			VolButton.Visible = true ;
			VolunteerList.Visible=true;
			BirthMonthList.Visible=false;
			//VolunteerList.Items.Clear();
			//VolunteerList.Items.Add(new ListItem(emptyVolListItemText,emptyListItemValue.ToString()));
		}

		private void EnableAgeRange() 
		{
			AgeRangePanel.Visible=true;
			OrgSvcList.Visible=false;
			VolButton.Visible = false ;
			VolunteerList.Visible=false;
			VolunteerList.Items.Clear();
			BirthMonthList.Visible=false;
		}

		private void EnableBirthMonth() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			VolButton.Visible = false ;
			VolunteerList.Visible=false;
			VolunteerList.Items.Clear();
			BirthMonthList.Visible=true;
		}

		private void EnableOrganization() 
		{
			AgeRangePanel.Visible=false;
			VolButton.Visible = false ;
			VolunteerList.Visible=false;
			VolunteerList.Items.Clear();
			BirthMonthList.Visible=false;
			PopulateOrganizationList();
			OrgSvcList.Visible=true;
		}

		private void EnableService() 
		{
			AgeRangePanel.Visible=false;
			VolButton.Visible = false ;
			VolunteerList.Visible=false;
			VolunteerList.Items.Clear();
			BirthMonthList.Visible=false;
			PopulateServiceList();
			OrgSvcList.Visible=true;
		}

		private void EnableVAVS() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			VolButton.Visible = false ;
			VolunteerList.Visible=false;
			VolunteerList.Items.Clear();
			BirthMonthList.Visible=false;
		}

		private void VolunteerButton()
		{
			PrintPanel.Visible = false ;
			VolunteerChooserControl.Visible = true ;
		}

		private void DivisionChange(object sender, System.EventArgs e)
		{

		}

		private void PrintFormatList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
		
		}
	}
}
