using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for DonationsDailyGrandTotal.
	/// </summary>
	public class DonationsDailyGrandTotal : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.CompareValidator BeginEndDateValidator;
		protected System.Web.UI.WebControls.RangeValidator EndDateRangeValidator;
		protected System.Web.UI.WebControls.TextBox txtDateEnd;
		protected System.Web.UI.WebControls.RangeValidator BeginDateRangeValidator;
		protected System.Web.UI.WebControls.TextBox txtDateBegin;
		protected System.Web.UI.WebControls.DropDownList ReferenceList;
		protected System.Web.UI.WebControls.RadioButtonList DetailRadioButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		const string emptySelectedListItemText = " - select organizations from list - ";
		const string emptySelectedListItemValue = "-1";
		const string emptyOrganizationListItemText = " - no organizations to select from - ";
		protected System.Web.UI.WebControls.Panel OrgPanel;
		protected System.Web.UI.WebControls.ListBox SelectedOrgListBox;
		protected System.Web.UI.WebControls.ListBox OrganizationListBox;
		protected System.Web.UI.WebControls.RequiredFieldValidator OrgListBoxValidator;
		protected System.Web.UI.WebControls.DropDownList DonorTypeList;
		protected System.Web.UI.WebControls.DropDownList DivisionList;
		const string emptyOrganizationListItemValue = "-1";
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Grand Total of Donations"))
				{
					Page.RegisterHiddenField("Action", String.Empty);
					OrganizationListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					SelectedOrgListBox.Attributes.Add("OnClick", "Set_NoBlank()");

					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						//set the selected datetime to today
						txtDateBegin.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
						txtDateEnd.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
						//populate donor types list
						PopulateDonorTypeList();
						//populate reference list
						PopulateReferenceList();
						// remove all selected organizations and populate organization list
						RemoveAllOrgButton();
						
						//turn on or off the organizations based on donor type
						//only make visible if donor type is organization
						OrgPanel.Visible = true;
						if (DonorTypeList.SelectedItem.Text != "Organization") OrgPanel.Visible = false;
					}
					else
					{
						//turn on or off the organizations based on donor type
						//only make visible if donor type is organization
						OrgPanel.Visible = true;
						if (DonorTypeList.SelectedItem.Text != "Organization") OrgPanel.Visible = false;
						
						if(Request.Form["Action"] != String.Empty)
						{
							if(Request.Form["Action"] == "Add")
							{
								Page.Trace.Warn("Action", "Add");
								AddOrgButton();
							}
							else if (Request.Form["Action"] == "AddAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								AddAllOrgButton();
							}
							else if (Request.Form["Action"] == "RemoveAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								RemoveAllOrgButton();
							}
							else //action = remove
							{
								Page.Trace.Warn("Action", "Remove");
								RemoveOrgButton();
							}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateDonorTypeList() 
		{
			try 
			{
				//populate list of donor types
				DataSet ds = Vha.Vtk.Donations.DonorType.GetQuickList();
				DataTable dt = ds.Tables["DonorTypeList"];

				// insert a new row for the "All" item
				DataRow dr = dt.NewRow() ;
				dr["Id"]=0;
				dr["DonorType"]="All";
				dt.Rows.InsertAt(dr,0);
				
				DonorTypeList.DataTextField = "DonorType";
				DonorTypeList.DataValueField = "Id";
				DonorTypeList.DataSource = dt;
				DonorTypeList.DataBind() ;
				ds.Dispose();
				dt.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateReferenceList() 
		{
			try 
			{
				//populate list of references
				DataSet ds = Vha.Vtk.Donations.Donation.GetQuickListReferencesBy_StationId(Convert.ToInt32(DivisionList.SelectedItem.Value));
				DataTable dt = ds.Tables["GetQuickListReferencesBy_StationId"];

				// insert a new row for the "All" item
				DataRow dr = dt.NewRow() ;
				dr["Id"]=0;
				dr["DonationReference"]="All";
				dt.Rows.InsertAt(dr,0);
				
				ReferenceList.DataTextField = "DonationReference";
				ReferenceList.DataValueField = "Id";
				ReferenceList.DataSource = dt;
				ReferenceList.DataBind() ;
				ds.Dispose();
				dt.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateOrganizationList() 
		{
			// (Only allow one division per, because org list is based on division)
			try 
			{
				DataSet ds = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(
					Convert.ToInt32(DivisionList.SelectedItem.Value));
				OrganizationListBox.DataSource=ds.Tables["OrganizationList"].DefaultView;
				OrganizationListBox.DataTextField="Name";
				OrganizationListBox.DataValueField="ID";
				OrganizationListBox.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.DivisionList.SelectedIndexChanged += new System.EventHandler(this.DivisionList_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void AddOrgButton()
		{
			//make sure item is selected
			if (OrganizationListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (OrganizationListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering orgs, remove it
					if (SelectedOrgListBox.Items[0].Value=="-1") 
					{
						SelectedOrgListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(OrganizationListBox, SelectedOrgListBox);
				}
			}
			//if the organization list box has no items, add the text for adding new ones
			if (OrganizationListBox.Items.Count==0) 
			{
				OrganizationListBox.Items.Add(new ListItem(emptyOrganizationListItemText,emptyOrganizationListItemValue.ToString()));
			}
		}

		private void AddAllOrgButton()
		{
			//remove all selected organizations first
			SelectedOrgListBox.Items.Clear();
			OrganizationListBox.Items.Clear();
			// re-populate organization list
			PopulateOrganizationList();
			//add all organizations
			for (int i=0;i<OrganizationListBox.Items.Count;i++)
			{
				OrganizationListBox.SelectedIndex=i;
				SelectedOrgListBox.Items.Add(new ListItem(OrganizationListBox.SelectedItem.Text, OrganizationListBox.SelectedItem.Value));
			}
			OrganizationListBox.Items.Clear();
			OrganizationListBox.Items.Add(new ListItem(emptyOrganizationListItemText,emptyOrganizationListItemValue.ToString()));
			//set the focus on the first item in selected list (to keep the validator from firing)
			SelectedOrgListBox.SelectedIndex=0;
		}

		private void RemoveOrgButton()
		{
			//make sure item is selected
			if (SelectedOrgListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (SelectedOrgListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering orgs, remove it
					if (OrganizationListBox.Items[0].Value=="-1") 
					{
						OrganizationListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(SelectedOrgListBox, OrganizationListBox);
				}
				//if the selected list box has no items, add the text for adding new ones
				if (SelectedOrgListBox.Items.Count==0) 
				{
					SelectedOrgListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
				}
				else
				{
					//set the focus on the first item in selected list (to keep the validator from firing)
					SelectedOrgListBox.SelectedIndex=0;
				}
			}
		}

		private void RemoveAllOrgButton()
		{
			// populate organization list
			PopulateOrganizationList();
			//remove all selected organizations
			SelectedOrgListBox.Items.Clear();
			//add the selection text
			SelectedOrgListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
		}

		//move selected item from one list to the other
		private void MoveSelectedItem(ListBox FromList, ListBox ToList) 
		{
			// if item selected, remove it from Org list and add it to selected list
			while (FromList.SelectedIndex>-1) 
			{
				ListItem li = new ListItem(FromList.SelectedItem.Text,
					FromList.SelectedItem.Value);
				FromList.Items.RemoveAt(FromList.SelectedIndex);
				int pos=-1;
				for (int i=0;i<ToList.Items.Count;i++) 
				{
					if (String.Compare(ToList.Items[i].Text, li.Text,
						true, System.Globalization.CultureInfo.CurrentUICulture)>=0) 
					{
						pos=i;
						break;
					}
				}
				if (pos>-1) 
				{
					ToList.Items.Insert(pos,li);
				} 
				else 
				{
					ToList.Items.Add(li);
				}
			}
			if(ToList.Items.Count > 0)
			{
				ToList.SelectedIndex = 0;
			}
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// Build input institution list
			foreach (ListItem li in DivisionList.Items) 
			{
				if (li.Selected) rp.AT_InputInstIdList+=li.Value+"^";
			}

			
			// Build input donor type list
			foreach (ListItem li in DonorTypeList.Items) 
			{
				if (li.Selected) rp.AT_InputDonorTypeIdList+=li.Value+"^";
			}
			// if all selected, set to ^
			if (DonorTypeList.SelectedItem.Value == "0") rp.AT_InputDonorTypeIdList="^";


			// Build input organization list
			foreach (ListItem li in SelectedOrgListBox.Items) 
			{
				rp.AT_InputOrgIdList+=li.Value+"^";
			}
			// if all selected, set to ^
			if (OrganizationListBox.Items[0].Value=="-1") rp.AT_InputOrgIdList="^";
			// if donor type not equal organizaion, pass ^ for all of them
			if (DonorTypeList.SelectedItem.Text != "Organization") rp.AT_InputOrgIdList="^";


			// Build input reference list
			foreach (ListItem li in ReferenceList.Items) 
			{
			if (li.Selected) rp.AT_InputRefIdList+=li.Value+"^";
			}
			// if all selected, set to ^
			if (ReferenceList.SelectedItem.Value == "0") rp.AT_InputRefIdList="^";

			// set detail (1) or summary (0)
			rp.AT_InputDetail = 0;
			if (DetailRadioButton.SelectedItem.Value == "Yes") rp.AT_InputDetail = 1;

			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// date of report
			rp.AT_InputBeginDate=System.Convert.ToDateTime(txtDateBegin.Text);
			rp.AT_InputEndDate=System.Convert.ToDateTime(txtDateEnd.Text);

			// report type (name of crystal report file)
			// from radio button, either print the list or the form
			rp.ReportType=UIReportType.VtkSL_DonationGrandTotalDetail;

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		private void DivisionList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			//populate reference list based on selected station
			PopulateReferenceList();		
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InputInstIdList;
			public DateTime AT_InputBeginDate;
			public DateTime AT_InputEndDate;
			public string AT_InputOrgIdList;
			public string AT_InputDonorTypeIdList;
			public string AT_InputRefIdList;
			public int AT_InputDetail;

			public UIReportParams() 
			{
				AT_InputInstIdList="^";
				AT_InputOrgIdList="^";
				AT_InputBeginDate=DateTime.Today;
				AT_InputEndDate=DateTime.Today;
				AT_InputDonorTypeIdList="^";
				AT_InputRefIdList="^";
				AT_InputDetail=1;
			}
		}
	}
}
