using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for DonationsGenerateDataView.
	/// </summary>
	public class DonationsGenerateDataView : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.TextBox txtDateBegin;
		protected System.Web.UI.WebControls.RangeValidator BeginDateRangeValidator;
		protected System.Web.UI.WebControls.RangeValidator EndDateRangeValidator;
		protected System.Web.UI.WebControls.TextBox txtDateEnd;
		protected System.Web.UI.WebControls.CompareValidator BeginEndDateValidator;
		protected System.Web.UI.WebControls.DropDownList DonationTypeList;
		protected System.Web.UI.WebControls.TextBox txtCheckNumber;
		protected System.Web.UI.WebControls.TextBox txtValue;
		protected System.Web.UI.WebControls.TextBox txtLastName;
		protected System.Web.UI.WebControls.DropDownList OrganizationList;
		protected System.Web.UI.WebControls.TextBox txtMemoryOf;
		protected System.Web.UI.WebControls.TextBox txtLocalBranch;
		protected System.Web.UI.WebControls.TextBox txtOtherGroups;
		protected System.Web.UI.WebControls.DropDownList GPFList;
		protected System.Web.UI.WebControls.DropDownList ReferenceList;
		protected System.Web.UI.WebControls.RangeValidator ValueValidator;
		protected System.Web.UI.WebControls.DropDownList DivisionList;
		protected System.Web.UI.WebControls.CheckBoxList ShowDataCheckBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Donations Data View"))
				{
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						//set the selected datetime to today
						txtDateBegin.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
						txtDateEnd.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
						//populate donation types list
						PopulateDonationTypeList();
						//populate organization list
						PopulateOrganizationList();
						//populate GPF list
						PopulateGPFList();
						//populate reference list
						PopulateReferenceList();
						//save the stationId on the form
						Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString());
					}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateDonationTypeList() 
		{
			try 
			{
				//populate list of donation types
				DataSet ds = Vha.Vtk.Donations.DonationType.GetQuickList();
				DataTable dt = ds.Tables["DonationTypeList"];

				// insert a new row for the "All" item
				DataRow dr = dt.NewRow() ;
				dr["Id"]=0;
				dr["DonationType"]="All";
				dt.Rows.InsertAt(dr,0);
				
				DonationTypeList.ClearSelection();
				DonationTypeList.DataTextField = "DonationType";
				DonationTypeList.DataValueField = "Id";
				DonationTypeList.DataSource = dt;
				DonationTypeList.DataBind() ;
				ds.Dispose();
				dt.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateOrganizationList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(Convert.ToInt32(DivisionList.SelectedItem.Value));
				DataTable dt = ds.Tables["OrganizationList"];

				// insert a new row for the "All" item
				DataRow dr = dt.NewRow() ;
				dr["Id"]=0;
				dr["Name"]="All";
				dt.Rows.InsertAt(dr,0);

				OrganizationList.ClearSelection();
				OrganizationList.DataSource=ds.Tables["OrganizationList"].DefaultView;
				OrganizationList.DataTextField="Name";
				OrganizationList.DataValueField="Id";
				OrganizationList.DataBind();
				ds.Dispose();
				dt.Dispose();
				} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateGPFList() 
		{
			try 
			{
				//populate list of GPF
				DataSet ds = Vha.Vtk.Donations.Donation.GetQuickListGPFsBy_StationId(Convert.ToInt32(DivisionList.SelectedItem.Value));
				DataTable dt = ds.Tables["GetQuickListGPFsBy_StationId"];

				// insert a new row for the "All" item
				DataRow dr = dt.NewRow() ;
				dr["Id"]=0;
				dr["GeneralPostFund"]="All";
				dt.Rows.InsertAt(dr,0);
				
				GPFList.ClearSelection();
				GPFList.DataTextField = "GeneralPostFund";
				GPFList.DataValueField = "Id";
				GPFList.DataSource = dt;
				GPFList.DataBind() ;
				ds.Dispose();
				dt.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateReferenceList() 
		{
			try 
			{
				//populate list of references
				DataSet ds = Vha.Vtk.Donations.Donation.GetQuickListReferencesBy_StationId(Convert.ToInt32(DivisionList.SelectedItem.Value));
				DataTable dt = ds.Tables["GetQuickListReferencesBy_StationId"];

				// insert a new row for the "All" item
				DataRow dr = dt.NewRow() ;
				dr["Id"]=0;
				dr["DonationReference"]="All";
				dt.Rows.InsertAt(dr,0);
				
				ReferenceList.ClearSelection();
				ReferenceList.DataTextField = "DonationReference";
				ReferenceList.DataValueField = "Id";
				ReferenceList.DataSource = dt;
				ReferenceList.DataBind() ;
				ds.Dispose();
				dt.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.DivisionList.SelectedIndexChanged += new System.EventHandler(this.DivisionList_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			string searchlist = "";
			string showlist = "";
			string data = "";

			// ----- BUILD SEARCH LIST -----
			// institution
			searchlist = searchlist + "&inst=" + DivisionList.SelectedItem.Value;
			//begin date
			searchlist = searchlist + "&begindate=" + txtDateBegin.Text;
			//end date
			searchlist = searchlist + "&enddate=" + txtDateEnd.Text;
			//donation type (pass ^ if All [value=0] is selected)
			data = DonationTypeList.SelectedItem.Value;
			if (data == "0") data = "^";
			searchlist = searchlist + "&donationtype=" + data;
			//value (if null, set to zero)
			if (txtValue.Text == string.Empty) txtValue.Text = "0";
			searchlist = searchlist + "&value=" + Convert.ToInt32(txtValue.Text);
			//gpf (pass ^ if All [value=0] is selected)
			data = GPFList.SelectedItem.Value;
			if (data == "0") data = "^";
			searchlist = searchlist + "&gpf=" + data;
			//check number
			searchlist = searchlist + "&check=" + txtCheckNumber.Text;
			//individual last name
			searchlist = searchlist + "&lastname=" + txtLastName.Text;
			//organization (pass ^ if All [value=0] is selected)
			data = OrganizationList.SelectedItem.Value;
			if (data == "0") data = "^";
			searchlist = searchlist + "&org=" + data;
			//local branch
			searchlist = searchlist + "&localbranch=" + txtLocalBranch.Text;
			//other groups
			searchlist = searchlist + "&othgroups=" + txtOtherGroups.Text;
			//reference (pass ^ if All [value=0] is selected)
			data = ReferenceList.SelectedItem.Value;
			if (data == "0") data = "^";
			searchlist = searchlist + "&reference=" + data;
			//in memory of
			searchlist = searchlist + "&memory=" + txtMemoryOf.Text;

			// ----- BUILD SHOW LIST -----
			//station detail
			showlist = showlist + "&fSD=" + ShowDataCheckBox.Items[0].Selected.ToString();
			//individual name
			showlist = showlist + "&fIN=" + ShowDataCheckBox.Items[1].Selected.ToString();
			//individual affiliation (other groups)
			showlist = showlist + "&fOG=" + ShowDataCheckBox.Items[2].Selected.ToString();
			//individual address
			showlist = showlist + "&fIA=" + ShowDataCheckBox.Items[3].Selected.ToString();		
			//organization
			showlist = showlist + "&fOR=" + ShowDataCheckBox.Items[4].Selected.ToString();		
			//check data
			showlist = showlist + "&fCD=" + ShowDataCheckBox.Items[5].Selected.ToString();		
			//reference
			showlist = showlist + "&fR=" + ShowDataCheckBox.Items[6].Selected.ToString();		
			//description
			showlist = showlist + "&fD=" + ShowDataCheckBox.Items[7].Selected.ToString();		
			//ack date
			showlist = showlist + "&fAD=" + ShowDataCheckBox.Items[8].Selected.ToString();		
			//post unit chapter
			showlist = showlist + "&fPU=" + ShowDataCheckBox.Items[9].Selected.ToString();		
			//in memory of
			showlist = showlist + "&fIM=" + ShowDataCheckBox.Items[10].Selected.ToString();		
			//salutation
			showlist = showlist + "&fS=" + ShowDataCheckBox.Items[11].Selected.ToString();		
			//cc
			showlist = showlist + "&fCC=" + ShowDataCheckBox.Items[12].Selected.ToString();		
			//family contact
			showlist = showlist + "&fFC=" + ShowDataCheckBox.Items[13].Selected.ToString();		

			Response.Redirect("../Reports/DonationsDataView.aspx?" + searchlist + showlist + "&StationId=" + VtkPageHeader1.DivSelectedId.ToString());
		}

		private void DivisionList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			//populate organization list
			PopulateOrganizationList();
			//populate GPF list
			PopulateGPFList();
			//populate reference list
			PopulateReferenceList();		
		}
	}
}
