using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using System.Text;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for GamesAddressLabels.
	/// </summary>
	public class GamesAddressLabels : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.DropDownList OrgSvcList;
		protected System.Web.UI.WebControls.DropDownList BirthMonthList;
		protected System.Web.UI.WebControls.DropDownList AgeRangeTo;
		protected System.Web.UI.WebControls.DropDownList AgeRangeFrom;
		protected System.Web.UI.WebControls.Panel AgeRangePanel;
		protected System.Web.UI.WebControls.DropDownList SelectBy;
		protected System.Web.UI.WebControls.Panel PrintPanel;
		protected System.Web.UI.WebControls.CustomValidator SelectByValidator;
		protected System.Web.UI.WebControls.CompareValidator CompareValidator1;
		protected System.Web.UI.WebControls.CustomValidator OrganizationServiceListValidator;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.ListBox GamesListBox;
		protected System.Web.UI.WebControls.Panel GameVolunteersPanel;
		protected System.Web.UI.WebControls.Label PageCount;
		protected System.Web.UI.WebControls.TextBox CurrentPage;
		protected System.Web.UI.WebControls.Panel PagerPanel;
		protected System.Web.UI.WebControls.TextBox SearchText;
		protected System.Web.UI.WebControls.DropDownList SearchOptionList;
		protected System.Web.UI.WebControls.Panel SearchPanel;
		protected System.Web.UI.WebControls.Label RecordLabel;
		protected System.Web.UI.WebControls.DataGrid GameVolunteersGrid;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Address Labels (Games)"))
				{
					Page.RegisterHiddenField("Action", String.Empty);

					if (!Page.IsPostBack) 
					{
						// populate Games List
						PopulateGamesList();
						// initalize age from to
						InitializeAge();
						//disable volunteer button
						GameVolunteersPanel.Visible = false ;
					}					
					else
					{
						if(Request.Form["Action"] != String.Empty)
						{
							if(Request.Form["Action"] == "First")
							{
								Page.Trace.Warn("Action", "First");
								Pager_Click("FIRST");
							}
							else if(Request.Form["Action"] == "Last")
							{
								Page.Trace.Warn("Action", "Last");
								Pager_Click("LAST");
							}
							else if(Request.Form["Action"] == "Next")
							{
								Page.Trace.Warn("Action", "Next");
								Pager_Click("NEXT");
							}
							else if(Request.Form["Action"] == "Prev")
							{
								Page.Trace.Warn("Action", "Prev");
								Pager_Click("PREV");
							}
							else if(Request.Form["Action"] == "Go")
							{
								Page.Trace.Warn("Action", "Go");
								Pager_Click("GO");
							}
							else if(Request.Form["Action"] == "Reset")
							{
								Page.Trace.Warn("Action", "Reset");
								ResetButton();
							}
							else if(Request.Form["Action"] == "Search")
							{
								Page.Trace.Warn("Action", "Search");
								SearchButton();
							}
							else if(Request.Form["Action"] == "Exit")
							{
								Page.Trace.Warn("Action", "Exit");
								ExitButton();
							}
						}
					}
					
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		#region Build Lists

		private void PopulateGamesList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Games.GamesSchedule.GetQuickList();
				ds.Tables["GamesScheduleList"].DefaultView.Sort = "Name";
				DataTable dt = ds.Tables["GamesScheduleList"];
				dt.Columns.Add("GameAndDate", System.Type.GetType("System.String"));
				foreach (DataRow dr in dt.Rows)
				{
					string s = String.Copy(dr["Name"] + " (" + Convert.ToString(Convert.ToDateTime(dr["StartDate"]).ToShortDateString()) + ")");
					dr["GameAndDate"] = s;
				}
				GamesListBox.DataTextField = "GameAndDate";
				GamesListBox.DataValueField = "ID";
				GamesListBox.DataSource = dt;
				GamesListBox.DataBind();
				ds.Dispose();
				dt.Dispose();
				GamesListBox.SelectedIndex = 0;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateServiceList() 
		{
			OrgSvcList.Items.Clear();
			try 
			{
				DataSet dsGameSchedule = Vha.Vtk.Games.GamesSchedule.GetQuickListByGameScheduleId(Convert.ToInt32(GamesListBox.SelectedItem.Value));
				DataTable dtGameSchedule = dsGameSchedule.Tables["GamesList"];
				if (dtGameSchedule.Rows.Count == 1)
				{
					DataRow drGameSchedule = dtGameSchedule.Rows[0];
					//populate list of services, pass the Game Code in [5]
					DataSet ds = Vha.Vtk.Common.Service.GetQuickListForGames(drGameSchedule[5].ToString());
					ds.Tables["GamesServiceCodes"].DefaultView.Sort = "ServiceCode";
					DataTable dt = ds.Tables["GamesServiceCodes"];
					dt.Columns.Add("ServiceAndCode", System.Type.GetType("System.String"));
					foreach (DataRow dr in dt.Rows)
					{
						string s = String.Copy("(" + dr["ServiceCode"] + ")  " + dr["Subdivision"] + " " + dr["ServiceName"]);
						dr["ServiceAndCode"] = s;
					}
					OrgSvcList.DataTextField = "ServiceAndCode";
					OrgSvcList.DataValueField = "ID";
					OrgSvcList.DataSource = dt;
					OrgSvcList.DataBind();
					ds.Dispose();
					dt.Dispose();
				}
				else
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "No services found for game schedule");
				}
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateOrganizationList() 
		{
			OrgSvcList.Items.Clear();
			try 
			{
				DataSet ds = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(
					Convert.ToInt32(GamesListBox.SelectedItem.Value));
				OrgSvcList.DataSource=ds.Tables["OrganizationList"].DefaultView;
				OrgSvcList.DataTextField="DisplayName";
				OrgSvcList.DataValueField="ID";
				OrgSvcList.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
			finally 
			{
				//OrgSvcList.Items.Insert(0, new ListItem(emptyOrgListItemText, emptyListItemValue));
			}
		}

		private void InitializeAge() 
		{
			// populate begin and end list month year
			for (int count = 0; count < 121; count++)
			{
				AgeRangeFrom.Items.Add(count.ToString());
				AgeRangeTo.Items.Add(count.ToString());
			}
			AgeRangeFrom.SelectedIndex=0;
			AgeRangeTo.SelectedIndex=120;
		}

		private void VolGridUpdate()
		{
			//update GameVolunteersGrid
			//bind to grid: [0]=Id, [1]=volId, [2]=stationId, [3]=profileId, [5]=volName, [6]=ssn, [7]=station 
			string sText = string.Empty ;
			string sOption = string.Empty ;
			if (SearchText.Text.Length > 0)
			{ sText = SearchText.Text ;}
			sOption = SearchOptionList.SelectedItem.Value ;

			DataSet ds = Vha.Vtk.Games.GamesRegistration.GetQuickListByGameSchedule(Convert.ToInt32(GamesListBox.SelectedItem.Value)) ;
			//if we have search field, do search, else do sort
			if (sText != string.Empty)
			{ ds.Tables["GamesRegistrationList"].DefaultView.RowFilter =  sOption + " LIKE '" + sText + "*'" ;}
			else
			{ ds.Tables["GamesRegistrationList"].DefaultView.Sort = sOption ;}
			DataTable dt = ds.Tables["GamesRegistrationList"] ;
			//if no rows, show 'no volunteer registered' message and not pager panel
			
			if (dt.Rows.Count != 0)
			{
				GameVolunteersGrid.DataSource = dt ;
				GameVolunteersGrid.DataBind() ;
				SetPagerStats();
				PagerPanel.Visible = true ;
				SearchPanel.Visible = true ;
			}

			ds.Dispose() ;
			dt.Dispose() ;
		}
		#endregion


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.GamesListBox.SelectedIndexChanged += new System.EventHandler(this.SelectBy_SelectedIndexChanged);
			this.SelectBy.SelectedIndexChanged += new System.EventHandler(this.SelectBy_SelectedIndexChanged);
			this.GameVolunteersGrid.PageIndexChanged += new System.Web.UI.WebControls.DataGridPageChangedEventHandler(this.PageGrid);
			this.GameVolunteersGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.VolGridEdit_Click);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


		private void SelectVolunteer()
		{
			VolGridUpdate();
			GameVolunteersPanel.Visible = true;
		}

		private void SelectBy_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			switch (SelectBy.SelectedItem.Value) 
			{
				case "All":
					EnableAll();
					break;
				case "Selected Volunteers":
					EnableSelectedVolunteers();
					SelectVolunteer();
					break;
				case "Age Range":
					EnableAgeRange();
					break;
				case "Birth Month":
					EnableBirthMonth();
					break;
				case "Organization":
					EnableOrganization();
					break;
				case "Service":
					EnableService();
					break;
				case "VAVS":
					EnableVAVS();
					break;
				default:
					break;
			}
		}

		#region Enable Controls

		private void EnableAll() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			GameVolunteersPanel.Visible = false ;
			BirthMonthList.Visible=false;
		}

		private void EnableSelectedVolunteers() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			GameVolunteersPanel.Visible = true ;
			BirthMonthList.Visible=false;
		}

		private void EnableAgeRange() 
		{
			AgeRangePanel.Visible=true;
			OrgSvcList.Visible=false;
			GameVolunteersPanel.Visible = false ;
			BirthMonthList.Visible=false;
		}

		private void EnableBirthMonth() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			GameVolunteersPanel.Visible = false ;
			BirthMonthList.Visible=true;
		}

		private void EnableOrganization() 
		{
			AgeRangePanel.Visible=false;
			GameVolunteersPanel.Visible = false ;
			BirthMonthList.Visible=false;
			PopulateOrganizationList();
			OrgSvcList.Visible=true;
		}

		private void EnableService() 
		{
			AgeRangePanel.Visible=false;
			GameVolunteersPanel.Visible = false ;
			BirthMonthList.Visible=false;
			PopulateServiceList();
			OrgSvcList.Visible=true;
		}

		private void EnableVAVS() 
		{
			AgeRangePanel.Visible=false;
			OrgSvcList.Visible=false;
			GameVolunteersPanel.Visible = false ;
			BirthMonthList.Visible=false;
		}
		#endregion


				
		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();
			//@InstitutionId
			rp.AT_InputGamesScheduleId=Convert.ToInt32(GamesListBox.SelectedItem.Value);
			// select by
			switch (SelectBy.SelectedItem.Value) 
			{
				case "All":
					rp.AT_InputSortBy=1;
					rp.AT_InputList="ALL";
					break;
				case "Selected Volunteers":
					rp.AT_InputSortBy=1;
					rp.AT_InputList = RecordLabel.Text;
					break;
				case "Age Range":
					rp.AT_InputSortBy=3;
					rp.AT_InputFrom=AgeRangeFrom.SelectedItem.Value;
					rp.AT_InputTo=AgeRangeTo.SelectedItem.Value;
					break;
				case "Birth Month":
					rp.AT_InputSortBy=4;
					rp.AT_InputList=BirthMonthList.SelectedItem.Value;
					break;
				case "Organization":
					rp.AT_InputSortBy=5;
					rp.AT_InputList=OrgSvcList.SelectedItem.Value;
					break;
				case "Service":
					rp.AT_InputSortBy=6;
					rp.AT_InputList=OrgSvcList.SelectedItem.Value;
					break;
				case "VAVS":
					rp.AT_InputSortBy=7;
					break;
				default:
					break;
			}
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// reportType
			rp.ReportType=UIReportType.VtkSG_GamesAddressLabels;
			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;
			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}
		
		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public int AT_InputGamesScheduleId;
			public int AT_InputSortBy;
			public string AT_InputFrom;
			public string AT_InputTo;
			public string AT_InputList;

			public UIReportParams() 
			{
				AT_InputGamesScheduleId=0;
				AT_InputSortBy=0;
				AT_InputFrom="";
				AT_InputTo="";
				AT_InputList="";
			}
		}

		#region Section: Private Events


		private void VolGridEdit_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			try
			{
				//get information from grid
				ViewState["VolunteerId"] = e.Item.Cells[1].Text.ToString() ;
				RecordLabel.Text = ViewState["VolunteerId"].ToString() ;
			    PrintButton_Click(source, e);
			} 
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer Information: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer Information: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer Information: " + err.Message) ;}
		}

		#endregion

		#region Paging Data

		private void PageGrid(object obj, DataGridPageChangedEventArgs e)
		{
			GameVolunteersGrid.CurrentPageIndex = 0;
			VolGridUpdate() ;
		}

		private void SetPagerStats()
		{
			int pageCount;
			int currentPageIndex;

			currentPageIndex = GameVolunteersGrid.CurrentPageIndex + 1;
			pageCount = GameVolunteersGrid.PageCount;

			CurrentPage.Text = currentPageIndex.ToString();
			PageCount.Text = pageCount.ToString();
		}
		#endregion

		#region Button Controls

		private void Pager_Click(string ActionItem)
		{			
			switch(ActionItem)
			{
				case "PREV":
					if(GameVolunteersGrid.CurrentPageIndex > 0)
						GameVolunteersGrid.CurrentPageIndex --;
					break;
				case "NEXT":
					if(GameVolunteersGrid.CurrentPageIndex < (GameVolunteersGrid.PageCount - 1))
						GameVolunteersGrid.CurrentPageIndex ++;
					break;
				case "GO":
					if((Convert.ToInt32(CurrentPage.Text) <= GameVolunteersGrid.PageCount) && (Convert.ToInt32(CurrentPage.Text) != 0))
					{
						GameVolunteersGrid.CurrentPageIndex = Convert.ToInt32(CurrentPage.Text) - 1;
					}
					break;
				case "FIRST":
					GameVolunteersGrid.CurrentPageIndex = 0;
					break;
				case "LAST":					
					GameVolunteersGrid.CurrentPageIndex = GameVolunteersGrid.PageCount - 1;
					break;
			}

			CurrentPage.Text = GameVolunteersGrid.CurrentPageIndex.ToString();
			VolGridUpdate() ;
		}

		private void ResetButton()
		{
			try
			{
				//reset search fields
				SearchText.Text = string.Empty ;
				SearchOptionList.SelectedIndex = 0 ;
				GameVolunteersGrid.CurrentPageIndex = 0;
				VolGridUpdate() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + err.Message) ;}
		}

		private void SearchButton()
		{
			//Perform search for the Volunteer Pager
			if (SearchText != null)
			{
				try
				{
					GameVolunteersGrid.CurrentPageIndex = 0;
					VolGridUpdate() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must enter a Name to use for searching!") ;}
		}

		private void ExitButton()
		{
			Response.Redirect("../Index.aspx?" + VtkPageHeader.GetURLParameterString() + "=" + VtkPageHeader1.DivSelectedId.ToString());
		}

		#endregion


	}
}
