using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for GamesServiceRSHours.
	/// </summary>
	public class GamesServiceRSHours : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.ListBox SelectedSvcListBox;
		protected System.Web.UI.WebControls.ListBox ServiceListBox;
		protected System.Web.UI.WebControls.RequiredFieldValidator SvcListBoxValidator;
		protected System.Web.UI.WebControls.DropDownList FiscalYearList;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidator1;
		protected System.Web.UI.WebControls.ListBox GamesListBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		const string emptySelectedListItemText = " - select services from list - ";
		const string emptySelectedListItemValue = "-1";
		const string emptyServiceListItemText = " - no services to select from - ";
		protected System.Web.UI.WebControls.RadioButtonList ShowDetailRadioButtonList1;
		const string emptyServiceListItemValue = "-1";
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Service Regular Scheduled Hours"))
				{
					Page.RegisterHiddenField("Action", String.Empty);
					ServiceListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					SelectedSvcListBox.Attributes.Add("OnClick", "Set_NoBlank()");

					if (!Page.IsPostBack)
					{
						InitializePageControls();
						// populate Games List
						PopulateGamesList();
						// populate games service list
						PopulateServiceList();
						// populate the fiscal year list
						PopulateFiscalYearList();
					}
					else
					{
						if(Request.Form["Action"] != String.Empty)
						{
							if(Request.Form["Action"] == "Add")
							{
								Page.Trace.Warn("Action", "Add");
								AddSvcButton();
							}
							else if (Request.Form["Action"] == "AddAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								AddAllSvcButton();
							}
							else if (Request.Form["Action"] == "RemoveAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								RemoveAllSvcButton();
							}
							else //action = remove
							{
								Page.Trace.Warn("Action", "Remove");
								RemoveSvcButton();
							}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void InitializePageControls()
		{
			// clear the service boxes
			ServiceListBox.Items.Clear();
			SelectedSvcListBox.Items.Clear();

			// if the service boxes are clear, set to "no services to choose from"
			if (ServiceListBox.Items.Count==0) 
			{
				ServiceListBox.Items.Add(new ListItem(emptyServiceListItemText,emptyServiceListItemValue.ToString()));
			}
			if (SelectedSvcListBox.Items.Count==0) 
			{
				SelectedSvcListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
			}
		}

		private void PopulateGamesList() 
		{
			// (Only allow one division per, because org list is based on division)
			try 
			{
				DataSet ds = Vha.Vtk.Games.GamesSchedule.GetQuickList();
				ds.Tables["GamesScheduleList"].DefaultView.Sort = "Name";
				DataTable dt = ds.Tables["GamesScheduleList"];
				dt.Columns.Add("GameAndDate", System.Type.GetType("System.String"));
				foreach (DataRow dr in dt.Rows)
				{
					string s = String.Copy(dr["Name"] + " (" + Convert.ToString(Convert.ToDateTime(dr["StartDate"]).ToShortDateString()) + ")");
					dr["GameAndDate"] = s;
				}
				GamesListBox.DataTextField = "GameAndDate";
				GamesListBox.DataValueField = "ID";
				GamesListBox.DataSource = dt;
				GamesListBox.DataBind();
				ds.Dispose();
				dt.Dispose();
				GamesListBox.SelectedIndex = 0;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateServiceList() 
		{
			try 
			{
				DataSet dsGameSchedule = Vha.Vtk.Games.GamesSchedule.GetQuickListByGameScheduleId(Convert.ToInt32(GamesListBox.SelectedItem.Value));
				DataTable dtGameSchedule = dsGameSchedule.Tables["GamesList"];

				if (dtGameSchedule.Rows.Count == 1)
				{
					DataRow drGameSchedule = dtGameSchedule.Rows[0];
					//populate list of services, pass the Game Code in [5]
					DataSet ds = Vha.Vtk.Common.Service.GetQuickListForGames(drGameSchedule[5].ToString());
					ds.Tables["GamesServiceCodes"].DefaultView.Sort = "ServiceCode";
					DataTable dt = ds.Tables["GamesServiceCodes"];
					dt.Columns.Add("ServiceAndCode", System.Type.GetType("System.String"));
					foreach (DataRow dr in dt.Rows)
					{
						string s = String.Copy("(" + dr["ServiceCode"] + ")  " + dr["Subdivision"] + " " + dr["ServiceName"]);
						dr["ServiceAndCode"] = s;
					}
					ServiceListBox.DataTextField = "ServiceAndCode";
					ServiceListBox.DataValueField = "ID";
					ServiceListBox.DataSource = dt;
					ServiceListBox.DataBind();
					ds.Dispose();
					dt.Dispose();
				}
				else
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "No services found for game schedule");
					InitializePageControls();
				}
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateFiscalYearList() 
		{
			int currentFiscalYear=VtkUtility.GetCurrentFiscalYear();
			// start from 1990 to current
			for (int i=1990;i<=currentFiscalYear;i++)
			{
				FiscalYearList.Items.Add(new ListItem(i.ToString(),i.ToString()));
			}
			// set current fiscal year as default.  the last entry in the list is the current fiscal year
			// and is indexed as count-1 (since the item list starts at 0)
			FiscalYearList.SelectedIndex=FiscalYearList.Items.Count-1;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.GamesListBox.SelectedIndexChanged += new System.EventHandler(this.GameScheduleListBox_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void GameScheduleListBox_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			InitializePageControls();
			PopulateServiceList();
		}

		private void AddSvcButton()
		{
			//make sure item is selected
			if (ServiceListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (ServiceListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering svcs, remove it
					if (SelectedSvcListBox.Items[0].Value=="-1") 
					{
						SelectedSvcListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(ServiceListBox, SelectedSvcListBox);
				}
			}
			//if the service list box has no items, add the text for adding new ones
			if (ServiceListBox.Items.Count==0) 
			{
				ServiceListBox.Items.Add(new ListItem(emptyServiceListItemText,emptyServiceListItemValue.ToString()));
			}
		}

		private void AddAllSvcButton()
		{
			//only add all items if there are services to select from
			if (ServiceListBox.Items[0].Value != "-1")
			{
				//remove all selected services first
				SelectedSvcListBox.Items.Clear();
				ServiceListBox.Items.Clear();
				// re-populate service list
				PopulateServiceList();
				//add all services
				for (int i=0;i<ServiceListBox.Items.Count;i++)
				{
					ServiceListBox.SelectedIndex=i;
					SelectedSvcListBox.Items.Add(new ListItem(ServiceListBox.SelectedItem.Text, ServiceListBox.SelectedItem.Value));
				}
				ServiceListBox.Items.Clear();
				ServiceListBox.Items.Add(new ListItem(emptyServiceListItemText,emptyServiceListItemValue.ToString()));
				//set the focus on the first item in selected list (to keep the validator from firing)
				SelectedSvcListBox.SelectedIndex=0;
			}
		}

		private void RemoveSvcButton()
		{
			//make sure item is selected
			if (SelectedSvcListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (SelectedSvcListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering svcs, remove it
					if (ServiceListBox.Items[0].Value=="-1") 
					{
						ServiceListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(SelectedSvcListBox, ServiceListBox);
				}
				//if the selected list box has no items, add the text for adding new ones
				if (SelectedSvcListBox.Items.Count==0) 
				{
					SelectedSvcListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
				}
				else
				{
					//set the focus on the first item in selected list (to keep the validator from firing)
					SelectedSvcListBox.SelectedIndex=0;
				}
			}
		}

		private void RemoveAllSvcButton()
		{
			// populate service list
			PopulateServiceList();
			//remove all selected services
			SelectedSvcListBox.Items.Clear();
			//add the selection text
			SelectedSvcListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
		}

		//move selected item from one list to the other
		private void MoveSelectedItem(ListBox FromList, ListBox ToList) 
		{
			// if item selected, remove it from svc list and add it to selected list
			while (FromList.SelectedIndex>-1) 
			{
				ListItem li = new ListItem(FromList.SelectedItem.Text,
					FromList.SelectedItem.Value);
				FromList.Items.RemoveAt(FromList.SelectedIndex);
				int pos=-1;
				for (int i=0;i<ToList.Items.Count;i++) 
				{
					if (String.Compare(ToList.Items[i].Text, li.Text,
						true, System.Globalization.CultureInfo.CurrentUICulture)>=0) 
					{
						pos=i;
						break;
					}
				}
				if (pos>-1) 
				{
					ToList.Items.Insert(pos,li);
				} 
				else 
				{
					ToList.Items.Add(li);
				}
			}
			if(ToList.Items.Count > 0)
			{
				ToList.SelectedIndex = 0;
			}
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// report type (name of crystal report file)
			rp.ReportType=UIReportType.VtkSG_GamesServiceRSHours;
			// selected games schedule
			rp.AT_InputGamesScheduleId=Convert.ToInt32(GamesListBox.SelectedItem.Value);
			// fiscal year
			rp.AT_InputFiscalYear=Convert.ToInt32(FiscalYearList.SelectedItem.Value);
			// show detail on report
			rp.AT_InputShowDetail=0;
			if (ShowDetailRadioButtonList1.SelectedIndex == 1) rp.AT_InputShowDetail=1;
			// Build input service list
			foreach (ListItem li in SelectedSvcListBox.Items) 
			{
				rp.AT_InputSvcIdList+=li.Value+"^";
			}
			// if all selected, set to ^
			if (ServiceListBox.Items[0].Value=="-1")
			{
				rp.AT_InputSvcIdList="^";
			}
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public int AT_InputGamesScheduleId;
			public string AT_InputSvcIdList;
			public int AT_InputFiscalYear;
			public int AT_InputShowDetail;

			public UIReportParams() 
			{
				AT_InputGamesScheduleId=0;
				AT_InputSvcIdList="";
				AT_InputFiscalYear=2003;
				AT_InputShowDetail=0;
			}
		}	
	}
}
