using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for GamesTelephoneList.
	/// </summary>
	public class GamesTelephoneList : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidator1;
		protected System.Web.UI.WebControls.ListBox GamesListBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Telephone List (Games)"))
				{
					if (!Page.IsPostBack)
					{
						// populate Games List
						PopulateGamesList();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateGamesList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Games.GamesSchedule.GetQuickList();
				ds.Tables["GamesScheduleList"].DefaultView.Sort = "Name";
				DataTable dt = ds.Tables["GamesScheduleList"];
				dt.Columns.Add("GameAndDate", System.Type.GetType("System.String"));
				foreach (DataRow dr in dt.Rows)
				{
					string s = String.Copy(dr["Name"] + " (" + Convert.ToString(Convert.ToDateTime(dr["StartDate"]).ToShortDateString()) + ")");
					dr["GameAndDate"] = s;
				}
				GamesListBox.DataTextField = "GameAndDate";
				GamesListBox.DataValueField = "ID";
				GamesListBox.DataSource = dt;
				GamesListBox.DataBind();
				ds.Dispose();
				dt.Dispose();
				GamesListBox.SelectedIndex = 0;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// report type (name of crystal report file)
			rp.ReportType=UIReportType.VtkSG_GamesTelephoneList;
			// selected games schedule
			rp.AT_InputGamesScheduleId=Convert.ToInt32(GamesListBox.SelectedItem.Value);
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public int AT_InputGamesScheduleId;

			public UIReportParams() 
			{
				AT_InputGamesScheduleId=0;
			}
		}	
	}
}
