using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for HoursByService.
	/// </summary>
	public class HoursByService : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		const string emptySelectedListItemText = " - select services from list - ";
		const string emptySelectedListItemValue = "-1";
		const string emptyServiceListItemText = " - no services to select from - ";
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.CompareValidator BeginEndDateValidator;
		protected System.Web.UI.WebControls.DropDownList EndMonthYearList;
		protected System.Web.UI.WebControls.DropDownList BegMonthYearList;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.ListBox SelectedSvcListBox;
		protected System.Web.UI.WebControls.ListBox ServiceListBox;
		protected System.Web.UI.WebControls.RequiredFieldValidator SvcListBoxValidator;
		const string emptyServiceListItemValue = "-1";
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Hours By Service"))
				{
					Page.RegisterHiddenField("Action", String.Empty);
					ServiceListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					SelectedSvcListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						// populate fiscal year list
						InitializeDates();
						// remove all selected services and populate service list
						RemoveAllSvcButton();
					}
					else
					{
						if(Request.Form["Action"] != String.Empty)
						{
							if(Request.Form["Action"] == "Add")
							{
								Page.Trace.Warn("Action", "Add");
								AddSvcButton();
							}
							else if (Request.Form["Action"] == "AddAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								AddAllSvcButton();
							}
							else if (Request.Form["Action"] == "RemoveAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								RemoveAllSvcButton();
							}
							else //action = remove
							{
								Page.Trace.Warn("Action", "Remove");
								RemoveSvcButton();
							}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}
		
		private void InitializeDates() 
		{
			// populate begin and end list month year
			int count=0;
			for (int year = 1990; year < (System.DateTime.Today.Year+2); year++)
			{
				for (int month = 1; month < 13; month++)
				{
					// put a 0 in front of the month if it is month 1-9, you need this or the validator will fail
					string monthdisplay = month.ToString();
					if (month < 10) monthdisplay = "0" + monthdisplay;

					count = count + 1;
					if (new DateTime(year, month, 1) < System.DateTime.Today)
					{
						BegMonthYearList.Items.Add(monthdisplay + "/01/" + year.ToString());
						EndMonthYearList.Items.Add(monthdisplay + "/" + System.DateTime.DaysInMonth(year, month).ToString() + "/" + year.ToString());
					}
					// stop if greater than current month year
					else break;
				}
			}
			// set current month year as default.  the last entry in the list is the current month year
			// and is indexed as count-1 (since the item list starts at 0)
			BegMonthYearList.SelectedIndex=BegMonthYearList.Items.Count-1;
			EndMonthYearList.SelectedIndex=EndMonthYearList.Items.Count-1;
		}

		private void PopulateServiceList() 
		{
			// (Only allow one division per, because svc list is based on division)
			try 
			{
				//populate list of services
				DataSet ds = Service.GetSiteQuickListByName(Convert.ToInt32(DivisionList.SelectedItem.Value));
				ServiceListBox.DataSource=ds.Tables["ServiceList"].DefaultView;
				ServiceListBox.DataTextField="DisplayName";
				ServiceListBox.DataValueField="ID";
				ServiceListBox.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.DivisionList.SelectedIndexChanged += new System.EventHandler(this.DivisionList_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void AddSvcButton()
		{
			//make sure item is selected
			if (ServiceListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (ServiceListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering svcs, remove it
					if (SelectedSvcListBox.Items[0].Value=="-1") 
					{
						SelectedSvcListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(ServiceListBox, SelectedSvcListBox);
				}
			}
			//if the service list box has no items, add the text for adding new ones
			if (ServiceListBox.Items.Count==0) 
			{
				ServiceListBox.Items.Add(new ListItem(emptyServiceListItemText,emptyServiceListItemValue.ToString()));
			}
		}

		private void AddAllSvcButton()
		{
			//remove all selected services first
			SelectedSvcListBox.Items.Clear();
			ServiceListBox.Items.Clear();
			// re-populate service list
			PopulateServiceList();
			//add all services
			for (int i=0;i<ServiceListBox.Items.Count;i++)
			{
				ServiceListBox.SelectedIndex=i;
				SelectedSvcListBox.Items.Add(new ListItem(ServiceListBox.SelectedItem.Text, ServiceListBox.SelectedItem.Value));
			}
			ServiceListBox.Items.Clear();
			ServiceListBox.Items.Add(new ListItem(emptyServiceListItemText,emptyServiceListItemValue.ToString()));
			//set the focus on the first item in selected list (to keep the validator from firing)
			SelectedSvcListBox.SelectedIndex=0;
		}

		private void RemoveSvcButton()
		{
			//make sure item is selected
			if (SelectedSvcListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (SelectedSvcListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering svcs, remove it
					if (ServiceListBox.Items[0].Value=="-1") 
					{
						ServiceListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(SelectedSvcListBox, ServiceListBox);
				}
				//if the selected list box has no items, add the text for adding new ones
				if (SelectedSvcListBox.Items.Count==0) 
				{
					SelectedSvcListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
				}
				else
				{
					//set the focus on the first item in selected list (to keep the validator from firing)
					SelectedSvcListBox.SelectedIndex=0;
				}
			}
		}

		private void RemoveAllSvcButton()
		{
			// populate service list
			PopulateServiceList();
			//remove all selected services
			SelectedSvcListBox.Items.Clear();
			//add the selection text
			SelectedSvcListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
		}

		//move selected item from one list to the other
		private void MoveSelectedItem(ListBox FromList, ListBox ToList) 
		{
			// if item selected, remove it from svc list and add it to selected list
			while (FromList.SelectedIndex>-1) 
			{
				ListItem li = new ListItem(FromList.SelectedItem.Text,
					FromList.SelectedItem.Value);
				FromList.Items.RemoveAt(FromList.SelectedIndex);
				int pos=-1;
				for (int i=0;i<ToList.Items.Count;i++) 
				{
					if (String.Compare(ToList.Items[i].Text, li.Text,
						true, System.Globalization.CultureInfo.CurrentUICulture)>=0) 
					{
						pos=i;
						break;
					}
				}
				if (pos>-1) 
				{
					ToList.Items.Insert(pos,li);
				} 
				else 
				{
					ToList.Items.Add(li);
				}
			}
			if(ToList.Items.Count > 0)
			{
				ToList.SelectedIndex = 0;
			}
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// Build input institution list
			foreach (ListItem li in DivisionList.Items) 
			{
				if (li.Selected) 
				{
					rp.AT_InputInstIdList+=li.Value+"^";
				}
			}

			// Build input service list
			foreach (ListItem li in SelectedSvcListBox.Items) 
			{
				rp.AT_InputServiceIdList+=li.Value+"^";
			}
			// if all selected, set to ^
			if (ServiceListBox.Items[0].Value=="-1")
			{
				rp.AT_InputServiceIdList="^";
			}

			// set up the begin and end month year for the report
			rp.AT_InputBeginDate=Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
			rp.AT_InputEndDate=Convert.ToDateTime(EndMonthYearList.SelectedItem.Value);

			// report type
			rp.ReportType=UIReportType.VtkSL_HoursByService_Day;

			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;


			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		private void DivisionList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			// remove all selected services and populate service list
			RemoveAllSvcButton();
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public string AT_InputInstIdList;
			public string AT_InputServiceIdList;
			public DateTime AT_InputBeginDate;
			public DateTime AT_InputEndDate;

			public UIReportParams() 
			{
				AT_InputInstIdList="";
				AT_InputServiceIdList="";
				AT_InputBeginDate=DateTime.Today;
				AT_InputEndDate=DateTime.Today;
			}
		}
	}
}
