using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for TerminatedVolunteers.
	/// </summary>
	public class TerminatedVolunteers : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.DropDownList BegMonthYearList;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidator1;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Terminated Volunteers"))
				{
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						// initialize dates
						InitializeDates();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void InitializeDates() 
		{
			// populate begin and end list month year
			int count=0;
			for (int year = 1990; year < (System.DateTime.Today.Year+1); year++)
			{
				for (int month = 1; month < 13; month++)
				{
					count = count + 1;
					BegMonthYearList.Items.Add(VtkUtility.MonthToString(month) + " " + year.ToString());

					// stop if current month year
					if ((month.ToString() + "/" + year.ToString()) == 
						(System.Convert.ToString(System.DateTime.Today.ToString("M/yyyy"))))
					{
						break;
					}
				}
			}
			// set today as default.  the last entry in the list is the current month year
			// and is indexed as count-1 (since the item list starts at 0)
			int begmonthcounter=BegMonthYearList.Items.Count-1;
			if (begmonthcounter<0) begmonthcounter=0;
			BegMonthYearList.SelectedIndex=begmonthcounter;
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// report type (name of crystal report file)
			rp.ReportType=UIReportType.VtkSL_TerminatedVolunteers;
			
			// Build input institution list
			foreach (ListItem li in DivisionList.Items) 
			{
				if (li.Selected) 
				{
					rp.AT_InputInstIdList+=li.Value+"^";
				}
			}

			// date input
			rp.AT_InputDate=Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public string AT_InputInstIdList;
			public DateTime AT_InputDate;

			public UIReportParams() 
			{
				AT_InputInstIdList="";
				AT_InputDate=DateTime.Today;
			}
		}
	}	
}
