using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

// add these classes to each report user interface
// ==========================================================================
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;
// ==========================================================================

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for VNONationalOfficialsLabels.
	/// </summary>
	public class VNONationalOfficialsLabels : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.RadioButtonList SelectTypeRadioButton;
		protected System.Web.UI.WebControls.ListBox IndividualsListBox;
		protected System.Web.UI.WebControls.ListBox SelectedIndividualsListBox;
		protected System.Web.UI.WebControls.DropDownList SkipLabelCount;
		protected System.Web.UI.WebControls.Label AvailableLabel;
		protected System.Web.UI.WebControls.Label SelectedLabel;
		protected System.Web.UI.WebControls.CustomValidator SelectTypeValidator;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		const string emptySelectedListItemText = " - select individuals from list - ";
		const string emptySelectedListItemValue = "-1";
		const string emptyIndividualListItemText = " - no individuals to select from - ";
		protected System.Web.UI.WebControls.RequiredFieldValidator IndividualListBoxValidator;
		protected System.Web.UI.WebControls.Panel IndividualPanel;
		const string emptyIndividualListItemValue = "-1";
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Labels"))
				{
					Page.RegisterHiddenField("Action", String.Empty);
					IndividualsListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					SelectedIndividualsListBox.Attributes.Add("OnClick", "Set_NoBlank()");

					if (!Page.IsPostBack)
					{
						PopulateSkipLabelCount();
						PopulateIndividuals();
						SelectedIndividualsListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
					}
					else
					{
						if(Request.Form["Action"] != String.Empty)
						{
							if(Request.Form["Action"] == "Add")
							{
								Page.Trace.Warn("Action", "Add");
								AddIndividualButton();
							}
							else if (Request.Form["Action"] == "AddAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								AddAllIndividualButton();
							}
							else if (Request.Form["Action"] == "RemoveAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								RemoveAllIndividualButton();
							}
							else //action = remove
							{
								Page.Trace.Warn("Action", "Remove");
								RemoveIndividualButton();
							}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateSkipLabelCount()
		{
			try
			{
				SkipLabelCount.Items.Clear();
				for (int i = 0; i <= 27; i++)
				{
					SkipLabelCount.Items.Add(i.ToString());
				}
			}
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		private void PopulateIndividuals() 
		{
			try 
			{
				// clear individual box
				IndividualsListBox.Items.Clear();

				// determine list type "R"eps, "D"eps, "C"ertified Nat Officials, or "A"ll
				string type = "";
				if (SelectTypeRadioButton.SelectedItem.Value=="R") type = "R";
				if (SelectTypeRadioButton.SelectedItem.Value=="D") type = "D";
				if (SelectTypeRadioButton.SelectedItem.Value=="C") type = "C";
				if (SelectTypeRadioButton.SelectedItem.Value=="A") type = "A";
				// select by individual (All)
				if (type == "A")
				{
					DataSet ds = Vha.Vtk.NationalOfficials.NationalOfficials.GetNationalRepsDepsQuickList("");
					IndividualsListBox.DataSource=ds.Tables["NationalOfficialsList"].DefaultView;
					IndividualsListBox.DataTextField="LastName";
					IndividualsListBox.DataValueField="ID";
					IndividualsListBox.DataBind();
					ds.Dispose();
					// turn the panel on
					IndividualPanel.Visible=true;
					// set the text
					AvailableLabel.Text = "Available Individuals";
					SelectedLabel.Text = "Selected Individuals";
					IndividualListBoxValidator.ErrorMessage = "Select an Individual.";
				}
				// select by organization (for type=R, D, or C)
				else if (type != "")
				{
					DataSet ds = Vha.Vtk.Common.Organization.GetNationalQuickListByCode();
					IndividualsListBox.DataSource=ds.Tables["OrganizationList"].DefaultView;
					IndividualsListBox.DataTextField="Name";
					IndividualsListBox.DataValueField="ID";
					IndividualsListBox.DataBind();
					ds.Dispose();
					// turn the panel on
					IndividualPanel.Visible=true;
					// set the text
					AvailableLabel.Text = "Available Organizations";
					SelectedLabel.Text = "Selected Organizations";
					IndividualListBoxValidator.ErrorMessage = "Select an Organization.";
				}
				else IndividualPanel.Visible=false;
			} 
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the National Officials List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the National Officials List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the National Officials List: " + err.Message) ;}
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.SelectTypeRadioButton.SelectedIndexChanged += new System.EventHandler(this.SelectTypeRadioButton_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void AddIndividualButton()
		{
			//make sure item is selected
			if (IndividualsListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (IndividualsListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering Individual, remove it
					if (SelectedIndividualsListBox.Items[0].Value=="-1") 
					{
						SelectedIndividualsListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(IndividualsListBox, SelectedIndividualsListBox);
				}
			}
			//if the Individual list box has no items, add the text for adding new ones
			if (IndividualsListBox.Items.Count==0) 
			{
				IndividualsListBox.Items.Add(new ListItem(emptyIndividualListItemText,emptyIndividualListItemValue.ToString()));
			}
		}

		private void AddAllIndividualButton()
		{
			//remove all selected Individuals first
			SelectedIndividualsListBox.Items.Clear();
			IndividualsListBox.Items.Clear();
			// re-populate organization list
			PopulateIndividuals();
			//add all Individuals
			for (int i=0;i<IndividualsListBox.Items.Count;i++)
			{
				IndividualsListBox.SelectedIndex=i;
				SelectedIndividualsListBox.Items.Add(new ListItem(IndividualsListBox.SelectedItem.Text, IndividualsListBox.SelectedItem.Value));
			}
			IndividualsListBox.Items.Clear();
			IndividualsListBox.Items.Add(new ListItem(emptyIndividualListItemText,emptyIndividualListItemValue.ToString()));
			//set the focus on the first item in selected list (to keep the validator from firing)
			SelectedIndividualsListBox.SelectedIndex=0;
		}

		private void RemoveIndividualButton()
		{
			//make sure item is selected
			if (SelectedIndividualsListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (SelectedIndividualsListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering orgs, remove it
					if (IndividualsListBox.Items[0].Value=="-1") 
					{
						IndividualsListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(SelectedIndividualsListBox, IndividualsListBox);
				}
				//if the selected list box has no items, add the text for adding new ones
				if (SelectedIndividualsListBox.Items.Count==0) 
				{
					SelectedIndividualsListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
				}
				else
				{
					//set the focus on the first item in selected list (to keep the validator from firing)
					SelectedIndividualsListBox.SelectedIndex=0;
				}
			}
		}

		private void RemoveAllIndividualButton()
		{
			// populate Individual list
			PopulateIndividuals();
			//remove all selected Individuals
			SelectedIndividualsListBox.Items.Clear();
			//add the selection text
			SelectedIndividualsListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
		}

		//move selected item from one list to the other
		private void MoveSelectedItem(ListBox FromList, ListBox ToList) 
		{
			// if item selected, remove it from Org list and add it to selected list
			while (FromList.SelectedIndex>-1) 
			{
				ListItem li = new ListItem(FromList.SelectedItem.Text,
					FromList.SelectedItem.Value);
				FromList.Items.RemoveAt(FromList.SelectedIndex);
				int pos=-1;
				for (int i=0;i<ToList.Items.Count;i++) 
				{
					if (String.Compare(ToList.Items[i].Text, li.Text,
						true, System.Globalization.CultureInfo.CurrentUICulture)>=0) 
					{
						pos=i;
						break;
					}
				}
				if (pos>-1) 
				{
					ToList.Items.Insert(pos,li);
				} 
				else 
				{
					ToList.Items.Add(li);
				}
			}
			if(ToList.Items.Count > 0)
			{
				ToList.SelectedIndex = 0;
			}
		}

		private void SelectTypeRadioButton_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			RemoveAllIndividualButton();
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// report type (name of crystal report file)
			rp.ReportType=UIReportType.VtkSNO_VoluntaryAllNatRepsLabels;
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// type of selection: 'C'ertifying Official, 'N'ational Representative
			rp.AT_InputTypeCN=SelectTypeRadioButton.SelectedItem.Value;
			// skip label count
			rp.AT_InputSkipLabel=Convert.ToInt32(SkipLabelCount.SelectedItem.Value);

			if (SelectTypeRadioButton.SelectedItem.Value=="RO") rp.AT_InputNatOfficialIdList="^";
			else if (SelectTypeRadioButton.SelectedItem.Value=="AO") rp.AT_InputNatOfficialIdList="^";
			else
			{
				// Build input national official list
				foreach (ListItem li in SelectedIndividualsListBox.Items) 
				{
					rp.AT_InputNatOfficialIdList+=li.Value+"^";
				}
				// if all selected, set to ^
				if (IndividualsListBox.Items[0].Value=="-1")
				{
					rp.AT_InputNatOfficialIdList="^";
				}
			}

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;
			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public string AT_InputNatOfficialIdList;
			public string AT_InputTypeCN;
			public int AT_InputSkipLabel;

			public UIReportParams() 
			{
				AT_InputNatOfficialIdList="^";
				AT_InputTypeCN="C";
				AT_InputSkipLabel=0;
			}
		}
	}
}
