using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

// add these classes to each report user interface
// ==========================================================================
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;
// ==========================================================================

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for VSDProgramsSupervised.
	/// </summary>
	public class VSDProgramsSupervised : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.ListBox ProgramsListBox;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidatorSortByListBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Supervised Programs"))
				{
					if (!Page.IsPostBack)
					{
						PopulateProgramsList();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateProgramsList() 
		{
			// add all supervised programs to list box
			try 
			{
				DataSet ds = Vha.Vtk.ServicesDirectory.Programs.GetVoluntaryPrograms(2, VtkUtility.GetAppCon());
				ProgramsListBox.DataSource=ds.Tables["ProgramsList"].DefaultView;
				ProgramsListBox.DataTextField="ProgramName";
				ProgramsListBox.DataValueField="ProgramID";
				ProgramsListBox.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.ProgramsListBox.SelectedIndexChanged += new System.EventHandler(this.ProgramsListBox_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			if (ValidateForm()) 
			{
				UIReportParams rp = new UIReportParams();

				// report type (name of crystal report file)
				rp.ReportType=UIReportType.VtkS_VoluntaryProgramsSupervised;
				// report format
				rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
				// selected program supervised
				rp.AT_InputProgramSupervised=Convert.ToInt32(ProgramsListBox.SelectedItem.Value);

				// Put UIParams into Context
				Context.Items["ReportParams"]=rp;

				// transfer
				if (rp.ReportFormat==UIReportFormat.Web) 
				{
					Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
				} 
				else 
				{
					Server.Transfer("../RptCR/CrystalExport.aspx");
				}
			}

		}
		// ==================================================================
		// verify and validate the input on the web form
		private bool ValidateForm() 
		{
			bool printOKFlag=true;
			//
			// put code here to validate input on form
			// validate a selected program supervised
			if (ProgramsListBox.SelectedIndex<0)
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a program supervised");
			}
			//
			return printOKFlag;
		}

		private void ProgramsListBox_SelectedIndexChanged(object sender, System.EventArgs e)
		{
		
		}
		// ==================================================================
		// initialize the report parameters (called from print click)
		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public int AT_InputProgramSupervised;

			public UIReportParams() 
			{
				AT_InputProgramSupervised=0;
			}
			//
		}
		// ==================================================================

	}
}
