using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

// add these classes to each report user interface
// ==========================================================================
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;
// ==========================================================================

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for VSDStationInformationDetail.
	/// </summary>
	public class VSDStationInformationDetail : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.DropDownList InstitutionList;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidatorSortByListBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Station Information Detail"))
				{
					if (!Page.IsPostBack)
					{
						PopulateInstitutionList();
						// set the default institution to the one the user entered on
						VtkUtility.SetSelectedSingle(InstitutionList.Items, VtkPageHeader1.DivSelectedId.ToString());
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateInstitutionList() 
		{
			// add all supervised programs to list box
			try 
			{
				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickList();
				ds.Tables["InstitutionList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable idt = ds.Tables["InstitutionList"] ;
				//define columns in list box
				InstitutionList.DataTextField = "DisplayName" ;
				InstitutionList.DataValueField = "ID" ;
				InstitutionList.DataSource = idt ;
				InstitutionList.DataBind() ;
				ds.Dispose() ;
				idt.Dispose() ;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// report type (name of crystal report file)
			rp.ReportType=UIReportType.VtkS_VoluntarySingleStationInformation;
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// selected Institution
			rp.AT_InputInstId=Convert.ToInt32(InstitutionList.SelectedItem.Value);

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}
		// ==================================================================
		// initialize the report parameters (called from print click)
		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public int AT_InputInstId;

			public UIReportParams() 
			{
				AT_InputInstId=0;
			}
			//
		}
		// ==================================================================
	}
}
