namespace VTK.RptCR
{
  using System;
  using System.Collections;
  using System.Collections.Specialized;
  using System.ComponentModel;
  using System.Data;
  using System.Drawing;
  using System.Web;
  using System.Web.SessionState;
  using System.Web.UI;
  using System.Web.UI.WebControls;
  using System.Web.UI.HtmlControls;

	using CrystalDecisions.Web;
  using CrystalDecisions.CrystalReports.Engine;
  using CREngine = CrystalDecisions.CrystalReports.Engine;
	using CrystalDecisions.Shared;
	using System.Data.SqlClient;
	using System.Diagnostics;
	using Vha.Vtk;
	using VTK.Utility;
	using VTK.RptCR;
	using VTK.Reports;
	using VTK.FileMaintenance;
	using VTK.Volunteer;
	using System.Configuration;
  
  using Vha.Vss.Utility;


  /// <summary>
  ///    Summary description for CrystalWeb.
  /// </summary>
  public class CrystalWeb : Page
  {
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label DateRangeLabel;
    protected CrystalDecisions.Web.CrystalReportViewer CrystalReportViewer1;
    protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;

    private IDictionary config;
    internal UIReportParams par = null;
    internal CREngine.ReportDocument rpt = null;
    private CREngine.Database crDatabase;
    private CREngine.Tables crTables;
    private TableLogOnInfo crTableLogOnInfo;
    private ConnectionInfo crConnectionInfo;

    private CREngine.Sections crSections;
    private CREngine.ReportObjects crReportObjects;
    private CREngine.SubreportObject crSubReportObject;
	  public CrystalWeb()
    {
      try
      {
        config = (IDictionary)ConfigurationSettings.GetConfig("VssConfiguration/DSN");
      }
      catch{}
	    Page.Init += new System.EventHandler(OnInit);
    }

    private void OnLoad(object sender, EventArgs e)
    {
			if (!IsPostBack) 
			{
				try 
				{
					if (VtkPageHeader1.IsDivSelected("")) 
					{
						// get ReportParams out of Session
						par = RptUtility.GetParams(Context);
						if (par.ReportFormat == UIReportFormat.Web) 
						{
							// Load report parameters if this is the first time
							RptUtility.LoadReportParamsWeb(par, CrystalReportViewer1.ParameterFieldInfo);
							// put ReportName into ViewState for purpose of checking during postbacks if URL 
							// parameter was tampered with
							ViewState["ReportName"]=par.ReportType.ToString();
						} 
						else 
						{
							// TODO: error condition
						}
					}
				} 
				catch (Exception err) 
				{
					VtkUtility.ErrMsgAdd(ErrorMessage,err.Message);
				}
			} 
			else 
			{
				// it is a postback. Check that Request.Params["rpt"]==par.ReportType.ToString()
				// not a foolproof check (because ViewState could be tampered with) but adds another level
				// of checking
				if (Request.Params["rpt"]!=((string)ViewState["ReportName"])) 
				{
					VtkUtility.ErrMsgAdd(ErrorMessage,"rpt QueryString does not match original report type.","CrystalWeb");
					// and how to terminate page display?
					CrystalReportViewer1.Visible=false;
				} 
			}
		}

		protected void LoadReport() 
		{
			// call this from Page_Init (BEFORE viewstate is restored) to load report into CR Viewer.
			string reportName="";
			// try getting report from Context.Items. This works on initial page load, but not on postbacks.
			try 
			{
				UIReportParams par = RptUtility.GetParams(Context);
				reportName=par.ReportType.ToString();
			} 
			catch 
			{
				// if it's not the initial page report, get the reportname from URL parameter (less secure,
				// could be tampered with -- but checked by ViewState in Page_Load).
				reportName = Request.Params["rpt"];
			}

			if (reportName.Length>0) 
      {        
				// load the report
				RptUtility.LoadReport(reportName, out rpt);
        
				//Creating connection to database from ODBC 
				DataEncoder dataDecoder = new DataEncoder("VhaVss");

        crConnectionInfo = new ConnectionInfo();
        crConnectionInfo.ServerName = (string)config["Name"];
        crConnectionInfo.UserID = (string)config["UserId"];
        crConnectionInfo.Password = dataDecoder.DecodeString(((string)config["Password"]).Substring(1, ((string)config["Password"]).Length - 2));
        crConnectionInfo.DatabaseName = (string)config["DBName"];

        //Looping thru each Table on the report to add the connection
        crDatabase = rpt.Database;
        crTables = crDatabase.Tables;
  
        foreach (CREngine.Table crTable in crTables)
        {
          crTableLogOnInfo = crTable.LogOnInfo;
          crTableLogOnInfo.ConnectionInfo = crConnectionInfo;
          crTable.ApplyLogOnInfo(crTableLogOnInfo);
        }
        
        //Looping Through each of the sections, Reports in those sections, 
        //and SubReports in those Reports.
        crSections = rpt.ReportDefinition.Sections;
        foreach (CREngine.Section crSection in crSections)
        {
          crReportObjects = crSection.ReportObjects;
          foreach(CREngine.ReportObject crReportObject in crReportObjects)
          {
            if(crReportObject.Kind == ReportObjectKind.SubreportObject)
            {
              crSubReportObject = (CREngine.SubreportObject)crReportObject;
              crDatabase = crSubReportObject.OpenSubreport(crSubReportObject.SubreportName).Database;
              crTables = crDatabase.Tables;

              foreach(CREngine.Table crTable in crTables)
              {
                crTableLogOnInfo = crTable.LogOnInfo;
                crTableLogOnInfo.ConnectionInfo = crConnectionInfo;
                crTable.ApplyLogOnInfo(crTableLogOnInfo);              
              }
            }
          }
        }
				CrystalReportViewer1.ReportSource = rpt;
			}
		}

		private void OnInit(object sender, EventArgs e)
    {
        //
        // CODEGEN: This call is required by the ASP+ Windows Form Designer.
        //
        InitializeComponent();
			  LoadReport();
    }

    /// <summary>
    ///    Required method for Designer support - do not modify
    ///    the contents of this method with the code editor.
    /// </summary>
    private void InitializeComponent()
		{
			this.Load += new System.EventHandler(this.OnLoad);
		}

	}
}
