using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Choose a volunteer
	/// input: 
	///  Context.Items["vtkVolunteerChooserReturnPage"]
	///  Context.Items["vtkVolunteerChooserCancelPage"]
	/// output:
	///  Context.Items["vtkVolunteerChooserId"] int
	///  Context.Items["vtkVolunteerChooserName"] string
	///  Context.Items["vtkVolunteerChooserSuccess"] bool
	///  Context.Items[vtkVolunteerChooserTerminated"] bool
	/// </summary>
	public class VolunteerChooser : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button GetMoreButton;
		protected System.Web.UI.WebControls.Button ChooseButton;
		protected System.Web.UI.WebControls.Button RefreshSSNButton;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Button RefreshCodeButton;
		protected System.Web.UI.WebControls.TextBox NameText;
		protected System.Web.UI.WebControls.TextBox CodeText;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Button RefreshNameButton;
		protected System.Web.UI.WebControls.ListBox VolunteerList;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.ListBox TermList;
		protected System.Web.UI.WebControls.TextBox SSNText;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator;
		protected System.Web.UI.WebControls.RegularExpressionValidator CodeValidator;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator2;
		protected System.Web.UI.WebControls.RegularExpressionValidator CodeValidator2;

		const string emptyText="Enter info above and press refresh";
	
		public VolunteerChooser()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected(""))
				{
					if (!Page.IsPostBack)
					{
						//get input parameters
						if (Context.Items["vtkVolunteerChooserCancelPage"] != null)
						{ ViewState["CancelPage"] = Context.Items["vtkVolunteerChooserCancelPage"] ;}

						if (Context.Items["vtkVolunteerChooserReturnPage"] != null)
						{ ViewState["ReturnPage"] = Context.Items["vtkVolunteerChooserReturnPage"] ;}

						VolunteerList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void Refresh()
		{
			VolunteerList.Items.Clear() ;
			VolunteerList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
			NameText.Text = string.Empty ;
			SSNText.Text = string.Empty ;
			CodeText.Text = string.Empty ;
			GetMoreButton.Enabled = false ;
			GetMoreButton.Font.Bold = false ;
		}

		protected void PopulateList(SelectCriteria sc)
		{
			try
			{
				DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerList(sc, VtkPageHeader1.DivSelectedId, VtkUtility.GetAppCon()) ;
				//DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerList(sc, VtkUtility.GetAppCon()) ;
				DataTable dt = ds.Tables["VolunteerList"] ;

				if (dt.Rows.Count > 0)
				{
					//enable the choose button and list
					ChooseButton.Enabled = true ;
					VolunteerList.Enabled = true ;
					//define columns in list box
					VolunteerList.DataTextField = "DisplayName" ;
					VolunteerList.DataValueField = "ID" ;

					//bind list box to DataTable
					VolunteerList.DataSource = dt ;
					VolunteerList.DataBind() ;

					//define column in term list box, this track termination date
					TermList.DataTextField = "TerminationDate" ;
					TermList.DataValueField = "ID" ;
					TermList.DataSource = dt ;
					TermList.DataBind() ;
					//if only one volunteer, select it
					if (dt.Rows.Count == 1)
					{ VolunteerList.SelectedIndex = 0 ;}
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}

				ds.Dispose() ;
				dt.Dispose() ;

				if (!sc.AtEnd)
				{
					ViewState["sc"] = sc ;
					GetMoreButton.Enabled = true ;
					GetMoreButton.Font.Bold = true ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void RefreshNameButton_Click(object sender, System.EventArgs e)
		{
			NameText.Text = NameText.Text.ToUpper().Trim() ;

			if (NameText.Text.Length < 3)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the first 3 or more characters of the Volunteer's last name and press Refresh") ;}
			else
			{
				SelectCriteria sc = new SelectCriteria() ;
				sc.StartsWith = NameText.Text ;
				sc.MaxRecords = 75 ;
				Refresh() ;
				PopulateList(sc) ;
			}
		}

		private void RefreshSSNButton_Click(object sender, System.EventArgs e)
		{
			string ssn = SSNText.Text ;
			//if ssn contains dashes, remove
			if (Regex.IsMatch(ssn, @"^\d{3}-\d{2}-\d{4}"))
			{ ssn = ssn.Substring(0,3) + ssn.Substring(4,2) + ssn.Substring(7,4) ;}
			Refresh() ;
			try
			{
				DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListBySSN(ssn, VtkPageHeader1.DivSelectedId) ;
				//DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListBySSN(ssn, VtkUtility.GetAppCon()) ;
				DataTable dt = ds.Tables["VolunteerList"] ;

				if (dt.Rows.Count > 0)
				{
					//enable the choose button and list
					ChooseButton.Enabled = true ;
					VolunteerList.Enabled = true ;
					//define columns in list box
					VolunteerList.DataTextField = "DisplayName" ;
					VolunteerList.DataValueField = "ID" ;

					//bind list box to DataTable and dispose
					VolunteerList.DataSource = dt ;
					VolunteerList.DataBind() ;

					//define column in term list box, this track termination date
					TermList.DataTextField = "TerminationDate" ;
					TermList.DataValueField = "ID" ;
					TermList.DataSource = dt ;
					TermList.DataBind() ;
					//if only one volunteer, select it
					if (dt.Rows.Count == 1)
					{ VolunteerList.SelectedIndex = 0 ;}
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}

				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void RefreshCodeButton_Click(object sender, System.EventArgs e)
		{
			string code = CodeText.Text.Trim() ;
			Refresh() ;
			try
			{
				DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListByIdentifierCode(code, VtkPageHeader1.DivSelectedId, true) ;
				DataTable dt = ds.Tables["VolunteerList"] ;

				if (dt.Rows.Count > 0)
				{
					//enable the choose button and list
					ChooseButton.Enabled = true ;
					VolunteerList.Enabled = true ;
					//define columns in list box
					VolunteerList.DataTextField = "DisplayName" ;
					VolunteerList.DataValueField = "ID" ;

					//bind list box to DataTable and dispose
					VolunteerList.DataSource = dt ;
					VolunteerList.DataBind() ;

					//define column in term list box, this track termination date
					TermList.DataTextField = "TerminationDate" ;
					TermList.DataValueField = "ID" ;
					TermList.DataSource = dt ;
					TermList.DataBind() ;
					//if only one volunteer, select it
					if (dt.Rows.Count == 1)
					{ VolunteerList.SelectedIndex = 0 ;}
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}

				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void ChooseButton_Click(object sender, System.EventArgs e)
		{
			//check to see if they selected one
			if (VolunteerList.SelectedIndex > -1)
			{
				//get ID from list
				string volId = VolunteerList.SelectedItem.Value.ToString() ;
				Context.Items["vtkVolunteerChooserId"] = VolunteerList.SelectedItem.Value.ToString() ;
				Context.Items["vtkVolunteerChooserName"] = VolunteerList.SelectedItem.Text.ToString() ;
				Context.Items["vtkVolunteerChooserSuccess"] = true ;

				//check termination data in list
				bool term = false ;
				foreach (ListItem li in TermList.Items)
				{
					if (li.Value == volId)
					{
						//get termination date
						if (li.Text != null)
						{ 
							if (li.Text.ToString() != string.Empty)
							{term = true ;}
						}
						break ;
					}
				}
				Context.Items["vtkVolunteerChooserTerminated"] = term ;
				//navigate back
				//Response.Redirect(ViewState["ReturnPage"].ToString()) ;
				Server.Transfer(ViewState["ReturnPage"].ToString()) ;
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose a Volunteer from the list before pressing Choose") ;}
		}

		private void CancelButton_Click(object sender, System.EventArgs e)
		{
			Context.Items["vtkVolunteerChooserId"] = null ;
			Context.Items["vtkVolunteerChooserSuccess"] = "false" ;
			//navigate back
			if (ViewState["CancelPage"] != null)
			{ Server.Transfer(ViewState["CancelPage"].ToString()) ;}
			else
			{ Server.Transfer(ViewState["ReturnPage"].ToString()) ;}

		}

		private void GetMoreButton_Click(object sender, System.EventArgs e)
		{
			SelectCriteria sc = null ;
			//get SelectCriteria from viewstate
			if (ViewState["sc"] != null)
			{ sc = (SelectCriteria) ViewState["sc"] ;}
			PopulateList(sc) ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.RefreshNameButton.Click += new System.EventHandler(this.RefreshNameButton_Click);
			this.RefreshSSNButton.Click += new System.EventHandler(this.RefreshSSNButton_Click);
			this.RefreshCodeButton.Click += new System.EventHandler(this.RefreshCodeButton_Click);
			this.ChooseButton.Click += new System.EventHandler(this.ChooseButton_Click);
			this.GetMoreButton.Click += new System.EventHandler(this.GetMoreButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


	}
}
