using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerChooserMerge.
	/// </summary>
	public class VolunteerChooserMerge : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Button ChooseButton;
		protected System.Web.UI.WebControls.ListBox VolunteerList;
		protected System.Web.UI.WebControls.Label MatchLabel;
		protected System.Web.UI.WebControls.Button SubmitButton;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator2;
		protected System.Web.UI.WebControls.TextBox SSNText;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Label StationNameLabel;
		protected System.Web.UI.WebControls.DropDownList StationList;
		protected System.Web.UI.WebControls.Label SSNLabel;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		const string emptyText="Enter info above and press 'Search for Existing Volunteers'";
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						if (ViewState["volId"] != null)
						{
							int volId = Convert.ToInt32(ViewState["volId"]) ;
							string volSites = string.Empty ;
							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
							StationNameLabel.Text = VtkPageHeader1.DivSelectedName ;
							//get last name and ssn of volunteer, need for search
							Vha.Vtk.TimeKeeping.Volunteer volhdl = new Vha.Vtk.TimeKeeping.Volunteer(volId, VtkUtility.GetAppCon()) ;
							ViewState["volLastName"] = volhdl.LastName ;
							ViewState["ssn"] = volhdl.SocialSecurityNumber ;
							SSNLabel.Text = ViewState["ssn"].ToString() ;
							SSNText.Text = ViewState["ssn"].ToString() ;

							//need to exclude all stations this volunteer has a profile, plus CO & EMC
							volSites = "'101','101EMC','101GAG','101CAF','101WSC','101WCG'" ;
							//get all station profiles for this volunteer
							DataSet pds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVol(volId);
							foreach(DataRow dr in pds.Tables["StationProfileList"].Rows)
							{
								//need to add to string
								volSites = volSites + ", '" + dr["StationNumber"] +"'" ;
							}

							GetStationList(volSites) ;

						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer's Information") ;}
					}
					//save the stationId and volId on the form, this is used to navigate back to VolunteerEdit.aspx
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer information: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer information: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer information: " + err.Message) ;}
		}

		private void Refresh()
		{
			VolunteerList.Items.Clear() ;
			VolunteerList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
			ChooseButton.Enabled = false ;
			VolunteerList.Enabled = false ;
			MatchLabel.Visible = false ;
		}

		private void GetStationList(string excludeStations)
		{
			try
			{
				//get station list
				DataSet ids = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickList(excludeStations);
				ids.Tables["InstitutionList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable idt = ids.Tables["InstitutionList"] ;
				//add the first row, uses Rows.InsertAt(
				DataRow idr = idt.NewRow() ;
				idr["DisplayName"] = " -Select Station- " ;
				idr["ID"] = -1 ;
				idt.Rows.InsertAt(idr, 0) ;
				//define columns in list box
				StationList.DataTextField = "DisplayName" ;
				StationList.DataValueField = "ID" ;
				StationList.DataSource = idt ;
				StationList.DataBind() ;
				ids.Dispose() ;
				idt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Validation error loading the Station List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was a Transaction error loading the Station List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + err.Message) ;}
		}

		private string MissingFields()
		{
			bool comma = false ;
			string fields = string.Empty ;
			if (StationList.SelectedIndex < 1)
			{
				fields = "The following field(s) are Required: Search Station " ;
				comma = true ;
			}
			if (SSNText.Text == string.Empty)
			{
				if (comma)
				{ fields = fields + ", Social Security Number" ;}
				else
				{ fields = "Social Security Number is Required" ;}
			}
			return fields ;
		}

		private void SubmitButton_Click(object sender, System.EventArgs e)
		{
			Refresh();
			//check required fields
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, missingdata) ;}
			else
			{
				string volId = ViewState["volId"].ToString() ;
				string ssn = SSNText.Text ;
				string lastName = string.Empty ;
				string code = string.Empty ;
				string name = string.Empty ;
				int siteId = Convert.ToInt32(StationList.SelectedItem.Value) ;
				//save site name, this is needed to pass to the VolunteerMerge screen
				ViewState["siteName2"] = StationList.SelectedItem.Text ;
				bool rowCount = false ;
				//if ssn contains dashes, remove
				if (Regex.IsMatch(ssn, @"^\d{3}-\d{2}-\d{4}"))
				{ ssn = ssn.Substring(0,3) + ssn.Substring(4,2) + ssn.Substring(7,4) ;}
				try
				{
					//define columns in list box
					VolunteerList.DataTextField = "DisplayNameWithSSN" ;
					VolunteerList.DataValueField = "ID" ;

					DataSet dss = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListBySSN(ssn, siteId, volId) ;
					DataTable dts = dss.Tables["VolunteerList"] ;
					if (dts.Rows.Count > 0)
					{
						rowCount = true ;
						VolunteerList.Enabled = true ;
						ChooseButton.Enabled = true ;
						MatchLabel.Text = "SSN matches the existing volunteer!" ;
						MatchLabel.Visible = true ;
						VolunteerList.Items.Clear();

						//bind list box to DataTable and dispose
						VolunteerList.DataSource = dts ;
						VolunteerList.DataBind() ;
						dss.Dispose() ;
						dts.Dispose() ;
					}
					else
					{
						lastName = ViewState["volLastName"].ToString() ;
						code = lastName.Substring(0,1) + ssn.Substring(5,4) ;
						//if ssn fails, try lookup by code and check last name
						DataSet dsc = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListByIdentifierCode(code, siteId, true, volId) ;
						DataTable dtc = dsc.Tables["VolunteerList"] ;

						if (dtc.Rows.Count > 0)
						{
							//loop check last name, if same then build string for the new column, NameSSNStation
							foreach (DataRow dr in dtc.Rows)
							{
								if (dr["DisplayName"].ToString().StartsWith(lastName))
								{ rowCount = true ;}
								else
								{ dr.Delete() ;}
							}
							if (rowCount)
							{
								VolunteerList.Enabled = true ;
								ChooseButton.Enabled = true ;
								MatchLabel.Text = "Potential matches of volunteer(s) on last name!" ;
								MatchLabel.Visible = true ;
								VolunteerList.Items.Clear();

								//bind list box to DataTable and dispose
								VolunteerList.DataSource = dtc ;
								VolunteerList.DataBind() ;
							}
						}

						//clean up
						dsc.Dispose() ;
						dtc.Dispose() ;
					}

					if (!rowCount)
					{
						MatchLabel.Text = "No volunteers match your criteria!" ;
						MatchLabel.Visible = true ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
			}
		}

		private void ChooseButton_Click(object sender, System.EventArgs e)
		{
			//check to see if they selected one
			if (VolunteerList.SelectedIndex > -1)
			{
				StringBuilder sb = new StringBuilder("VolunteerMerge.aspx?") ;
				//add division
				sb.Append(VtkPageHeader.GetURLParameterString()) ;
				sb.Append("=") ;
				sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
				//add merge id1
				sb.Append("&mergeId1=") ;
				sb.Append(ViewState["volId"].ToString()) ;
				//add merge id2
				sb.Append("&mergeId2=") ;
				sb.Append(VolunteerList.SelectedItem.Value.ToString()) ;
				//add merge site
				sb.Append("&mergeSite=") ;
				sb.Append(ViewState["siteName2"].ToString()) ;
				Response.Redirect(sb.ToString()) ;
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose a Volunteer from the list before pressing 'Select Existing'") ;}
		
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.SubmitButton.Click += new System.EventHandler(this.SubmitButton_Click);
			this.ChooseButton.Click += new System.EventHandler(this.ChooseButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
