using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerChooserNew.
	/// </summary>
	public class VolunteerChooserNew : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button ChooseButton;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button AddButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Button SubmitButton;
		protected System.Web.UI.WebControls.TextBox NameText;
		protected System.Web.UI.WebControls.ListBox VolunteerList;
		protected System.Web.UI.WebControls.Label MatchLabel;
		protected System.Web.UI.WebControls.TextBox SSNText;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator2;
	
		const string emptyText="Enter info above and press 'Search for Existing Volunteers'";

		public VolunteerChooserNew()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Add Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						VolunteerList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void Refresh()
		{
			VolunteerList.Items.Clear() ;
			VolunteerList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
			AddButton.Enabled = false ;
			ChooseButton.Enabled = false ;
			VolunteerList.Enabled = false ;
			MatchLabel.Visible = false ;
		}

		private bool StationProfile(int volId, int siteId)
		{
			//check if volunteer has a station profile
			bool check = false ;
			DataSet ds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVolAndSite(volId, siteId) ;
			DataTable dt = ds.Tables["StationProfileList"] ;
			if (dt.Rows.Count == 1)
			{ check = true;}
			ds.Dispose() ;
			dt.Dispose() ;
			return check ;
		}

		private string MissingFields()
		{
			bool comma = false ;
			string fields = string.Empty ;
			if (NameText.Text == string.Empty)
			{
				fields = "The following field(s) are Required: Last Name " ;
				comma = true ;
			}
			if (SSNText.Text == string.Empty)
			{
				if (comma)
				{ fields = fields + ", Social Security Number" ;}
				else
				{ fields = "Social Security Number is Required" ;}
			}
			if (fields == string.Empty)
			{
				if (NameText.Text.Trim().Length < 2)
				{ fields = "Last Name must be at least 2 characters!" ;}
			}
			return fields ;
		}

		private string NavBuilder(string destination, string id, string ssn, string name)
		{
			//build url string to navigate VolunteerNewEdit add query strings
			StringBuilder sb = new StringBuilder(destination) ;
			sb.Append("?") ;
			//add division
			sb.Append(VtkPageHeader.GetURLParameterString()) ;
			sb.Append("=") ;
			sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
			//add volunteer id
			sb.Append("&volId=") ;
			sb.Append(id) ;
			//add volunteer name
			sb.Append("&volName=") ;
			sb.Append(name) ;
			//add volunteer ssn
			sb.Append("&volSSN=") ;
			sb.Append(ssn) ;
			return sb.ToString() ;
		}

		private void SubmitButton_Click(object sender, System.EventArgs e)
		{
			Refresh();
			//check required fields
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, missingdata) ;}
			else
			{
				if (NameText.Text==String.Empty)
				{VtkUtility.ErrMsgAdd(ErrorMessage, "You must enter the Last Name of the new Volunteer") ;}
				else 
				{
					string ssn = SSNText.Text ;
					string lastName = NameText.Text ;
					string code = lastName.Substring(0,1) + ssn.Substring(5,4) ;
					string name = string.Empty ;
					bool rowCount = false ;
					//if ssn contains dashes, remove
					if (Regex.IsMatch(ssn, @"^\d{3}-\d{2}-\d{4}"))
					{ ssn = ssn.Substring(0,3) + ssn.Substring(4,2) + ssn.Substring(7,4) ;}
					try
					{
						//define columns in list box
						VolunteerList.DataTextField = "DisplayNameWithSSN" ;
						VolunteerList.DataValueField = "ID" ;

						//first lookup by SSN
						DataSet dss = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListBySSN(ssn) ;
						DataTable dts = dss.Tables["VolunteerList"] ;

						if (dts.Rows.Count > 0)
						{
							rowCount = true ;
							VolunteerList.Enabled = true ;
							ChooseButton.Enabled = true ;
							MatchLabel.Text = "SSN matches the existing volunteer!" ;
							MatchLabel.Visible = true ;
							VolunteerList.Items.Clear();

							//bind list box to DataTable and dispose
							VolunteerList.DataSource = dts ;
							VolunteerList.DataBind() ;
							//disable add button, they have a ssn match, can't have duplicate ssn
							AddButton.Enabled = false ;
							//if only one volunteer, select it
							if (dts.Rows.Count == 1)
							{ VolunteerList.SelectedIndex = 0 ;}
						}
						else
						{
							//if ssn fails, try lookup by code and check last name
							DataSet dsc = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListByIdentifierCode(code, true) ;
							DataTable dtc = dsc.Tables["VolunteerList"] ;

							if (dtc.Rows.Count > 0)
							{
								//loop check last name, if same then build string for the new column, NameSSNStation
								foreach (DataRow dr in dtc.Rows)
								{
									if (dr["DisplayName"].ToString().StartsWith(lastName))
									{ rowCount = true ;}
									else
									{ dr.Delete() ;}
								}
							}
							if (rowCount)
							{
								VolunteerList.Enabled = true ;
								ChooseButton.Enabled = true ;
								MatchLabel.Text = "Potential matches of volunteer(s) on last name!" ;
								MatchLabel.Visible = true ;
								VolunteerList.Items.Clear();

								//bind list box to DataTable and dispose
								VolunteerList.DataSource = dtc ;
								VolunteerList.DataBind() ;
								//if only one volunteer, select it
								if (dtc.Rows.Count == 1)
								{ VolunteerList.SelectedIndex = 0 ;}
							}
							else
							{
								Response.Redirect(NavBuilder("VolunteerNewEdit.aspx","",SSNText.Text,NameText.Text)) ;
							}

							//clean up
							dsc.Dispose() ;
							dtc.Dispose() ;
							//enable add button
							AddButton.Enabled = true ;
						}
						dss.Dispose() ;
						dts.Dispose() ;
					}
					catch (VhaValidationException valErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
					catch (VhaTransactionException transErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
					catch (Exception err)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
				}
			}
		}

		private void ChooseButton_Click(object sender, System.EventArgs e)
		{
			//check to see if they selected one
			if (VolunteerList.SelectedIndex > -1)
			{
				string volId = VolunteerList.SelectedItem.Value.ToString() ;
				//if there is a station profile, goto VolunteerEdit
				if (StationProfile(Convert.ToInt32(volId), VtkPageHeader1.DivSelectedId))
				{ Response.Redirect(NavBuilder("VolunteerEdit.aspx",volId,"",VolunteerList.SelectedItem.Text.ToString())) ;}
				else
				{ Response.Redirect(NavBuilder("VolunteerNewEdit.aspx",volId,"",VolunteerList.SelectedItem.Text.ToString())) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose a Volunteer from the list before pressing 'Select Existing'") ;}

		}

		private void AddButton_Click(object sender, System.EventArgs e)
		{
			//pass name and ssn
			Context.Items["vtkVolunteerChooserSSN"] = SSNText.Text ;
			Context.Items["vtkVolunteerChooserName"] = NameText.Text ;
			//navigate
			Response.Redirect(NavBuilder("VolunteerNewEdit.aspx","",SSNText.Text,NameText.Text)) ;
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.SubmitButton.Click += new System.EventHandler(this.SubmitButton_Click);
			this.ChooseButton.Click += new System.EventHandler(this.ChooseButton_Click);
			this.AddButton.Click += new System.EventHandler(this.AddButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
