using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerComboEdit.
	/// </summary>
	public class VolunteerComboEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Label CodeLabel;
		protected System.Web.UI.WebControls.DropDownList OrganizationList;
		protected System.Web.UI.WebControls.DropDownList WorkdayList;
		protected System.Web.UI.WebControls.DropDownList ServiceList;
		protected System.Web.UI.WebControls.CheckBox InactiveCheckBox;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button NextButton;
		protected System.Web.UI.WebControls.DataGrid ComboGrid;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		public VolunteerComboEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						//check is this is a new volunteer, we navigate after the post differently
						if (Page.Request.QueryString["isNewVol"] != null)
						{ 
							ViewState["isNewVol"] = true ;
							NextButton.Visible = true ;
						}
						if (ViewState["volId"] != null)
						{
							//create handle
							int volId = Convert.ToInt32(ViewState["volId"]) ;

							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
							GetOrganizationList(VtkPageHeader1.DivSelectedId) ;
							GetServiceList(VtkPageHeader1.DivSelectedId) ;
							GetWorkdayList() ;
							GetComboGrid(volId) ;
							//get and save profile id, need it during posting
							Vha.Vtk.TimeKeeping.StationProfile prohdl = Vha.Vtk.TimeKeeping.StationProfile.Create(volId, VtkPageHeader1.DivSelectedId, VtkUtility.GetAppCon()) ;
							ViewState["proId"] = prohdl.ID.ToString() ;
							prohdl.Dispose() ;
							SetFields() ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination List") ;}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + err.Message) ;}
		}

		private void GetComboGrid(int volId)
		{
			try
			{
				//populate list of Combinations, get dataset,
				DataSet ds = Vha.Vtk.TimeKeeping.CombinationAssignment.GetQuickList(volId, VtkPageHeader1.DivSelectedId) ;
				DataTable dt = ds.Tables["CombinationAssignmentList"] ;

				ComboGrid.DataSource = dt ;
				ComboGrid.DataBind() ;
				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Combination List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Combination List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Combination List: " + err.Message) ;}
		}

		private void GetOrganizationList(int siteId)
		{
			try
			{
				//populate list of Organizations, get dataset, sort by code
				DataSet dsorg = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(siteId) ;
				//dsorg.Tables["OrganizationList"].DefaultView.Sort = "Code ASC" ;
				DataTable dtorg = dsorg.Tables["OrganizationList"] ;

				//add the first row
				DataRow drorg = dtorg.NewRow() ;
				drorg["DisplayName"] = " -Select Organization Code- " ;
				drorg["Code"] = "" ;
				dtorg.Rows.InsertAt(drorg, 0) ;

				//define columns in list box
				OrganizationList.DataTextField = "DisplayName" ;
				OrganizationList.DataValueField = "ID" ;

				//bind list box to DataTable and dispose
				OrganizationList.DataSource = dtorg ;
				OrganizationList.DataBind() ;
				dsorg.Dispose() ;
				dtorg.Dispose() ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void GetServiceList(int siteId)
		{
			try
			{
				//populate list of Services, get dataset, sort by code
				DataSet dssrv = Service.GetSiteQuickListByName(siteId) ;
				//dssrv.Tables["ServiceList"].DefaultView.Sort = "Code ASC" ;
				DataTable dtsrv = dssrv.Tables["ServiceList"] ;

				//add the first row
				DataRow drsrv = dtsrv.NewRow() ;
				drsrv["DisplayName"] = " -Select Service Code- " ;
				drsrv["Code"] = "" ;
				dtsrv.Rows.InsertAt(drsrv, 0) ;

				//define columns in list box
				ServiceList.DataTextField = "DisplayName" ;
				ServiceList.DataValueField = "ID" ;

				//bind list box to DataTable and dispose
				ServiceList.DataSource = dtsrv ;
				ServiceList.DataBind() ;
				dssrv.Dispose() ;
				dtsrv.Dispose() ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + err.Message) ;}
		}

		private void GetWorkdayList()
		{
			try
			{
				//populate list of workday, get dataset
				DataSet dswk = ScheduleWorkday.GetQuickList() ;
				dswk.Tables["ScheduleWorkdayList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable dtwk = dswk.Tables["ScheduleWorkdayList"] ;

				//add the first row
				DataRow drwk = dtwk.NewRow() ;
				drwk["DisplayName"] = " -Select Schedule Workday- " ;
				drwk["Code"] = "" ;
				dtwk.Rows.Add(drwk) ;

				//define columns in list box
				WorkdayList.DataTextField = "DisplayName" ;
				WorkdayList.DataValueField = "ID" ;

				//bind list box to DataTable and dispose
				WorkdayList.DataSource = dtwk ;
				WorkdayList.DataBind() ;
				dswk.Dispose() ;
				dtwk.Dispose() ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Workday List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Workday List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Workday List: " + err.Message) ;}
		}

		private void SetFields()
		{
			//initialize fields clear viewstate
			ViewState["comId"] = string.Empty ;
			ViewState["comVersion"] = string.Empty ;
			CodeLabel.Text = string.Empty ;
			OrganizationList.SelectedIndex = 0 ;
			ServiceList.SelectedIndex = 0 ;
			WorkdayList.SelectedIndex = 0 ;
			InactiveCheckBox.Checked = false ;
			//allway in New state
			CodeLabel.Text = "NEW" ;
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			int count = 0 ;
			bool comma = false ;
			if (OrganizationList.SelectedIndex < 1)
			{
				fields = "Organization" ;
				comma = true ;
				count++ ;
			}
			if (WorkdayList.SelectedIndex < 1)
			{
				if (comma)
				{ fields = fields + ", " ;}
				fields = fields + "Schedule Workday" ;
				comma = true ;
				count++ ;
			}
			if (ServiceList.SelectedIndex < 1)
			{
				if (comma)
				{ fields = fields + ", " ;}
				fields = fields + "Service" ;
				comma = true ;
				count++ ;
			}

			//if none of the fields are set, then there is no error
			if (count == 3)
			{ fields = string.Empty ;}
			return fields ;
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			CodeLabel.Text = "NEW" ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + missingdata) ;}
			else
			{
				SaveData() ;
			}
		}

		private void SaveData()
		{
			if (OrganizationList.SelectedIndex > 0)
			{
				//flag to check if version number has changed
				bool versionOk = true ;
				try
				{
					//define handle
					Vha.Vtk.TimeKeeping.CombinationAssignment comhdl = null ;
					//check if new or existing record
					if (ViewState["comId"].ToString() != string.Empty)
					{
						string comId = ViewState["comId"].ToString() ;
						//create handle and save Id and version
						comhdl = new Vha.Vtk.TimeKeeping.CombinationAssignment(Convert.ToInt32(comId), VtkUtility.GetAppCon()) ;
						//check version number
						if (ViewState["comVersion"].ToString() != comhdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Contact record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
					else
					{
						if (ViewState["proId"] != null)
						{
							//new record
							comhdl = Vha.Vtk.TimeKeeping.CombinationAssignment.AddRecord(Convert.ToInt32(ViewState["proId"]), VtkUtility.GetAppCon()) ;
						}
						else
						{ versionOk = false ;}
					}
					if (versionOk)
					{
						//save current fields
						comhdl.OrganizationId = Convert.ToInt32(OrganizationList.SelectedItem.Value) ;
						comhdl.BenefitingServiceId = Convert.ToInt32(ServiceList.SelectedItem.Value) ;
						comhdl.WorkdayScheduleId = Convert.ToInt32(WorkdayList.SelectedItem.Value) ;
						if (InactiveCheckBox.Checked)
						{comhdl.IsInactive = true ;}
						else
						{ comhdl.IsInactive = false ;}

						//save and dispose
						comhdl.Save() ;
						comhdl.Dispose() ;

						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update DataGrid
						GetComboGrid(Convert.ToInt32(ViewState["volId"])) ;

					}
					else
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Combination record has changed while you were editing, Please press EXIT and start over. ") ;}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + err.Message) ;}

				//clear viewstate and fields
				SetFields() ;
			}
		}

		private void NextButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + missingdata) ;}
			else
			{
				//if we have a record, save data
				if (OrganizationList.SelectedIndex > 0)
				{ SaveData() ;}
			}
			StringBuilder sb ;
			if (ViewState["isNewVol"] != null)
			{
				//navigate to parking edit page is volunteer is new
				sb = new StringBuilder("VolunteerKinEdit.aspx?") ;
				sb.Append("isNewVol=true&") ;
				//add division
				sb.Append(VtkPageHeader.GetURLParameterString()) ;
				sb.Append("=") ;
				sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
				//add volunteer id
				sb.Append("&volId=") ;
				sb.Append(ViewState["volId"]) ;
				//add volunteer name
				sb.Append("&volName=") ;
				sb.Append(ViewState["volName"]) ;
				Response.Redirect(sb.ToString()) ;
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error trying to navigate to the next page") ;}		
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//get selected Combination
			string comId = ComboGrid.SelectedItem.Cells[1].Text ;
			try
			{
				//create handle 
				Vha.Vtk.TimeKeeping.CombinationAssignment comhdl = new Vha.Vtk.TimeKeeping.CombinationAssignment(Convert.ToInt32(comId), VtkUtility.GetAppCon()) ;
				//enable fields and buttons and save Id and version
				SetFields() ;
				ViewState["comId"] = comId ;
				ViewState["comVersion"] = comhdl.Version.ToString() ;


				//set fields value
				CodeLabel.Text = comhdl.CombinationCode ;
				VtkUtility.SetSelectedSingle(OrganizationList.Items, comhdl.OrganizationId.ToString()) ;
				VtkUtility.SetSelectedSingle(ServiceList.Items, comhdl.BenefitingServiceId.ToString()) ;
				VtkUtility.SetSelectedSingle(WorkdayList.Items, comhdl.WorkdayScheduleId.ToString()) ;
				InactiveCheckBox.Checked = comhdl.IsInactive ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Combination record: " + err.Message) ;}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.NextButton.Click += new System.EventHandler(this.NextButton_Click);
			this.ComboGrid.SelectedIndexChanged += new System.EventHandler(this.EditButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
