using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerKinEdit.
	/// </summary>
	public class VolunteerKinEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.DropDownList KinList;
		protected System.Web.UI.WebControls.Label RecordLabel;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Button ExitButton;
		protected System.Web.UI.WebControls.TextBox KinNameText;
		protected System.Web.UI.WebControls.TextBox KinRelationshipText;
		protected System.Web.UI.WebControls.TextBox KinPhoneText;
		protected System.Web.UI.WebControls.TextBox KinPhone1Text;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Label StationLabel;
		protected System.Web.UI.WebControls.Label StationNameLabel;
		protected System.Web.UI.WebControls.DataGrid StationDataGrid;
		protected System.Web.UI.WebControls.Panel DataGridPanel;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.LinkButton NOKLinkButton;
		protected System.Web.UI.WebControls.Button NextButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		public VolunteerKinEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						//check is this is a new volunteer, we navigate after the post differently
						if (Page.Request.QueryString["isNewVol"] != null)
						{
							ViewState["isNewVol"] = true ;
							NextButton.Visible = true ;
						}
						if (ViewState["volId"] != null)
						{
							int volId = Convert.ToInt32(ViewState["volId"]) ;
							//set header name
							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
							GetStationGrid(volId) ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin List") ;}
					}
					//save the stationId & volId on the form, this is used by the exit button in the HTML
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + err.Message) ;}
	}

		protected void SetFields()
		{
			//clear all fields
			RecordLabel.Text = string.Empty ;
			KinNameText.Text = string.Empty ;
			KinRelationshipText.Text = string.Empty ;
			KinPhoneText.Text = string.Empty ;
			KinPhone1Text.Text = string.Empty ;
		}

		private void GetStationGrid(int volId)
		{
			string kinId = "0" ;
			try
			{
				//get contact list
				GetKinList(volId) ;
				//populate list of stations and next of kin, get dataset
				DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListOfNOKStations(volId) ;
				DataTable dt = ds.Tables["StationNOKListForVolunteer"] ;
				if (dt.Rows.Count == 1)
				{
					//if only 1 contact, then select it and make StationDataGrid invisible
					DataRow dr = dt.Rows[0] ;
					kinId = dr["NextOfKinId"].ToString() ;
					//set the station header label fields
					StationNameLabel.Text = dr["StationDisplayName"].ToString() ;
					ViewState["stationId"] = dr["StationId"].ToString() ;
					//RecordLabel.Visible = true ;
					//make invisible fields and buttons for multiple stations
					//KinList.Visible = false ;
					DataGridPanel.Visible = false ;
					NewButton.Visible = false ;
					GetKinRecord(kinId) ;
				}
				else
				{
					StationNameLabel.Text = string.Empty ;
					//loop thru stations and find current one
					foreach (DataRow drs in dt.Rows)
					{
						if (drs["StationId"].ToString() == VtkPageHeader1.DivSelectedId.ToString())
						{
							ViewState["stationId"] = drs["StationId"].ToString() ;
							kinId = drs["NextOfKinId"].ToString() ;
							//set the station header label fields
							StationNameLabel.Text = drs["StationDisplayName"].ToString() ;
							GetKinRecord(kinId) ;
							break ;
						}
					}
					StationDataGrid.DataSource = dt ;
					StationDataGrid.DataBind() ;
					//make visible fields and buttons for multiple stations
					RecordLabel.Visible = false ;
					KinList.Visible = true ;
					StationLabel.Visible = true ;
					StationNameLabel.Visible = true ;
					DataGridPanel.Visible = true ;
					NewButton.Visible = true ;
					PostButton.Visible = true ;
				}
				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Next of Kin Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Next of Kin Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Next of Kin Record: " + err.Message) ;}
		}

		private void GetKinRecord(string kinId)
		{
			if (kinId != string.Empty)
			{
				try
				{
					//create handle and save Id and version
					Vha.Vtk.TimeKeeping.NextOfKin kinhdl = new Vha.Vtk.TimeKeeping.NextOfKin(Convert.ToInt32(kinId), VtkUtility.GetAppCon()) ;
					ViewState["kinId"] = kinId.ToString() ;
					ViewState["kinVersion"] = kinhdl.Version.ToString() ;
					//get field values
					RecordLabel.Text = kinhdl.ID.ToString() ;
					KinNameText.Text = kinhdl.KinsName.ToString() ;
					KinRelationshipText.Text = kinhdl.Relationship.ToString() ;
					KinPhoneText.Text = kinhdl.Telephone.ToString() ;
					KinPhone1Text.Text = kinhdl.AlternateTelephone.ToString() ;

					//set contact list to current record
					VtkUtility.SetSelectedSingle(KinList.Items, kinId.ToString()) ;
					kinhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + err.Message) ;}
			}
			//there is no Next of Kin record id
			else
			{
				KinList.SelectedIndex = 0 ;
				ViewState["kinId"] = string.Empty ;
			}
		}

		private void GetKinList(int volId)
		{
			try
			{
				//populate list of kins, get dataset
				DataSet ds = Vha.Vtk.TimeKeeping.NextOfKin.GetQuickList(volId, VtkUtility.GetAppCon()) ;
				DataTable dt = ds.Tables["NextOfKinList"] ;

				//add the first row, uses Rows.InsertAt(
				DataRow dr = dt.NewRow() ;
				dr["KinsName"] = " -none- " ;
				dr["Id"] = -1 ;
				dt.Rows.InsertAt(dr,0) ;

				//define columns in list box
				KinList.DataTextField = "KinsName" ;
				KinList.DataValueField = "Id" ;

				//bind list box to DataTable and dispose
				KinList.DataSource = dt ;
				KinList.DataBind() ;
				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin Record: " + err.Message) ;}
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if (KinNameText.Text == string.Empty &&((KinRelationshipText.Text != string.Empty)
				||(KinPhoneText.Text != string.Empty)||(KinPhone1Text.Text != string.Empty)))
			{ fields = "The Name field is required." ;}
			
			return fields ;
		}

		private void EditButton_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			//"&nbsp;" is what we get from SQL when no data is present
			//when a field is null, SQL returns System.DBnull.  When this value is set in a control, it
			//is changed to &nbsp;  HtmlDecode will convert to a space and trim will remove spaces
			//This only needs to be done on fields that aren't required.
			string kinId = Server.HtmlDecode(e.Item.Cells[2].Text.ToString()).Trim() ;
			string siteId = e.Item.Cells[0].Text.ToString() ;
			//set the station header label fields
			StationNameLabel.Text = e.Item.Cells[1].Text.ToString() ;
			ViewState["stationId"] = siteId ;

			SetFields() ;
			GetKinRecord(kinId) ;

			StationLabel.Visible = true ;
			StationNameLabel.Visible = true ;
			KinList.Visible = true ;
			NewButton.Visible = true ;
			PostButton.Visible = true ;
			RecordLabel.Visible = false ;
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			RecordLabel.Text = "NEW" ;
			RecordLabel.Visible = true ;
			KinList.Visible = false ;
			NewButton.Visible = false ;
			ViewState["kinId"] = string.Empty ;
			ViewState["kinVersion"] = string.Empty ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, missingdata) ;}
			else
			{
				SaveData() ;
			}
		}

		private void SaveData()
		{
			int volId = Convert.ToInt32(ViewState["volId"].ToString()) ;
			//flag to check if version number has changed
			bool versionOk = false ;
			string kinId ;
			int kinhdlId = -1 ;
			try
			{
					//define handle
					Vha.Vtk.TimeKeeping.NextOfKin kinhdl = null ;
					//check if new or existing record
					if (ViewState["kinId"].ToString() != string.Empty)
					{
						kinId = ViewState["kinId"].ToString() ;
						kinhdlId = Convert.ToInt32(kinId) ;
						//kinhdlId = -1 if user selected '-none-'
						if (kinhdlId > 0)
						{
							//create handle and save Id and version
							kinhdl = new Vha.Vtk.TimeKeeping.NextOfKin(kinhdlId, VtkUtility.GetAppCon()) ;
							//check version number
							if (ViewState["kinVersion"].ToString() == kinhdl.Version.ToString())
							{
								versionOk = true ;
							}
							else
							{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Next of Kin record has changed while you were editing, Please press EXIT and start over. ") ;}
						}
							//user selected '-none-'
						else
						{ versionOk = true ;}
					}
					else
					{
						if (KinNameText.Text != string.Empty)
						{
							//new record
							kinhdl = Vha.Vtk.TimeKeeping.NextOfKin.AddRecord(volId, VtkUtility.GetAppCon()) ;
							kinhdlId = kinhdl.ID ;
							versionOk = true ;
						}
					}
					if (versionOk)
					{
						if (kinhdlId > -1)
						{
							//save current fields
							kinhdl.KinsName = KinNameText.Text ;
							kinhdl.Relationship = KinRelationshipText.Text ;
							kinhdl.Telephone = KinPhoneText.Text ;					
							kinhdl.AlternateTelephone = KinPhone1Text.Text ;

							//save and close
							kinhdl.Save() ;
							//get id, need to post to station profile
							kinhdlId = kinhdl.ID ;
							kinhdl.Dispose() ;
						}
						//use stationId to get station profile and file link
						if (ViewState["stationId"].ToString() != string.Empty)
						{
							int siteId = Convert.ToInt32(ViewState["stationId"].ToString()) ;
							DataSet ds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVolAndSite(volId, siteId) ;
							DataTable dt = ds.Tables["StationProfileList"] ;
							if (dt.Rows.Count == 1)
							{
								DataRow dr = dt.Rows[0] ;
								int proId = (int) dr["Id"] ;
								ds.Dispose() ;
								dt.Dispose() ;

								Vha.Vtk.TimeKeeping.StationProfile prohdl = new Vha.Vtk.TimeKeeping.StationProfile(proId, VtkUtility.GetAppCon()) ;
								if (kinhdlId > 0)
								{ prohdl.NextOfKinId = kinhdlId ;}
								else
								{ prohdl.NextOfKinId = int.MinValue ;}
								prohdl.Save() ;
								prohdl.Dispose() ;
							}
						}
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update service list and reset fields
						GetStationGrid(volId) ;
					}
					else
					{
						//update confirmation message
						ConfirmationMessage.Text = "No Record to Posted!" ;
					}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + err.Message) ;}
		}

		private void NOKLinkButton_Click(object sender, System.EventArgs e)
		{
			//build url string to navigate too, input the destination and add query strings
			StringBuilder sb = new StringBuilder("VolunteerKinEdit1.aspx") ;
			sb.Append("?") ;
			//add division
			sb.Append(VtkPageHeader.GetURLParameterString()) ;
			sb.Append("=") ;
			sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
			//add volunteer id
			sb.Append("&volId=") ;
			sb.Append(ViewState["volId"]) ;
			//add volunteer name
			sb.Append("&volName=") ;
			sb.Append(ViewState["volName"]) ;
			Response.Redirect(sb.ToString()) ;		
		}

		private void KinList_Click(object sender, System.EventArgs e)
		{
			//get next of kin id of row selected
			string kinId = KinList.SelectedItem.Value.ToString() ;
			SetFields() ;
			//check if we have a Kin record
			if (Convert.ToInt32(kinId) > 0)
			{ GetKinRecord(kinId) ;}
			else
			{
				//have 'none' record
				ViewState["kinId"] = "-1" ;
			}
		}

		private void NextButton_Click(object sender, System.EventArgs e)
		{
			//check if we have incomplete data
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, missingdata) ;}
			else
			{
				//if we have data, save it first
				if (KinNameText.Text != string.Empty)
				{ SaveData() ;}
				StringBuilder sb ;
				if (ViewState["isNewVol"] != null)
				{
					//navigate to station profile page is volunteer is new
					sb = new StringBuilder("VolunteerEdit.aspx?") ;
					sb.Append("isNewVol=true&") ;
					//add division
					sb.Append(VtkPageHeader.GetURLParameterString()) ;
					sb.Append("=") ;
					sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
					//add volunteer id
					sb.Append("&volId=") ;
					sb.Append(ViewState["volId"]) ;
					//add volunteer name
					sb.Append("&volName=") ;
					sb.Append(ViewState["volName"]) ;
					Response.Redirect(sb.ToString()) ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error trying to navigate to the next page") ;}
			}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.KinList.SelectedIndexChanged += new System.EventHandler(this.KinList_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.NextButton.Click += new System.EventHandler(this.NextButton_Click);
			this.StationDataGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.EditButton_Click);
			this.NOKLinkButton.Click += new System.EventHandler(this.NOKLinkButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
