using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerKinEdit1.
	/// </summary>
	public class VolunteerKinEdit1 : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.DataGrid KinDataGrid;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						if (ViewState["volId"] != null)
						{
							int volId = Convert.ToInt32(ViewState["volId"]) ;
							//set header name
							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
							GetKinDataGrid(volId) ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin List") ;}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
					if (ViewState["volName"] != null)
					{ Page.RegisterHiddenField("volName", ViewState["volName"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Next of Kin record: " + err.Message) ;}
		}

		private void DeleteButton_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			//get Id of selected nok
			string kinId = e.Item.Cells[0].Text.ToString() ;
			try
			{
				//define handle
				Vha.Vtk.TimeKeeping.NextOfKin kinhdl ;
				//create handle and save Id and version
				kinhdl = new Vha.Vtk.TimeKeeping.NextOfKin(Convert.ToInt32(kinId), VtkUtility.GetAppCon()) ;
				//delete, save, and dispose
				kinhdl.Delete() ;
				kinhdl.Save() ;
				kinhdl.Dispose() ;
				//update confirmation message
				ConfirmationMessage.Text = "Record Deleted!" ;
				if (ViewState["volId"].ToString() != string.Empty)
				{
					int volId = Convert.ToInt32(ViewState["volId"].ToString()) ;
					GetKinDataGrid(volId) ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Next of Kin Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Next of Kin Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Next of Kin Record: " + err.Message) ;}		
		}

		private void GetKinDataGrid(int volId)
		{
			try
			{
				//populate list of stations and next of kin, get dataset
				DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListOfNOKs(volId) ;
				DataTable dt = ds.Tables["NOKListForVolunteer"] ;

				KinDataGrid.DataSource = dt ;
				KinDataGrid.DataBind() ;
				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Next of Kin Records: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Next of Kin Records: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Next of Kin Records: " + err.Message) ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.KinDataGrid.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.DeleteButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
