using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerMerge.
	/// </summary>
	public class VolunteerMerge : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label NameLabel1;
		protected System.Web.UI.WebControls.Label NameLabel2;
		protected System.Web.UI.WebControls.Label SSNLabel1;
		protected System.Web.UI.WebControls.Label SSNLabel2;
		protected System.Web.UI.WebControls.Label PseudoLabel1;
		protected System.Web.UI.WebControls.Label PseudoLabel2;
		protected System.Web.UI.WebControls.Label DOBLabel1;
		protected System.Web.UI.WebControls.Label DOBLabel2;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Label SexLabel1;
		protected System.Web.UI.WebControls.Label SexLabel2;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label StationLabel1;
		protected System.Web.UI.WebControls.Label StationLabel2;
		protected System.Web.UI.WebControls.Label NickNameLabel1;
		protected System.Web.UI.WebControls.Label NickNameLabel2;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.CheckBox CheckBox1;
		protected System.Web.UI.WebControls.CheckBox CheckBox2;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					//create pop-up for verifying merge
					Page.RegisterOnSubmitStatement("PostButton", "return confirm('         !!!!WARNING!!!!  \\n This procedure will merge the \\n volunteer master records.\\n Do you still want to proceed?')") ;
					if (!Page.IsPostBack)
					{
						//check for input parameter, these came from VolunteerChooserMerge
						if (Page.Request.QueryString["mergeId1"] != null)
						{
							//save in view state
							ViewState["volId1"] = Page.Request.QueryString["mergeId1"].ToString() ;
							ViewState["volId2"] = Page.Request.QueryString["mergeId2"].ToString() ;
							ViewState["siteName"] = Page.Request.QueryString["mergeSite"].ToString() ;

							int volId1 = Convert.ToInt32(ViewState["volId1"]) ;
							int volId2 = Convert.ToInt32(ViewState["volId2"]) ;
							//populate fields
							GetVolunteerData(volId1, 1) ;
							GetVolunteerData(volId2, 2) ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer's Information") ;}
					}
					//save the stationId and volId on the form, this is used to navigate back to VolunteerEdit.aspx
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId1"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId1"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer information: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer information: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer information: " + err.Message) ;}
		}

		private void GetVolunteerData(int volId, int col)
		{
			//create handle
				Vha.Vtk.TimeKeeping.Volunteer volhdl = new Vha.Vtk.TimeKeeping.Volunteer(volId, VtkUtility.GetAppCon()) ;
			//get field values
			switch (col)
			{
				case 1:
					StationLabel1.Text = VtkPageHeader1.DivSelectedName ;
					NickNameLabel1.Text = volhdl.NickName ;
					NameLabel1.Text = volhdl.FullNameForReports ;
					SSNLabel1.Text = volhdl.SocialSecurityNumber ;
					DOBLabel1.Text = volhdl.DateOfBirth.ToShortDateString() ;
					if (volhdl.IsPseudoSSN)
					{ PseudoLabel1.Visible = true ;}
					else
					{ PseudoLabel1.Visible = false ;}
					if (volhdl.Sex == "M")
					{ SexLabel1.Text = "Male" ;}
					if (volhdl.Sex == "F")
					{ SexLabel1.Text = "Female" ;}
					break ;
				case 2:
					StationLabel2.Text = ViewState["siteName"].ToString() ;
					NickNameLabel2.Text = volhdl.NickName ;
					NameLabel2.Text = volhdl.FullNameForReports ;
					SSNLabel2.Text = volhdl.SocialSecurityNumber ;
					DOBLabel2.Text = volhdl.DateOfBirth.ToShortDateString() ;
					if (volhdl.IsPseudoSSN)
					{ PseudoLabel2.Visible = true ;}
					else
					{ PseudoLabel2.Visible = false ;}
					if (volhdl.Sex == "M")
					{ SexLabel2.Text = "Male" ;}
					if (volhdl.Sex == "F")
					{ SexLabel2.Text = "Female" ;}
					break ;
			}
		}

		private string CheckBox()
		{
			string errorString = string.Empty;
			if (CheckBox1.Checked == false && CheckBox2.Checked == false)
			{ errorString = "Please select a Volunteer to Keep." ;}
			if (CheckBox1.Checked == true && CheckBox2.Checked == true)
			{ errorString = "Please select only one Volunteer to Keep." ;}

			return errorString ;
		}

		private void CheckBox_Click(object sender, System.EventArgs e)
		{
			string errorMsg = CheckBox() ;
			if (errorMsg != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, errorMsg) ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string errorMsg = CheckBox() ;
			if (errorMsg == string.Empty)
			{
				try
				{
					int volId1 = Convert.ToInt32(ViewState["volId1"]) ;
					int volId2 = Convert.ToInt32(ViewState["volId2"]) ;

					//check if they already did the merge
					if (volId1 == volId2)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer has already been Merged") ;}
					else
					{
						if (CheckBox1.Checked)
						{
							//keep volunteer1
							Vha.Vtk.TimeKeeping.Volunteer.MergeVolunteers(volId1, volId2) ;
							volId2 = volId1 ;
							ViewState["volId2"] = volId2.ToString() ;
							GetVolunteerData(volId2, 2) ;
						}
						else
						{
							//keep volunteer 2
							Vha.Vtk.TimeKeeping.Volunteer.MergeVolunteers(volId2, volId1) ;
							volId1 = volId2 ;
							ViewState["volId1"] = volId1.ToString() ;
							GetVolunteerData(volId1, 1) ;
						}
						//update confirmation message
						ConfirmationMessage.Text = "Record Merged!" ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error mergeing the Volunteer Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error mergeing the Volunteer Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error mergeing the Volunteer Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, errorMsg) ;}
		
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.CheckBox1.CheckedChanged += new System.EventHandler(this.CheckBox_Click);
			this.CheckBox2.CheckedChanged += new System.EventHandler(this.CheckBox_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


	}
}
