using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerMultContactEdit.
	/// </summary>
	public class VolunteerMultContactEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.DataGrid StationDataGrid;
		protected System.Web.UI.WebControls.Label RecordLabel;
		protected System.Web.UI.WebControls.DropDownList RecordList;
		protected System.Web.UI.WebControls.TextBox Address1Text;
		protected System.Web.UI.WebControls.TextBox Address2Text;
		protected System.Web.UI.WebControls.TextBox CityText;
		protected System.Web.UI.WebControls.DropDownList StateList;
		protected System.Web.UI.WebControls.TextBox ZipText;
		protected System.Web.UI.WebControls.TextBox PhoneText;
		protected System.Web.UI.WebControls.TextBox Phone1Text;
		protected System.Web.UI.WebControls.TextBox Phone2Text;
		protected System.Web.UI.WebControls.TextBox EMailText;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button DeleteButton;
		protected System.Web.UI.WebControls.Label StationLabel;
		protected System.Web.UI.WebControls.Label StationNameLabel;
		protected System.Web.UI.WebControls.Panel DataGridPanel;
		protected System.Web.UI.WebControls.RegularExpressionValidator EMailValidator;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						if (ViewState["volId"] != null)
						{
							int volId = Convert.ToInt32(ViewState["volId"]) ;
							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;

							//populate state list
							DataSet dsst = Vha.Vtk.Kernel.Data.SystemTables.State.GetQuickList() ;
							DataTable dtst = dsst.Tables["StateList"] ;
							dtst.DefaultView.Sort = "Abbreviation ASC" ;

							// insert a new row for the "not selected" item
							DataRow stdr = dtst.NewRow() ;
							stdr["Id"]=int.MinValue;
							stdr["Abbreviation"]="--";
							dtst.Rows.InsertAt(stdr,0);

							StateList.DataTextField = "Abbreviation" ;
							StateList.DataValueField = "Id" ;
							StateList.DataSource = dtst.DefaultView ;
							StateList.DataBind() ;
							dsst.Dispose() ;
							dtst.Dispose() ;

							GetStationGrid(volId) ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer's Information") ;}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + err.Message) ;}
		}

		protected void SetFields()
		{
			//clear all fields
			RecordLabel.Text = string.Empty ;
			Address1Text.Text = string.Empty ;
			Address2Text.Text = string.Empty ;
			CityText.Text = string.Empty ;
			ZipText.Text = string.Empty ;
			PhoneText.Text = string.Empty ;
			Phone1Text.Text = string.Empty ;
			Phone2Text.Text = string.Empty ;
			EMailText.Text = string.Empty ;
			StateList.SelectedIndex = 0 ;

		}

		private void GetStationGrid(int volId)
		{
			string conId = "0" ;
			try
			{
				//get contact list
				GetContactList(volId) ;
				//populate list of stations and contacts, get dataset
				DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListOfStations(volId) ;
				DataTable dt = ds.Tables["StationListForVolunteer"] ;
				if (dt.Rows.Count == 1)
				{
					//if only 1 contact, then select it and make StationDataGrid invisible
					DataRow dr = dt.Rows[0] ;
					conId = dr["ContactInformationId"].ToString() ;
					//set the station header label fields
					StationNameLabel.Text = dr["StationDisplayName"].ToString() ;
					ViewState["stationId"] = dr["StationId"].ToString() ;
					RecordLabel.Visible = true ;
					//make invisible fields and buttons for multiple stations
					RecordList.Visible = false ;
					DataGridPanel.Visible = false ;
					DeleteButton.Visible = false ;
					NewButton.Visible = false ;
					GetContact(conId) ;
				}
				else
				{
					StationNameLabel.Text = string.Empty ;
					//loop thru stations and find current one
					foreach (DataRow drs in dt.Rows)
					{
						if (drs["StationId"].ToString() == VtkPageHeader1.DivSelectedId.ToString())
						{
							ViewState["stationId"] = drs["StationId"].ToString() ;
							conId = drs["ContactInformationId"].ToString() ;
							//set the station header label fields
							StationNameLabel.Text = drs["StationDisplayName"].ToString() ;
							GetContact(conId) ;
							break ;
						}
					}
					StationDataGrid.DataSource = dt ;
					StationDataGrid.DataBind() ;
					//make visible fields and buttons for multiple stations
					RecordLabel.Visible = false ;
					RecordList.Visible = true ;
					StationLabel.Visible = true ;
					StationNameLabel.Visible = true ;
					DataGridPanel.Visible = true ;
					NewButton.Visible = true ;
					PostButton.Visible = true ;
				}
				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact Record: " + err.Message) ;}
		}

		protected void GetContact(string conId)
		{
			try
			{
				//create handle
				Vha.Vtk.TimeKeeping.ContactInformation conhdl = new Vha.Vtk.TimeKeeping.ContactInformation(Convert.ToInt32(conId)) ;
				ViewState["conId"] = conhdl.ID.ToString() ;
				ViewState["conVersion"] = conhdl.Version.ToString() ;
				//populate fields
				RecordLabel.Text = conhdl.ID.ToString() ;
				Address1Text.Text = conhdl.StreetAddress1.ToString() ;
				Address2Text.Text = conhdl.StreetAddress2.ToString() ;
				CityText.Text = conhdl.City.ToString() ;
				ZipText.Text = conhdl.ZipCode.ToString() ;
				PhoneText.Text = conhdl.Telephone.ToString() ;
				Phone1Text.Text = conhdl.AlternateTelephone.ToString() ;
				Phone2Text.Text = conhdl.AlternateTelephone2.ToString() ;
				EMailText.Text = conhdl.EMailAddress.ToString() ;
				VtkUtility.SetSelectedSingle(StateList.Items, conhdl.StateId.ToString()) ;
				//set RecordList to current contact
				VtkUtility.SetSelectedSingle(RecordList.Items, conhdl.ID.ToString()) ;
				conhdl.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact Record: " + err.Message) ;}
		}

		private void GetContactList(int volId)
		{
			try
			{

				//populate list of contacts, get dataset
				DataSet ds = Vha.Vtk.TimeKeeping.ContactInformation.GetQuickList(volId, VtkUtility.GetAppCon()) ;
				DataTable dt = ds.Tables["ContactInformationList"] ;
				//define columns in list box
				RecordList.DataTextField = "StreetAddress1" ;
				RecordList.DataValueField = "Id" ;

				//bind list box to DataTable and cleanup
				RecordList.DataSource = dt ;
				RecordList.DataBind() ;
				ds.Dispose() ;
				dt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Contact List: " + err.Message) ;}
		}

		private void EditButton_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			string conId = e.Item.Cells[2].Text.ToString() ;
			string siteId = e.Item.Cells[0].Text.ToString() ;
			//set the station header label fields
			StationNameLabel.Text = e.Item.Cells[1].Text.ToString() ;
			ViewState["stationId"] = siteId ;
			try
			{
				SetFields() ;
				GetContact(conId) ;
				//"&nbsp;" is what we get from SQL when no data is present, maybe this could be changed to System.DBNull.Value
				if (siteId == "&nbsp;")
				{
					ViewState["stationId"] = string.Empty ;
					StationLabel.Visible = false ;
					StationNameLabel.Visible = false ;
					RecordList.Visible = false ;
					NewButton.Visible = false ;
					PostButton.Visible = false ;
					RecordLabel.Visible = true ;
					DeleteButton.Visible = true ;
				}
				else
				{
					StationLabel.Visible = true ;
					StationNameLabel.Visible = true ;
					RecordList.Visible = true ;
					NewButton.Visible = true ;
					PostButton.Visible = true ;
					RecordLabel.Visible = false ;
					DeleteButton.Visible = false ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + err.Message) ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			RecordLabel.Text = "NEW" ;
			RecordLabel.Visible = true ;
			RecordList.Visible = false ;
			NewButton.Visible = false ;
			DeleteButton.Visible = false ;
			ViewState["conId"] = string.Empty ;
			ViewState["conVersion"] = string.Empty ;
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			if (ViewState["stationId"].ToString() == string.Empty)
			{
				//get existing record
				if (ViewState["conId"].ToString() != string.Empty)
				{
					try
					{
						//define handle
						Vha.Vtk.TimeKeeping.ContactInformation conhdl ;
						string conId = ViewState["conId"].ToString() ;
						//create handle
						conhdl = new Vha.Vtk.TimeKeeping.ContactInformation(Convert.ToInt32(conId)) ;
						conhdl.Delete() ;
						conhdl.Save() ;
						conhdl.Dispose() ;

						//update confirmation message
						ConfirmationMessage.Text = "Record Deleted!" ;
						if (ViewState["volId"].ToString() != string.Empty)
						{
							int volId = Convert.ToInt32(ViewState["volId"].ToString()) ;
							GetStationGrid(volId) ;
						}
					}
					catch (VhaValidationException valErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + valErr.Message) ;}
					catch (VhaTransactionException transErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + transErr.Message) ;}
					catch (Exception err)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Contact record: " + err.Message) ;}
				}
			}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			int volId = Convert.ToInt32(ViewState["volId"].ToString()) ;
			//flag to check if version number has changed
			bool versionOk = false ;
			string conId ;
			try
			{
				//define handle
				Vha.Vtk.TimeKeeping.ContactInformation conhdl ;

				//get existing record
				if (ViewState["conId"].ToString() != string.Empty)
				{
					conId = ViewState["conId"].ToString() ;
					//create handle and save Id and version
					conhdl = new Vha.Vtk.TimeKeeping.ContactInformation(Convert.ToInt32(conId)) ;
					//check version number
					if (ViewState["conVersion"].ToString() == conhdl.Version.ToString())
					{
						versionOk = true ;
					}
					else
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Station Profile record has changed while you were editing, Please press EXIT and start over. ") ;}
				}
				else
				{
					//new record
					conhdl = Vha.Vtk.TimeKeeping.ContactInformation.AddRecord(volId) ;
					versionOk = true ;
				}
				if (versionOk)
				{
					//save current fields
					conhdl.StreetAddress1 = Address1Text.Text ;
					conhdl.StreetAddress2 = Address2Text.Text ;
					conhdl.City = CityText.Text ;
					conhdl.ZipCode = ZipText.Text ;
					conhdl.Telephone = PhoneText.Text ;
					conhdl.AlternateTelephone = Phone1Text.Text ;
					conhdl.AlternateTelephone2 = Phone2Text.Text ;
					conhdl.EMailAddress = EMailText.Text ;
					if (StateList.SelectedIndex > -1)
					{ conhdl.StateId = Convert.ToInt32(StateList.SelectedItem.Value) ;}
					//save
					conhdl.Save() ;
					//get id, need to post to station profile
					int conhdlId = conhdl.ID ;
					conhdl.Dispose() ;
					//use stationId to get station profile and file link
					if (ViewState["stationId"].ToString() != string.Empty)
					{
						int siteId = Convert.ToInt32(ViewState["stationId"].ToString()) ;
						DataSet ds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVolAndSite(volId, siteId) ;
						DataTable dt = ds.Tables["StationProfileList"] ;
						if (dt.Rows.Count == 1)
						{
							DataRow dr = dt.Rows[0] ;
							int proId = (int) dr["Id"] ;
							ds.Dispose() ;
							dt.Dispose() ;

							Vha.Vtk.TimeKeeping.StationProfile prohdl = new Vha.Vtk.TimeKeeping.StationProfile(proId, VtkUtility.GetAppCon()) ;
							prohdl.ContactInfoId = conhdlId ;
							prohdl.Save() ;
							prohdl.Dispose() ;
						}
					}
					//update confirmation message
					ConfirmationMessage.Text = "Record Posted!" ;
					//update service list and reset fields
					GetStationGrid(volId) ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Contact record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Contact record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Contact record: " + err.Message) ;}
		}

		private void RecordList_Click(object sender, System.EventArgs e)
		{
			//get contact id of row selected
			string conId = RecordList.SelectedItem.Value.ToString() ;
			GetContact(conId) ;
		}

		private void DivisionChange(object sender, System.EventArgs e)
		{

		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.RecordList.SelectedIndexChanged += new System.EventHandler(this.RecordList_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.DeleteButton.Click += new System.EventHandler(this.DeleteButton_Click);
			this.StationDataGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.EditButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
