using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.VOLUNTEER
{
	/// <summary>
	/// Summary description for VolunteerParkingEdit.
	/// </summary>
	public class VolunteerParkingEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.TextBox StickerText;
		protected System.Web.UI.WebControls.TextBox LicenseText;
		protected System.Web.UI.WebControls.DropDownList StateList;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button DeleteButton;
		protected System.Web.UI.WebControls.DataGrid ParkingGrid;
		protected System.Web.UI.WebControls.Label RecordLabel;
		protected System.Web.UI.WebControls.RegularExpressionValidator StickerValidator;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			//volId=volunteer Id; proId=volunteer station profile Id
			int proId ;
			int volId ;
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						if (ViewState["volId"] != null)
						{
							volId = Convert.ToInt32(ViewState["volId"]) ;
							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;

							//populate state list
							DataSet dsst = Vha.Vtk.Kernel.Data.SystemTables.State.GetQuickList() ;
							DataTable dtst = dsst.Tables["StateList"] ;
							dtst.DefaultView.Sort = "Abbreviation ASC" ;

							// insert a new row for the "not selected" item
							DataRow stdr = dtst.NewRow() ;
							stdr["Id"]=int.MinValue;
							stdr["Abbreviation"]="--";
							dtst.Rows.InsertAt(stdr,0);

							StateList.DataTextField = "Abbreviation" ;
							StateList.DataValueField = "Id" ;
							StateList.DataSource = dtst.DefaultView ;
							StateList.DataBind() ;
							dsst.Dispose() ;
							dtst.Dispose() ;

							//create handle, get station profile and save in viewstate
							DataSet spds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVolAndSite(volId, VtkPageHeader1.DivSelectedId) ;
							DataTable spdt = spds.Tables["StationProfileList"] ;
							//can only have 1 profile
							if (spdt.Rows.Count == 1)
							{
								DataRow spdr = spdt.Rows[0] ;
								//station profile Id
								proId = (int) spdr["Id"] ;
								//save information
								ViewState["proId"] = proId.ToString() ;
								//update parking grid
								GetParkingGrid(proId) ;
								//Clear fields and setup for new record
								SetFields() ;
								RecordLabel.Text = "New" ;
							}
							else
							{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer record is corrupted, multiple or missing Station Profile, contact your site manager!") ;}
							spds.Dispose() ;
							spdt.Dispose() ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Volunteer's Information") ;}
					}
					//save the stationId and volId on the form, this is used to navigate back to VolunteerEdit.aspx
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Parking Sticker record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Parking Sticker record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Parking Sticker record: " + err.Message) ;}
		}

		protected void SetFields()
		{
			//clear all fields
			RecordLabel.Text = string.Empty ;
			StickerText.Text = string.Empty ;
			LicenseText.Text = string.Empty ;
			StateList.SelectedIndex = 0 ;
			//reset viewstate values
			ViewState["parkingId"] = string.Empty ;
			ViewState["version"] = string.Empty ;
			DeleteButton.Visible = false ;
		}

		private void GetParkingGrid(int proId)
		{
			int stateId ;
			try
			{
				//populate grid of parking stickers, get dataset
				DataSet psds = Vha.Vtk.TimeKeeping.ParkingSticker.GetQuickList(proId, VtkUtility.GetAppCon()) ;
				DataTable psdt = psds.Tables["ParkingStickerList"] ;
				//define state column
				psdt.Columns.Add("State", System.Type.GetType("System.String")) ;
				//loop and set state field from stateId
				foreach (DataRow dr in psdt.Rows)
				{
					//check stateId, resolve id to text.
					if (dr["StateId"].ToString() != string.Empty)
					{
						stateId = Convert.ToInt32(dr["StateId"].ToString()) ;
						dr["State"] = GetState(stateId) ;
					}
				}
				//bind to parking grid and dispose
				ParkingGrid.DataSource = psdt ;
				ParkingGrid.DataBind() ;
				psds.Dispose() ;
				psdt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Parking Sticker Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Parking Sticker Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Parking Sticker Record: " + err.Message) ;}
		}

		protected string GetState(int Id) 
		{
			// given the int Id of a state, returns text of state abbreviation, for DISPLAY of current state
			string returnString;
			if (Id > 0) 
			{
				Vha.Vtk.Kernel.Data.SystemTables.State state = new Vha.Vtk.Kernel.Data.SystemTables.State(Id, VtkUtility.GetAppCon());
				returnString=state.Abbreviation;
				state.Dispose();
			} 
			else 
			{
				returnString = "--" ;
			}
			return returnString;
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if (StickerText.Text == string.Empty)
			{
				fields = "Sticker Number" ;
			}
			return fields ;
		}

		private void ParkingEdit_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			SetFields() ;
			//ParkingGrid: cell[0]=Id, [1]=StationProfileId, [2]=StateId
			string parkingId = e.Item.Cells[0].Text.ToString() ;
			try
			{
				//create handle pshdl
				Vha.Vtk.TimeKeeping.ParkingSticker pshdl = new Vha.Vtk.TimeKeeping.ParkingSticker(Convert.ToInt32(parkingId)) ;
				//update fields
				RecordLabel.Text = pshdl.ID.ToString() ;
				StickerText.Text = pshdl.StickerNumber ;
				LicenseText.Text = pshdl.LicensePlate ;
				VtkUtility.SetSelectedSingle(StateList.Items, pshdl.StateId.ToString());
				//save id
				ViewState["parkingId"] = pshdl.ID.ToString() ;
				ViewState["version"] = pshdl.Version.ToString() ;
				DeleteButton.Visible = true ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Parking Sticker Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Parking Sticker Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Parking Sticker Record: " + err.Message) ;}
		
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			//proId=volunteer station profile Id; parkingId=parking sticker record id
			int proId ;
			int parkingId = 0 ;
			string missingdata = MissingFields() ;
			bool versionOk = true ;
			try
			{
				if (ViewState["proId"] != null)
				{
					proId = Convert.ToInt32(ViewState["proId"].ToString()) ;
					if (missingdata != string.Empty)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following field is Required: " + missingdata) ;}
					else
					{
						//define handle
						Vha.Vtk.TimeKeeping.ParkingSticker pshdl ;
						//check if new or existing record
						if (ViewState["parkingId"].ToString() != string.Empty)
						{
							//existing record
							parkingId = Convert.ToInt32(ViewState["parkingId"].ToString()) ;
							pshdl = new Vha.Vtk.TimeKeeping.ParkingSticker(parkingId) ;
							//check version
							if (ViewState["version"].ToString() != pshdl.Version.ToString())
							{
								VtkUtility.ErrMsgAdd(ErrorMessage, "Current Program record has changed while you were editing, Please press EXIT and start over. ") ;
								versionOk = false ;
							}
						}
						else
						{
							//new record
							pshdl = Vha.Vtk.TimeKeeping.ParkingSticker.AddRecord(proId) ;
						}
						if (versionOk)
						{
							//post values
							pshdl.StickerNumber = StickerText.Text ;
							pshdl.LicensePlate = LicenseText.Text ;
							if (StateList.SelectedIndex > -1)
							{ pshdl.StateId = Convert.ToInt32(StateList.SelectedItem.Value) ;}
							//post and dispost
							pshdl.Save() ;
							pshdl.Dispose() ;
							//update confirmation message
							ConfirmationMessage.Text = "Record Posted!" ;
							//update service list and reset fields
							GetParkingGrid(proId) ;
							//Clear fields and setup for new record
							SetFields() ;
							RecordLabel.Text = "New" ;
						}
					}
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Parking Sticker record, Please try again!") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Parking Sticker record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Parking Sticker record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Parking Sticker record: " + err.Message) ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			RecordLabel.Text = "New" ;
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			int proId ;
			int parkingId ;
			try
			{
				//get existing record
				if (ViewState["parkingId"].ToString() != string.Empty)
				{
					parkingId = Convert.ToInt32(ViewState["parkingId"].ToString()) ;
					proId = Convert.ToInt32(ViewState["proId"].ToString()) ;
					//get handle
					Vha.Vtk.TimeKeeping.ParkingSticker pshdl = new Vha.Vtk.TimeKeeping.ParkingSticker(parkingId) ;
					pshdl.Delete() ;
					pshdl.Save() ;
					pshdl.Dispose() ;
					//update confirmation message
					ConfirmationMessage.Text = "Record Deleted!" ;
					//update service list and reset fields
					GetParkingGrid(proId) ;
					//Clear fields and setup for new record
					SetFields() ;
					RecordLabel.Text = "New" ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Parking Sticker record, Please try again!") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Parking Sticker record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Parking Sticker record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting Parking Sticker record: " + err.Message) ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.ParkingGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.ParkingEdit_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.DeleteButton.Click += new System.EventHandler(this.DeleteButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
