using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.TimeKeeping;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerStationAdjustment.
	/// </summary>
	public class VolunteerStationAdjustment : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.DataGrid AdjustmentGrid;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Label IdLabel;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate AdjustmentDate;
		protected System.Web.UI.WebControls.TextBox HoursText;
		protected System.Web.UI.WebControls.TextBox DescriptionText;
		protected System.Web.UI.WebControls.RegularExpressionValidator HoursValidator;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
							ViewState["proId"] = Page.Request.QueryString["proId"].ToString() ;
						}
						if (ViewState["volId"] != null && (ViewState["proId"] != null))
						{
							//initialize year list in date field, 
							AdjustmentDate.YearListBegin = DateTime.Now.Year-1 ;
							AdjustmentDate.YearListEnd = DateTime.Now.Year ;
							AdjustmentDate.InitializeControl() ;
							//update header
							VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
							InitializeFields() ;
							GetDataGrid(Convert.ToInt32(ViewState["proId"].ToString())) ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an Error loading record, Please Exit and try again!") ;}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{
						//save Id and Name, this is used by client side exit button to return to profile page
						Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;
						Page.RegisterHiddenField("volName", ViewState["volName"].ToString()) ;
					}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				int proId = Convert.ToInt32(ViewState["proId"].ToString()) ;
				string error = CheckFields() ;
				if (error != string.Empty)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
				else
				{
					Vha.Vtk.TimeKeeping.VolunteerAdjustments adjustHdl = Vha.Vtk.TimeKeeping.VolunteerAdjustments.AddRecord(proId) ;
					//save current fields
					adjustHdl.AdjustmentHours = Convert.ToInt32(HoursText.Text.ToString()) ;
					adjustHdl.AdjustmentDescription = DescriptionText.Text ;
					adjustHdl.AdjustmentDate = AdjustmentDate.Date ;
					adjustHdl.ProfileId = proId ;
					adjustHdl.StationId = VtkPageHeader1.DivSelectedId ;
					adjustHdl.VolunteerId = Convert.ToInt32(ViewState["volId"].ToString()) ;
					//save and close
					adjustHdl.Save() ;
					adjustHdl.Dispose() ;

					//update DataGrid
					GetDataGrid(proId) ;
					//update confirmation message
					ConfirmationMessage.Text = "Record Posted!" ;
					InitializeFields() ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving the Adjustment Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving the Adjustment Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving the Adjustment Record: " + err.Message) ;}
		}

		private void ClearButton_Click(object sender, System.EventArgs e)
		{
			InitializeFields() ;
		}

		private void InitializeFields()
		{
			//clear fields
			HoursText.Text = "" ;
			DescriptionText.Text = "" ;
			//set default values
			IdLabel.Text = "NEW" ;
			AdjustmentDate.Date = DateTime.MinValue ;
		}

		private string CheckFields()
		{
			string errorMsg = CheckDate() ;
			string msg = string.Empty ;
			//check required fields
			if (HoursText.Text == string.Empty)
			{ msg = "The following field(s) are Required: Hours" ;}
			if (DescriptionText.Text == string.Empty)
			{
				if (msg == string.Empty)
				{ msg = "The following field(s) are Required: Description" ;}
				else
				{ msg = msg + ", Description" ;}
			}
			if (msg != string.Empty)
			{ errorMsg = errorMsg + ", " + msg ;}

			return errorMsg ;
		}

		private string CheckDate()
		{
			string errorMsg = string.Empty ;
			if (AdjustmentDate.Date == DateTime.MinValue)
			{ errorMsg = "Adjustment Date is invalid" ;}
			else
			{
				//date must be prior fiscal year
				int fy = FiscalYear(DateTime.Now) ;
				if (FiscalYear(AdjustmentDate.Date) >= fy)
				{ errorMsg = "Adjustment Date cannot be in current Fiscal Year" ;}
			}
			return errorMsg ;
		}

		private int FiscalYear(DateTime date)
		{
			//return the fiscal year for the given date
			int fiscalYear = date.Year ;
			if (date.Month > 9)
			{ fiscalYear++ ;}
			return fiscalYear ;
		}

		private void GetDataGrid(int proId)
		{
			try
			{
				DataSet adds = Vha.Vtk.TimeKeeping.VolunteerAdjustments.GetQuickList(proId, VtkUtility.GetAppCon()) ;
				DataTable addt = adds.Tables["VolunteerAdjustmentsList"] ;
				//bind to parking grid and dispose
				AdjustmentGrid.DataSource = addt ;
				AdjustmentGrid.DataBind() ;
				adds.Dispose() ;
				addt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Adjustment List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Adjustment List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Adjustment List: " + err.Message) ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.ClearButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
