using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.TimeKeeping;
using Vha.Vss.Utility;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary description for VolunteerStationEdit.
	/// </summary>
	public class VolunteerStationEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox YearsText;
		protected System.Web.UI.WebControls.DropDownList TransportationList;
		protected System.Web.UI.WebControls.CheckBox CauseCheckBox;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button ExitButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate TerminationDate;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate LastAwardDate;
		protected System.Web.UI.WebControls.Label VolunteerNameLabel;
		protected System.Web.UI.WebControls.Label TotalHoursLabel;
		protected System.Web.UI.WebControls.Label CurrentHoursLabel;
		protected System.Web.UI.WebControls.DropDownList AwardList;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.RegularExpressionValidator YearsValidator;
		protected System.Web.UI.WebControls.Button ClearButton;
		protected System.Web.UI.WebControls.RadioButtonList MealsList;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate EntryDate;
		protected System.Web.UI.WebControls.Label TermRemarkLabel;
		protected System.Web.UI.WebControls.TextBox TermRemarkText;
		protected System.Web.UI.WebControls.Label AdjustedHoursLabel;
		protected System.Web.UI.WebControls.Button AddHoursButton;
		protected System.Web.UI.WebControls.Label PriorHoursLabel;
		protected System.Web.UI.WebControls.Label AwardHoursLabel;
		protected System.Web.UI.WebControls.TextBox RemarksText;

		public VolunteerStationEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//check for input parameter, must have
						if (Page.Request.QueryString["volId"] != null)
						{
							//save in view state
							ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							ViewState["volName"] = Page.Request.QueryString["volName"].ToString() ;
						}
						if (ViewState["volId"] != null)
						{
							//initialize year list in all date fields
							EntryDate.YearListBegin = 1980 ;
							EntryDate.YearListEnd = DateTime.Now.Year ;
							EntryDate.InitializeControl() ;
							TerminationDate.YearListBegin = 1980 ;
							TerminationDate.YearListEnd = DateTime.Now.Year ;
							TerminationDate.InitializeControl() ;
							LastAwardDate.YearListBegin = 1980 ;
							LastAwardDate.YearListEnd = DateTime.Now.Year ;
							LastAwardDate.InitializeControl() ;

							//get method of transportation list
							DataSet dsl = Vha.Vtk.TimeKeeping.StationProfile.GetMethodOfTransportationList() ;
							DataTable dtl = dsl.Tables["MethodOfTransportationList"] ;
							TransportationList.DataTextField = "External" ;
							TransportationList.DataValueField = "Key" ;
							TransportationList.DataSource = dtl ;
							TransportationList.DataBind() ;
							dsl.Dispose() ;
							dtl.Dispose() ;

							//Exclude following award codes from the list.
							//10 is "Hours and Years" Award.
							string sAwList = "'10'";

							//get award list
							DataSet dsa = Vha.Vtk.Common.Award.GetQuickListExclude(sAwList) ;
							dsa.Tables["AwardList"].DefaultView.Sort = "AwardCode ASC" ;
							DataTable dta = dsa.Tables["AwardList"] ;
							AwardList.DataTextField = "DisplayName" ;
							AwardList.DataValueField = "Id" ;
							//add the first row
							DataRow dra = dta.NewRow() ;
							dra["DisplayName"] = " - Select Award Code - " ;
							dra["AwardCode"] = "" ;
							dta.Rows.Add(dra) ;
							AwardList.DataSource = dta ;
							AwardList.DataBind() ;
							dsa.Dispose() ;
							dta.Dispose() ;

							//create handle, get station profile
							int volId = Convert.ToInt32(ViewState["volId"]) ;
							DataSet ds = Vha.Vtk.TimeKeeping.StationProfile.GetQuickListByVolAndSite(volId, VtkPageHeader1.DivSelectedId) ;
							DataTable dt = ds.Tables["StationProfileList"] ;
							if (dt.Rows.Count == 1)
							{
								DataRow dr = dt.Rows[0] ;
								//station profile Id
								int proId = (int) dr["Id"] ;
								int priorHours = 0 ;
								int adjustHours = 0 ;
								//save viewstate information
								ViewState["proId"] = proId.ToString() ;
								ViewState["version"] = dr["Version"].ToString() ;
								//get field values
								VolunteerNameLabel.Text = ViewState["volName"].ToString() ;
								YearsText.Text = dr["YearsAtStation"].ToString() ;
								//AwardHoursText.Text = dr["HoursLastAward"].ToString() ;
								AwardHoursLabel.Text = dr["HoursLastAward"].ToString() ;
								RemarksText.Text = dr["Remarks"].ToString() ;
								TotalHoursLabel.Text = dr["TotalHoursServed"].ToString() ;
								CurrentHoursLabel.Text = dr["CurrentYearHoursServed"].ToString() ;

								//prior hours includes the total adjustment hours, need to subtract the adjustments hours out so users can see adjustments
								priorHours = Convert.ToInt32(dr["PriorYearsServed"].ToString()) ;
								adjustHours = Vha.Vtk.TimeKeeping.VolunteerAdjustments.GetSumOfAdjustmentHours(proId, VtkUtility.GetAppCon()) ;
								PriorHoursLabel.Text =  Convert.ToString(priorHours - adjustHours);
								AdjustedHoursLabel.Text = adjustHours.ToString() ;

								//check that dates aren't null
								if (dr["EntryDate"] != System.DBNull.Value)
								{ EntryDate.Date =  (DateTime) dr["EntryDate"] ;}
								if (dr["DateLastAwardField"] != System.DBNull.Value)
								{ LastAwardDate.Date = (DateTime) dr["DateLastAwardField"] ;}
								if (dr["TerminationDate"] != System.DBNull.Value)
								{ TerminationDate.Date =  (DateTime) dr["TerminationDate"] ;}

								//get list value
								if (dr["EligibleForMeals"] != null)
								{ VtkUtility.SetSelectedSingle(MealsList.Items, dr["EligibleForMeals"].ToString()) ;}
								//get check boxes value
								if (dr["IsTerminatedWithCause"] != System.DBNull.Value)
								{
									if (Convert.ToBoolean(dr["IsTerminatedWithCause"]))
									{
										CauseCheckBox.Checked = true ;
										TermRemarkText.Visible = true ;
									}
									else
									{ CauseCheckBox.Checked = false ;}
								}

								//get list values
								if (dr["MethodOfTransportation"].ToString() != string.Empty)
								{ VtkUtility.SetSelectedSingle(TransportationList.Items, dr["MethodOfTransportation"].ToString()) ;}
								if (dr["AwardCodeId"].ToString() != string.Empty)
								{ VtkUtility.SetSelectedSingle(AwardList.Items, dr["AwardCodeId"].ToString()) ;}

								ds.Dispose() ;
								dt.Dispose() ;
							}
							else
							{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer record is corrupted, multiple or missing Station Profile, contact your site manager!") ;}
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer selection failed") ;}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					if (ViewState["volId"] != null)
					{ Page.RegisterHiddenField("volId", ViewState["volId"].ToString()) ;}
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			if (ViewState["proId"].ToString() != string.Empty)
			{
				//check date fields; EntryDate, TerminationDate, LastAwardDate
				string error = CheckFields() ;
				if (error != string.Empty)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
				else
				{ 
					if ((LastAwardDate.Date == System.DateTime.MinValue) && (AwardList.SelectedIndex > 0))
					{
						VtkUtility.ErrMsgAdd(ErrorMessage, "Date of Last Award cannot be empty. Select the Date of Last Award.") ;
					}
					else
					{
						if ((LastAwardDate.Date != System.DateTime.MinValue) && (AwardList.SelectedIndex == 0))
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Date of Last Award is assigned but no award selected from the list. Select an appropriate award from the list.") ;
						}
						else
						{
							SaveData() ;
						}
					}

				}			
			}			
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Station Profile record failed, can't post data") ;}
		}

		private void SaveData()
		{
			try
			{
				int proId = Convert.ToInt32(ViewState["proId"]) ;
				Vha.Vtk.TimeKeeping.StationProfile prohdl = new Vha.Vtk.TimeKeeping.StationProfile(proId, VtkUtility.GetAppCon()) ;
				//check version
				if (ViewState["version"].ToString() == prohdl.Version.ToString())
				{
					//post values
					prohdl.YearsAtStation = Convert.ToInt32(YearsText.Text) ;
					//prohdl.HoursLastAward = Convert.ToInt32(AwardHoursText.Text) ;
					prohdl.HoursLastAward = Convert.ToInt32(AwardHoursLabel.Text) ;
					//prohdl.PriorYearsHoursServed = Convert.ToInt32(PriorHoursText.Text) ;
					prohdl.Remarks = RemarksText.Text ;
					prohdl.EntryDate = EntryDate.Date ;
					prohdl.TerminationDate = TerminationDate.Date ;
					prohdl.DateLastAward = LastAwardDate.Date ;
					//prohdl.TotalHoursServed = Convert.ToInt32(TotalHoursLabel.Text) + Convert.ToInt32(PriorHoursLabel.Text) ;

					if (MealsList.SelectedIndex > -1)
					{ prohdl.EligibleForMeals = Convert.ToInt32(MealsList.SelectedItem.Value.ToString()) ;}
					prohdl.IsTerminatedWithCause = CauseCheckBox.Checked ;
					if (TransportationList.SelectedIndex > -1)
					{ prohdl.MethodOfTransportation = TransportationList.SelectedItem.Value.ToString() ;}
					//award=0 means they want to remove the award
					if (AwardList.SelectedIndex == 0)
					{ prohdl.AwardCodesId = int.MinValue ;}
					else
					{ prohdl.AwardCodesId = Convert.ToInt32(AwardList.SelectedItem.Value) ;}
					prohdl.Save() ;
					//TotalHoursLabel.Text = prohdl.TotalHoursServed.ToString() ;

					//save viewstate information
					ViewState["version"] = prohdl.Version.ToString() ;
					prohdl.Dispose() ;
					//save terminated remarks with station name and date in the Volunteer Record
					if (CauseCheckBox.Checked && TermRemarkText.Text.Length > 0)
					{
						Vha.Vtk.TimeKeeping.Volunteer volhdl = new Vha.Vtk.TimeKeeping.Volunteer(Convert.ToInt32(ViewState["volId"].ToString()),  VtkUtility.GetAppCon()) ;
						volhdl.Remarks = volhdl.Remarks + '\n' + "----------" + '\n' + VtkPageHeader1.DivSelectedName + " (" + DateTime.Today.ToShortDateString() + "): " + TermRemarkText.Text ;
						volhdl.Save() ;
						volhdl.Dispose() ;
						TermRemarkText.Text = string.Empty ;
					}

					//update confirmation message
					ConfirmationMessage.Text = "Record Posted!" ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Station Profile record has changed while you were editing, Please press EXIT and start over. ") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving the Station Profile Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving the Station Profile Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving the Station Profile Record: " + err.Message) ;}
		}

		private void ClearButton_Click(object sender, System.EventArgs e)
		{
			TerminationDate.Date = DateTime.MinValue ;
			CauseCheckBox.Checked = false ;
		}

		private void CauseCheckBox_Click(object sender, System.EventArgs e)
		{
			if (CauseCheckBox.Checked)
			{
				TermRemarkLabel.Visible = true ;
				TermRemarkText.Visible = true ;
			}
			else
			{
				TermRemarkLabel.Visible = false ;
				TermRemarkText.Visible = false ;
				TermRemarkText.Text = string.Empty ;
			}
		}

		private void AddHoursButton_Click(object sender, System.EventArgs e)
		{
			//build url string to navigate to
			StringBuilder sb = new StringBuilder("VolunteerStationAdjustment.aspx") ;
			sb.Append("?") ;
			//add division
			sb.Append(VtkPageHeader.GetURLParameterString()) ;
			sb.Append("=") ;
			sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
			//add volunteer id
			sb.Append("&volId=") ;
			sb.Append(ViewState["volId"]) ;
			//add volunteer name
			sb.Append("&volName=") ;
			sb.Append(ViewState["volName"]) ;
			//add profile id
			sb.Append("&proId=") ;
			sb.Append(ViewState["proId"]) ;
			Response.Redirect(sb.ToString()) ;
		}

		private string CheckFields()
		{
			string errorMsg = CheckDates() ;
			//Years at Station is required, can be 0
			if (YearsText.Text == string.Empty)
			{
				if ( errorMsg != string.Empty)
				{ errorMsg = errorMsg + ", " ;}

				errorMsg = errorMsg + "Years at Station is Required" ;
			}
			if (errorMsg == string.Empty)
			{
				if (CauseCheckBox.Checked && TerminationDate.Date == DateTime.MinValue)
				{ errorMsg = "You can't Check 'Terminated with Cause?' without a Termination Date" ;}
			}

			return errorMsg ;
		}

		private string CheckDates()
		{
			string errorMsg = string.Empty ;
			string msg = string.Empty ;
			bool flag = false ;
			//the setting of date is needed to force the object to set the ValidateErrorMessage
			DateTime date ;
			if (EntryDate.Date == DateTime.MinValue)
			{
				errorMsg = "Record Entry Date is invalid" ;
				flag = true ;
			}
			date = TerminationDate.Date ;
			msg = TerminationDate.ValidateErrorMessage ;
			if (msg != string.Empty && (msg != "Not selected"))
			{
				if (flag)
				{ errorMsg = errorMsg + ", " ;}
				errorMsg = errorMsg + "Termination Date is invalid" ;
				flag = true ;
			}
			date = LastAwardDate.Date ;
			msg = LastAwardDate.ValidateErrorMessage ;
			if (msg != string.Empty && (msg != "Not selected"))
			{
				if (flag)
				{ errorMsg = errorMsg + ", " ;}
				errorMsg = errorMsg + "Date Of Last Award is invalid" ;
			}
			return errorMsg ;
		}
		private void AwardList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (AwardList.SelectedIndex != 0)
			{ 
				int awardId = Convert.ToInt32(AwardList.SelectedItem.Value);

				AwardHoursLabel.Text = "";

				NameObjectCollection awrdList = Vha.Vtk.Common.Award.GetHoursDRForAwardId(awardId); 
				NameObjectCollection awrdRec = new NameObjectCollection();

				if (awrdList.Count > 0)
				{
					awrdRec = (NameObjectCollection)awrdList.Get(0);
					if (awrdRec.Count> 0)
						AwardHoursLabel.Text = awrdRec.Get(0).ToString();
				}
				awrdList.Dispose();
				awrdRec.Dispose();
			}
			else
				AwardHoursLabel.Text = "";
			
		}
		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.AddHoursButton.Click += new System.EventHandler(this.AddHoursButton_Click);
			this.AwardList.SelectedIndexChanged += new System.EventHandler(this.AwardList_SelectedIndexChanged);
			this.ClearButton.Click += new System.EventHandler(this.ClearButton_Click);
			this.CauseCheckBox.CheckedChanged += new System.EventHandler(this.CauseCheckBox_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion



	}
}
